@@ -23,11 +23,13 @@
    You should have received a copy of the GNU Library General Public
    License along with this library; see the file COPYING.LIB.
    If not, write to the Free Software Foundation,
-   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+   51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */ 
 
 #ifndef _GNUstep_H_AppKit
 #define _GNUstep_H_AppKit
+#import <GNUstepBase/GSVersionMacros.h>
 
 /* Define library version */
 #include <GNUstepGUI/GSVersion.h>
@@ -43,6 +45,7 @@
 #include <AppKit/NSGraphics.h>
 
 #include <AppKit/NSActionCell.h>
+#include <AppKit/NSAnimation.h>
 #include <AppKit/NSApplication.h>
 #include <AppKit/NSAttributedString.h>
 #include <AppKit/NSBitmapImageRep.h>
@@ -105,7 +108,6 @@
 #include <AppKit/NSSliderCell.h>
 #include <AppKit/NSSpellChecker.h>
 #include <AppKit/NSSpellProtocol.h>
-#include <AppKit/NSSpellServer.h>
 #include <AppKit/NSSplitView.h>
 #include <AppKit/NSStringDrawing.h>
 #include <AppKit/NSText.h>
@@ -115,12 +117,14 @@
 #include <AppKit/NSWindow.h>
 #include <AppKit/NSWorkspace.h>
 
-#ifndef STRICT_OPENSTEP
+#if OS_API_VERSION(GS_API_MACOSX, GS_API_LATEST)
 #include <AppKit/NSAlert.h>
 #include <AppKit/NSAffineTransform.h>
+#include <AppKit/NSArrayController.h>
 #include <AppKit/NSBezierPath.h>
 #include <AppKit/NSComboBox.h>
 #include <AppKit/NSComboBoxCell.h>
+#include <AppKit/NSController.h>
 #include <AppKit/NSDocument.h>
 #include <AppKit/NSDocumentController.h>
 #include <AppKit/NSDrawer.h>
@@ -130,11 +134,15 @@
 #include <AppKit/NSInputManager.h>
 #include <AppKit/NSInputServer.h>
 #include <AppKit/NSInterfaceStyle.h>
+#include <AppKit/NSKeyValueBinding.h>
 #include <AppKit/NSLayoutManager.h>
+#include <AppKit/NSLevelIndicator.h>
+#include <AppKit/NSLevelIndicatorCell.h>
 #include <AppKit/NSMovie.h>
 #include <AppKit/NSMovieView.h>
 #include <AppKit/NSNib.h>
 #include <AppKit/NSNibDeclarations.h>
+#include <AppKit/NSObjectController.h>
 #include <AppKit/NSOpenGL.h>
 #include <AppKit/NSOpenGLView.h>
 #include <AppKit/NSOutlineView.h>
@@ -160,6 +168,7 @@
 #include <AppKit/NSTextView.h>
 #include <AppKit/NSToolbar.h>
 #include <AppKit/NSToolbarItem.h>
+#include <AppKit/NSUserDefaultsController.h>
 #include <AppKit/NSUserInterfaceValidation.h>
 #include <AppKit/NSWindowController.h>
 #include <AppKit/NSWindow+Toolbar.h>
