@@ -18,11 +18,13 @@
    
    You should have received a copy of the GNU Library General Public
    License along with this library; if not, write to the Free
-   Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111 USA.
+   Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02111 USA.
    */
 
 #ifndef _DPSOperators_h_INCLUDE
 #define _DPSOperators_h_INCLUDE
+#import <GNUstepBase/GSVersionMacros.h>
 
 #include <AppKit/NSGraphicsContext.h>
 
