@@ -23,12 +23,14 @@
    You should have received a copy of the GNU Library General Public
    License along with this library; see the file COPYING.LIB.
    If not, write to the Free Software Foundation,
-   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+   51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */ 
 #ifndef _GNUstep_H_NSAttributedString
 #define _GNUstep_H_NSAttributedString
+#import <GNUstepBase/GSVersionMacros.h>
 
-#ifndef	STRICT_OPENSTEP
+#if OS_API_VERSION(GS_API_MACOSX, GS_API_LATEST)
 
 #include <Foundation/NSAttributedString.h>
 #include <Foundation/NSRange.h>
@@ -47,17 +49,26 @@
 /* Global NSString attribute names used in accessing the respective
    property in a text attributes dictionary.  if the key is not in the
    dictionary the default value is assumed.  */
-APPKIT_EXPORT NSString *NSFontAttributeName;
-APPKIT_EXPORT NSString *NSParagraphStyleAttributeName;
-APPKIT_EXPORT NSString *NSForegroundColorAttributeName;
-APPKIT_EXPORT NSString *NSUnderlineStyleAttributeName;
-APPKIT_EXPORT NSString *NSSuperscriptAttributeName;
-APPKIT_EXPORT NSString *NSBackgroundColorAttributeName;
 APPKIT_EXPORT NSString *NSAttachmentAttributeName;
-APPKIT_EXPORT NSString *NSLigatureAttributeName;
+APPKIT_EXPORT NSString *NSBackgroundColorAttributeName;
 APPKIT_EXPORT NSString *NSBaselineOffsetAttributeName;
+APPKIT_EXPORT NSString *NSCursorAttributeName;
+APPKIT_EXPORT NSString *NSExpansionAttributeName;
+APPKIT_EXPORT NSString *NSFontAttributeName;
+APPKIT_EXPORT NSString *NSForegroundColorAttributeName;
 APPKIT_EXPORT NSString *NSKernAttributeName;
+APPKIT_EXPORT NSString *NSLigatureAttributeName;
 APPKIT_EXPORT NSString *NSLinkAttributeName;
+APPKIT_EXPORT NSString *NSObliquenessAttributeName;
+APPKIT_EXPORT NSString *NSParagraphStyleAttributeName;
+APPKIT_EXPORT NSString *NSShadowAttributeName;
+APPKIT_EXPORT NSString *NSStrikethroughColorAttributeName;
+APPKIT_EXPORT NSString *NSStrokeColorAttributeName;
+APPKIT_EXPORT NSString *NSStrokeWidthAttributeName;
+APPKIT_EXPORT NSString *NSSuperscriptAttributeName;
+APPKIT_EXPORT NSString *NSToolTipAttributeName;
+APPKIT_EXPORT NSString *NSUnderlineColorAttributeName;
+APPKIT_EXPORT NSString *NSUnderlineStyleAttributeName;
 
 /* Currently supported values for NSUnderlineStyleAttributeName.  */
 enum 									
@@ -91,7 +102,7 @@ enum
 - (NSFileWrapper*) RTFDFileWrapperFromRange: (NSRange)range
   documentAttributes: (NSDictionary*)dict;
 
-#ifndef STRICT_OPENSTEP
+#if OS_API_VERSION(GS_API_MACOSX, GS_API_LATEST)
 + (NSArray *) textFileTypes;
 + (NSArray *) textPasteboardTypes;
 + (NSArray *) textUnfilteredFileTypes;
