@@ -23,19 +23,25 @@
    You should have received a copy of the GNU Library General Public
    License along with this library; see the file COPYING.LIB.
    If not, write to the Free Software Foundation,
-   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+   51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */ 
 
 #ifndef _GNUstep_H_NSCell
 #define _GNUstep_H_NSCell
+#import <GNUstepBase/GSVersionMacros.h>
 
 #include <Foundation/NSCoder.h>
 #include <Foundation/NSGeometry.h>
 
 // For tint
 #include <AppKit/NSColor.h>
+// for NSWritingDirection
+#include <AppKit/NSParagraphStyle.h>
 // For text alignment
 #include <AppKit/NSText.h>
+// for NSFocusRingType
+#include <AppKit/NSView.h>
 
 @class NSString;
 @class NSMutableDictionary;
@@ -56,9 +62,9 @@ enum {
   NSPositiveIntType,   
   NSFloatType,
   NSPositiveFloatType,   
-  NSDateType,
   NSDoubleType,   
-  NSPositiveDoubleType
+  NSPositiveDoubleType,
+  NSDateType
 };
 
 typedef enum {
@@ -119,7 +125,7 @@ enum {
   NSString *_contents;
   NSImage *_cell_image;
   NSFont *_font;
-  id _objectValue;
+  id _object_value;
   struct GSCellFlagsType { 
     // total 32 bits.  0 bits left.
     unsigned contents_is_attributed_string: 1;
@@ -142,30 +148,40 @@ enum {
     unsigned type: 2;           // 3 values
     unsigned image_position: 3; // 7 values
     unsigned entry_type: 4;     // 8 values
+    unsigned allows_undo: 1;
+    unsigned line_break_mode: 3; // 6 values
+
+    // total 19 bits.  4 bits extension, 9 bits left.
+    int state: 2; // 3 values but one negative
+    unsigned mnemonic_location: 8;
+    unsigned control_tint: 3;
+    unsigned control_size: 2;
+    unsigned focus_ring_type: 2; // 3 values
+    unsigned base_writing_direction: 2; // 3 values
     // 4 bits reserved for subclass use
     unsigned subclass_bool_one: 1;
     unsigned subclass_bool_two: 1;
     unsigned subclass_bool_three: 1;
     unsigned subclass_bool_four: 1;
-    /* This is not in the bitfield now (for simpler macosx compatibility) 
-       but who knows in the future */
-    int state; // 3 values but one negative
   } _cell;
-  unsigned char _mnemonic_location;
   unsigned int _mouse_down_flags;
   unsigned int _action_mask; 
   NSFormatter *_formatter;
   NSMenu *_menu;
   id _represented_object; 
+  void *_reserved1;
 }
 
 //
 // Class methods
 // 
-#ifndef STRICT_OPENSTEP
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_3, GS_API_LATEST)
++ (NSFocusRingType)defaultFocusRingType;
+#endif
+#if OS_API_VERSION(GS_API_MACOSX, GS_API_LATEST)
 + (NSMenu *)defaultMenu;
 #endif
-+ (BOOL) prefersTrackingUntilMouseUp;
++ (BOOL)prefersTrackingUntilMouseUp;
 
 //
 // Initializing an NSCell 
@@ -215,6 +231,10 @@ enum {
 - (BOOL)isOpaque;
 - (void)setBezeled:(BOOL)flag;
 - (void)setBordered:(BOOL)flag;
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_3, GS_API_LATEST)
+- (NSFocusRingType)focusRingType;
+- (void)setFocusRingType:(NSFocusRingType)type;
+#endif
 
 //
 // Setting the NSCell's State 
@@ -242,7 +262,7 @@ enum {
 - (void)setWraps:(BOOL)flag;
 - (BOOL)wraps;
 - (NSText *)setUpFieldEditorAttributes:(NSText *)textObject;
-#ifndef STRICT_OPENSTEP
+#if OS_API_VERSION(GS_API_MACOSX, GS_API_LATEST)
 - (void)setAttributedStringValue:(NSAttributedString *)attribStr;
 - (NSAttributedString *)attributedStringValue;
 - (void)setAllowsEditingTextAttributes:(BOOL)flag;
@@ -252,6 +272,12 @@ enum {
 - (void)setTitle:(NSString *)aString;
 - (NSString *)title;
 #endif
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_4, GS_API_LATEST)
+- (NSWritingDirection)baseWritingDirection;
+- (void)setBaseWritingDirection:(NSWritingDirection)direction;
+- (NSLineBreakMode)lineBreakMode;
+- (void)setLineBreakMode:(NSLineBreakMode)mode;
+#endif
 
 //
 // Target and Action 
@@ -279,7 +305,7 @@ enum {
 //
 // Formatting Data and Validating Input 
 //
-#ifndef STRICT_OPENSTEP
+#if OS_API_VERSION(GS_API_MACOSX, GS_API_LATEST)
 - (void)setFormatter:(NSFormatter *)newFormatter;
 - (id)formatter;
 #endif
@@ -293,7 +319,7 @@ enum {
 //
 // Menu
 //
-#ifndef STRICT_OPENSTEP
+#if OS_API_VERSION(GS_API_MACOSX, GS_API_LATEST)
 - (void)setMenu:(NSMenu *)aMenu;
 - (NSMenu *)menu;
 - (NSMenu *)menuForEvent:(NSEvent *)anEvent 
@@ -318,7 +344,7 @@ enum {
 // interface so methods referring to mnemonics do nothing -- they are
 // provided for compatibility only; please use key equivalents instead
 // in your GNUstep programs.
-#ifndef STRICT_OPENSTEP
+#if OS_API_VERSION(GS_API_MACOSX, GS_API_LATEST)
 - (BOOL)acceptsFirstResponder;
 - (void)setShowsFirstResponder:(BOOL)flag;
 - (BOOL)showsFirstResponder;
@@ -391,7 +417,7 @@ enum {
 - (NSRect)drawingRectForBounds:(NSRect)theRect;
 - (NSRect)imageRectForBounds:(NSRect)theRect;
 - (NSRect)titleRectForBounds:(NSRect)theRect;
-#ifndef STRICT_OPENSTEP
+#if OS_API_VERSION(GS_API_MACOSX, GS_API_LATEST)
 - (void)setControlSize:(NSControlSize)controlSize;
 - (NSControlSize)controlSize;
 #endif
@@ -408,7 +434,7 @@ enum {
 	withFrame:(NSRect)cellFrame
 	   inView:(NSView *)controlView;
 - (BOOL)isHighlighted;
-#ifndef STRICT_OPENSTEP
+#if OS_API_VERSION(GS_API_MACOSX, GS_API_LATEST)
 - (void)setHighlighted: (BOOL) flag;
 - (NSColor*)highlightColorWithFrame:(NSRect)cellFrame
 			     inView:(NSView *)controlView;
@@ -431,10 +457,14 @@ enum {
 		  start:(int)selStart	 
 		 length:(int)selLength;
 - (void)endEditing:(NSText *)textObject;
-#ifndef STRICT_OPENSTEP
+#if OS_API_VERSION(GS_API_MACOSX, GS_API_LATEST)
 - (BOOL)sendsActionOnEndEditing;
 - (void)setSendsActionOnEndEditing:(BOOL)flag;
 #endif
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_4, GS_API_LATEST)
+- (BOOL)allowsUndo;
+- (void)setAllowsUndo:(BOOL)flag;
+#endif
 
 @end
 
