@@ -23,11 +23,13 @@
    You should have received a copy of the GNU Library General Public
    License along with this library; see the file COPYING.LIB.
    If not, write to the Free Software Foundation,
-   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+   51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */ 
 
 #ifndef _GNUstep_H_NSColor
 #define _GNUstep_H_NSColor
+#import <GNUstepBase/GSVersionMacros.h>
 
 #include <Foundation/NSCoder.h>
 #include <AppKit/AppKitDefines.h>
@@ -39,9 +41,9 @@
 
 typedef enum _NSControlTint {
     NSDefaultControlTint,
-    NSClearControlTint,
     NSBlueControlTint,
-    NSGraphiteControlTint
+    NSGraphiteControlTint = 6,
+    NSClearControlTint
 } NSControlTint;
 
 typedef enum _NSControlSize {
@@ -186,7 +188,7 @@ typedef enum _NSControlSize {
 - (void)drawSwatchInRect:(NSRect)rect;
 - (void)set;
 
-#ifndef	STRICT_OPENSTEP
+#if OS_API_VERSION(GS_API_MACOSX, GS_API_LATEST)
 //
 // Changing the color
 //
@@ -241,7 +243,7 @@ typedef enum _NSControlSize {
 
 APPKIT_EXPORT NSString	*NSSystemColorsDidChangeNotification;
 
-#ifndef	STRICT_MACOS_X
+#if OS_API_VERSION(GS_API_NONE, GS_API_NONE)
 @interface NSCoder (NSCoderAdditions)
 
 //
