@@ -22,11 +22,13 @@
 
    You should have received a copy of the GNU Library General Public
    License along with this library; if not, write to the Free
-   Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111 USA.
+   Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02111 USA.
 */ 
 
 #ifndef _GNUstep_H_NSColorPicking
 #define _GNUstep_H_NSColorPicking
+#import <GNUstepBase/GSVersionMacros.h>
 
 #include <objc/Protocol.h>
 
