@@ -23,11 +23,13 @@
    You should have received a copy of the GNU Library General Public
    License along with this library; see the file COPYING.LIB.
    If not, write to the Free Software Foundation,
-   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+   51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */ 
 
 #ifndef _GNUstep_H_NSDrawer
 #define _GNUstep_H_NSDrawer
+#import <GNUstepBase/GSVersionMacros.h>
 
 #include <Foundation/NSGeometry.h>
 #include <AppKit/NSResponder.h>
@@ -47,8 +49,7 @@ enum {
 {
   // Attributes
   id _delegate;
-  NSView *_contentView;
-  NSWindow *_parentWindow;
+  id _drawerWindow;
   NSRectEdge _preferredEdge;
   NSRectEdge _currentEdge;
   NSSize _maxContentSize;
