@@ -23,11 +23,13 @@
    You should have received a copy of the GNU Library General Public
    License along with this library; see the file COPYING.LIB.
    If not, write to the Free Software Foundation,
-   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+   51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */ 
 
 #ifndef _GNUstep_H_NSFormCell
 #define _GNUstep_H_NSFormCell
+#import <GNUstepBase/GSVersionMacros.h>
 
 #include <AppKit/NSActionCell.h>
 
@@ -57,7 +59,7 @@
 - (float)titleWidth;
 - (float)titleWidth:(NSSize)aSize;
 
-#ifndef	STRICT_OPENSTEP
+#if OS_API_VERSION(GS_API_MACOSX, GS_API_LATEST)
 //
 // Attributed title
 //
