@@ -23,13 +23,16 @@
    You should have received a copy of the GNU Library General Public
    License along with this library; see the file COPYING.LIB.
    If not, write to the Free Software Foundation,
-   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+   51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */ 
 
-#ifndef	STRICT_MACOS_X
 
 #ifndef _GNUstep_H_NSHelpPanel
 #define _GNUstep_H_NSHelpPanel
+#import <GNUstepBase/GSVersionMacros.h>
+
+#if	OS_API_VERSION(GS_API_OPENSTEP,GS_API_MACOSX) || GS_API_VERSION(GS_API_NONE, GS_API_LATEST)
 
 #include <AppKit/NSApplication.h>
 #include <AppKit/NSPanel.h>
@@ -48,46 +51,46 @@
 //
 // Accessing the Help Panel
 //
-+ (NSHelpPanel *)sharedHelpPanel;
-+ (NSHelpPanel *)sharedHelpPanelWithDirectory:(NSString *)helpDirectory;
++ (NSHelpPanel *) sharedHelpPanel;
++ (NSHelpPanel *) sharedHelpPanelWithDirectory: (NSString *)helpDirectory;
 
 //
 // Managing the Contents
 //
-+ (void)setHelpDirectory:(NSString *)helpDirectory;
-- (void)addSupplement:(NSString *)helpDirectory
-	       inPath:(NSString *)supplementPath;
-- (NSString *)helpDirectory;
-- (NSString *)helpFile;
++ (void) setHelpDirectory: (NSString *)helpDirectory;
+- (void) addSupplement: (NSString *)helpDirectory
+	        inPath: (NSString *)supplementPath;
+- (NSString *) helpDirectory;
+- (NSString *) helpFile;
 
 //
 // Attaching Help to Objects 
 //
-+ (void)attachHelpFile:(NSString *)filename
-	    markerName:(NSString *)markerName
-		    to:(id)anObject;
-+ (void)detachHelpFrom:(id)anObject;
++ (void) attachHelpFile: (NSString *)filename
+	     markerName: (NSString *)markerName
+		     to: (id)anObject;
++ (void) detachHelpFrom: (id)anObject;
 
 //
 // Showing Help 
 //
-- (void)showFile:(NSString *)filename
-	atMarker:(NSString *)markerName;
-- (BOOL)showHelpAttachedTo:(id)anObject;
+- (void) showFile: (NSString *)filename
+	 atMarker: (NSString *)markerName;
+- (BOOL) showHelpAttachedTo: (id)anObject;
 
 //
 // Printing 
 //
-- (void)print:(id)sender;
+- (void) print: (id)sender;
 
 //
 // NSCoding protocol
 //
-- (void)encodeWithCoder: (NSCoder *)aCoder;
-- initWithCoder: (NSCoder *)aDecoder;
+- (void) encodeWithCoder: (NSCoder *)aCoder;
+- (id) initWithCoder: (NSCoder *)aDecoder;
 
 @end
 
+#endif // !GS_API_MACOSX
 #endif // _GNUstep_H_NSHelpPanel
-#endif // STRICT_MACOS_X
 
