@@ -23,11 +23,13 @@
    You should have received a copy of the GNU Library General Public
    License along with this library; see the file COPYING.LIB.
    If not, write to the Free Software Foundation,
-   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+   51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */ 
 
 #ifndef _GNUstep_H_NSImageRep
 #define _GNUstep_H_NSImageRep
+#import <GNUstepBase/GSVersionMacros.h>
 
 #include <Foundation/NSGeometry.h>
 #include <AppKit/AppKitDefines.h>
@@ -57,11 +59,17 @@ enum {
 //
 // Creating an NSImageRep
 //
+/** Returns a NSImageRep with the contents of filename.
+ */
 + (id)imageRepWithContentsOfFile:(NSString *)filename;
+
+/** Returns an array of newly allocated NSImageRep objects with the
+ *  contents of filename.
+ */
 + (NSArray *)imageRepsWithContentsOfFile:(NSString *)filename;
 + (id)imageRepWithPasteboard:(NSPasteboard *)pasteboard;
 + (NSArray *)imageRepsWithPasteboard:(NSPasteboard *)pasteboard;
-#ifndef STRICT_OPENSTEP
+#if OS_API_VERSION(GS_API_MACOSX, GS_API_LATEST)
 + (id)imageRepWithContentsOfURL:(NSURL *)anURL;
 + (NSArray *)imageRepsWithContentsOfURL:(NSURL *)anURL;
 #endif
@@ -69,22 +77,49 @@ enum {
 //
 // Checking Data Types 
 //
+/** Returns NO.  It is the subclass' responsibility to implement this method.
+ *  <p>See Also:</p>
+ *  <list>
+ *   <item>[NSBitmapImageRep+canInitWithData:]</item>
+ *  </list>
+ */
 + (BOOL)canInitWithData:(NSData *)data;
 + (BOOL)canInitWithPasteboard:(NSPasteboard *)pasteboard;
+
+/** Returns array produced by calling -imageUnfilteredFileTypes.
+ */
 + (NSArray *)imageFileTypes;
 + (NSArray *)imagePasteboardTypes;
+
+/** Returns nil.  It is the subclass' responsibility to implement this method.
+ *  <p>See Also:</p>
+ *  <list>
+ *   <item>[NSBitmapImageRep+imageUnfilteredFileTypes]</item>
+ *  </list>
+ */ 
 + (NSArray *)imageUnfilteredFileTypes;
 + (NSArray *)imageUnfilteredPasteboardTypes;
 
 //
 // Setting the Size of the Image 
 //
+/** Sets the size of the image to aSize.
+ */
 - (void)setSize:(NSSize)aSize;
+
+/** Returns the size of the image.
+ */
 - (NSSize)size;
 
 //
 // Specifying Information about the Representation 
 //
+/** Returns the bits per sample of the receiver.
+ *  <p>See Also:</p>
+ *  <list>
+ *   <item>-setBitsPerSample:</item>
+ *  </list>
+ */
 - (int)bitsPerSample;
 - (NSString *)colorSpaceName;
 - (BOOL)hasAlpha;
@@ -92,6 +127,13 @@ enum {
 - (int)pixelsHigh;
 - (int)pixelsWide;
 - (void)setAlpha:(BOOL)flag;
+
+/** Sets the number of bits for each component of a pixel.
+ *  <p>See Also:</p>
+ *  <list>
+ *   <item>-bitsPerSample</item>
+ *  </list>
+ */
 - (void)setBitsPerSample:(int)anInt;
 - (void)setColorSpaceName:(NSString *)aString;
 - (void)setOpaque:(BOOL)flag;
