@@ -21,11 +21,13 @@
    You should have received a copy of the GNU Library General Public
    License along with this library; see the file COPYING.LIB.
    If not, write to the Free Software Foundation,
-   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+   51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */ 
 
 #ifndef _GNUstep_H_NSInputManager
 #define _GNUstep_H_NSInputManager
+#import <GNUstepBase/GSVersionMacros.h>
 
 #include <objc/Protocol.h>
 #include <objc/objc.h>
