@@ -26,14 +26,17 @@
    You should have received a copy of the GNU Library General Public
    License along with this library; see the file COPYING.LIB.
    If not, write to the Free Software Foundation,
-   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+   51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */ 
 
 #ifndef _GNUstep_H_NSMenuItem
 #define _GNUstep_H_NSMenuItem
+#import <GNUstepBase/GSVersionMacros.h>
 
 #include <Foundation/NSObject.h>
 
+@class NSAttributedString;
 @class NSString;
 
 @class NSMenu;
@@ -74,6 +77,15 @@
  */
 - (SEL) action;
 
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_3, GS_API_LATEST)
+/**
+   <p>
+   Returns the menu item's title as an attributed string.
+   </p>
+ */
+- (NSAttributedString *)attributedTitle;
+#endif
+
 /**
    <p>
    Returns a boolean indicating if the receiver has a sub menu.
@@ -88,6 +100,15 @@
  */
 - (NSImage*) image;
 
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_3, GS_API_LATEST)
+/**
+   <p>
+   Returns the indentation level, a number between 0 and 15.
+   </p>
+ */
+- (int)indentationLevel;
+#endif
+
 /**
    <p>
    Initializes the receiver with <var>aString</var> as the title.
@@ -100,6 +121,10 @@
 	      action: (SEL)aSelector
        keyEquivalent: (NSString*)charCode;
 
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_3, GS_API_LATEST)
+- (BOOL)isAlternate;
+#endif
+
 /**
    <p>
    Returns <code>YES</code> if the receiver is enabled.
@@ -172,6 +197,12 @@
  */
 - (void) setAction: (SEL)aSelector;
 
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_3, GS_API_LATEST)
+- (void) setAlternate: (BOOL)isAlternate;
+
+-(void) setAttributedTitle: (NSAttributedString *)title;
+#endif
+
 /**
    <p>
    Set the receiver to be enabled.
@@ -186,6 +217,10 @@
  */
 - (void) setImage: (NSImage*)menuImage;
 
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_3, GS_API_LATEST)
+- (void)setIndentationLevel: (int)level;
+#endif
+
 /**
    <p>
    Sets the key equivalent of the receiver.
@@ -274,6 +309,10 @@
 - (void) setTitle: (NSString*)aString;
 - (void) setTitleWithMnemonic: (NSString*)stringWithAmpersand;
 
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_3, GS_API_LATEST)
+- (void) setToolTip: (NSString *)toolTip;
+#endif
+
 /**
    <p>
    Returns the state of the receiver.
@@ -308,6 +347,10 @@
  */
 - (NSString*) title;
 
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_3, GS_API_LATEST)
+- (NSString *) toolTip;
+#endif
+
 /**
    <p>
    Returns the user defined key equivalent modifier.
@@ -332,7 +375,6 @@
   unsigned int _keyEquivalentModifierMask;
   unsigned _mnemonicLocation;
   int _state;
-  BOOL _enabled;
   NSImage *_image;
   NSImage *_onStateImage;
   NSImage *_offStateImage;
@@ -342,12 +384,16 @@
   int _tag;
   id _representedObject;
   NSMenu *_submenu;
+  BOOL _enabled;
   BOOL _changesState;
+  BOOL _isAlternate;
+  char _indentation; // 0..15
+  NSString *_toolTip;
 }
 
 @end
 
-#ifndef	NO_GNUSTEP
+#if OS_API_VERSION(GS_API_NONE, GS_API_NONE)
 @interface NSMenuItem (GNUstepExtra)
 - (void) setChangesState: (BOOL)flag;
 - (BOOL) changesState;
