@@ -20,11 +20,13 @@
 
    You should have received a copy of the GNU Library General Public
    License along with this library; if not, write to the Free
-   Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111 USA.
+   Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02111 USA.
 */ 
 
 #ifndef _GNUstep_H_NSNibConnector
 #define _GNUstep_H_NSNibConnector
+#import <GNUstepBase/GSVersionMacros.h>
 
 #ifndef GNUSTEP
 #include <Foundation/Foundation.h>
