@@ -19,11 +19,13 @@
    
    You should have received a copy of the GNU Library General Public
    License along with this library; if not, write to the Free
-   Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111 USA.
+   Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02111 USA.
    */
 
 #ifndef _NSOpenGLView_h
 #define _NSOpenGLView_h
+#import <GNUstepBase/GSVersionMacros.h>
 
 #include <AppKit/NSView.h>
 
