@@ -30,11 +30,13 @@
    You should have received a copy of the GNU Library General Public
    License along with this library; see the file COPYING.LIB.
    If not, write to the Free Software Foundation,
-   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+   51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */ 
 
 #ifndef _GNUstep_H_NSOpenPanel
 #define _GNUstep_H_NSOpenPanel
+#import <GNUstepBase/GSVersionMacros.h>
 
 #include <AppKit/NSSavePanel.h>
 
@@ -56,7 +58,7 @@
                         file: (NSString *)name
                        types: (NSArray *)fileTypes;
 
-#ifndef	STRICT_OPENSTEP
+#if OS_API_VERSION(GS_API_MACOSX, GS_API_LATEST)
 - (int) runModalForDirectory: (NSString *)path
 			file: (NSString *)name
 		       types: (NSArray *)fileTypes
@@ -72,7 +74,7 @@
 
 - (NSArray *) filenames;
 
-#ifndef	STRICT_OPENSTEP
+#if OS_API_VERSION(GS_API_MACOSX, GS_API_LATEST)
 - (NSArray *) URLs; 
 #endif
 
@@ -81,7 +83,7 @@
 - (BOOL) canChooseFiles;
 - (void) setCanChooseDirectories: (BOOL)flag;
 - (void) setCanChooseFiles: (BOOL)flag;
-#ifndef	STRICT_OPENSTEP
+#if OS_API_VERSION(GS_API_MACOSX, GS_API_LATEST)
 - (void) setResolvesAliases: (BOOL)flag; 
 - (BOOL) resolvesAliases; 
 #endif
