@@ -23,11 +23,13 @@
    You should have received a copy of the GNU Library General Public
    License along with this library; see the file COPYING.LIB.
    If not, write to the Free Software Foundation,
-   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+   51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */ 
 
 #ifndef _GNUstep_H_NSOutlineView
 #define _GNUstep_H_NSOutlineView
+#import <GNUstepBase/GSVersionMacros.h>
 
 #include <AppKit/NSTableView.h>
 #include <Foundation/NSMapTable.h>
@@ -40,7 +42,7 @@
   NSMapTable *_itemDict;
   NSMutableArray *_items;
   NSMutableArray *_expandedItems;
-  NSMutableArray *_selectedItems;
+  NSMutableArray *_selectedItems; /* No longer in use */
   NSMapTable *_levelOfItems;
   BOOL _autoResizesOutlineColumn;
   BOOL _indentationMarkerFollowsCell;
@@ -82,8 +84,8 @@
  */
 @interface NSObject (NSOutlineViewDataSource)
 /**
- * Returns whether or not the outline view should accept a drop 
- * into the indicated item.
+ * Called to perform drop operation and returns YES if successful,
+ * and NO otherwise.
  */
 - (BOOL)outlineView: (NSOutlineView *)outlineView 
          acceptDrop: (id <NSDraggingInfo>)info 
@@ -139,8 +141,8 @@ persistentObjectForItem: (id)item;
              byItem: (id)item;
 
 /**
- * Used by the Drag and Drop system.  Returns the drap operations which was performed on the
- * given outline view.
+ * Used by the Drag and Drop system.  Returns the drag operation which should
+ * be used when -outlineView:acceptDrop:item:childIndex: is called.
  */
 - (NSDragOperation)outlineView: (NSOutlineView*)outlineView 
                   validateDrop: (id <NSDraggingInfo>)info 
