@@ -26,7 +26,8 @@
    You should have received a copy of the GNU Library General Public
    License along with this library; see the file COPYING.LIB.
    If not, write to the Free Software Foundation,
-   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+   51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 
 */ 
 
@@ -90,7 +91,7 @@ enum {
 // Running the Panel 
 //
 - (int) runModal;
-#ifndef STRICT_OPENSTEP
+#if OS_API_VERSION(GS_API_MACOSX, GS_API_LATEST)
 - (void) beginSheetWithPrintInfo: (NSPrintInfo *)printInfo 
                   modalForWindow: (NSWindow *)docWindow 
                         delegate: (id)delegate 
