@@ -27,11 +27,13 @@
    You should have received a copy of the GNU Library General Public
    License along with this library; see the file COPYING.LIB.
    If not, write to the Free Software Foundation,
-   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+   51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */ 
 
 #ifndef _GNUstep_H_NSScreen
 #define _GNUstep_H_NSScreen
+#import <GNUstepBase/GSVersionMacros.h>
 
 #include <Foundation/NSObject.h>
 #include <AppKit/NSGraphics.h>
@@ -63,11 +65,11 @@
 - (NSRect) frame;
 - (NSDictionary*) deviceDescription;
 
-#ifndef STRICT_OPENSTEP
+#if OS_API_VERSION(GS_API_MACOSX, GS_API_LATEST)
 - (const NSWindowDepth*) supportedWindowDepths;
 - (NSRect) visibleFrame;
 #endif
-#ifndef NO_GNUSTEP
+#if OS_API_VERSION(GS_API_NONE, GS_API_NONE)
 - (int) screenNumber;
 #endif
 
