@@ -23,11 +23,13 @@
 
    You should have received a copy of the GNU Library General Public
    License along with this library; if not, write to the Free
-   Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111 USA.
+   Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02111 USA.
 */
 
 #ifndef _GNUstep_H_NSScrollView
 #define _GNUstep_H_NSScrollView
+#import <GNUstepBase/GSVersionMacros.h>
 
 #include <AppKit/NSView.h>
 
@@ -39,11 +41,13 @@
 
 @interface NSScrollView : NSView
 {
-  NSClipView* _contentView;
-  NSScroller* _horizScroller;
-  NSScroller* _vertScroller;
-  NSRulerView* _horizRuler;
-  NSRulerView* _vertRuler;
+  NSClipView *_contentView;
+  NSScroller *_horizScroller;
+  NSScroller *_vertScroller;
+  NSRulerView *_horizRuler;
+  NSRulerView *_vertRuler;
+  NSClipView *_headerClipView;
+  NSView *_cornerView;
   float _hLineScroll;
   float _hPageScroll;
   float _vLineScroll;
@@ -58,8 +62,7 @@
   BOOL _knobMoved;
   BOOL _hasHeaderView;
   BOOL _hasCornerView;
-  NSClipView *_headerClipView;
-  NSView *_cornerView;
+  BOOL _autohidesScrollers;
 }
 
 /* Calculating layout */
@@ -121,7 +124,7 @@
 - (float)pageScroll;
 - (void)setScrollsDynamically:(BOOL)flag;
 - (BOOL)scrollsDynamically;
-#ifndef	STRICT_OPENSTEP
+#if OS_API_VERSION(GS_API_MACOSX, GS_API_LATEST)
 - (float) horizontalLineScroll;
 - (float) horizontalPageScroll;
 - (float) verticalLineScroll;
@@ -134,6 +137,10 @@
 - (void)setDrawsBackground:(BOOL)flag;
 - (BOOL)drawsBackground;
 #endif
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_3, GS_API_LATEST)
+- (BOOL)autohidesScrollers;
+- (void)setAutohidesScrollers:(BOOL)flag;
+#endif
 
 /* Updating display after scrolling */
 - (void)reflectScrolledClipView:(NSClipView*)aClipView;
@@ -141,8 +148,6 @@
 /* Arranging components */
 - (void)tile;
 
-/* GNUstep private methods */
-- (void)_synchronizeHeaderAndCornerView;
 @end
 
 #endif /* _GNUstep_H_NSScrollView */
