@@ -20,7 +20,8 @@
 
    You should have received a copy of the GNU Library General Public
    License along with this library; if not, write to the Free
-   Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111 USA.
+   Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02111 USA.
 */
 
 #ifndef _GNUstep_H_NSSliderCell
@@ -92,7 +93,7 @@ typedef enum _NSTickMarkPosition
 - (void) setMinValue: (double)aDouble;
 - (void) setMaxValue: (double)aDouble;
 
-#ifndef	STRICT_OPENSTEP
+#if OS_API_VERSION(GS_API_MACOSX, GS_API_LATEST)
 // ticks
 - (BOOL) allowsTickMarkValuesOnly;
 - (double) closestTickMarkValueToValue: (double)aValue;
