@@ -21,7 +21,8 @@
    You should have received a copy of the GNU Library General Public
    License along with this library; see the file COPYING.LIB.
    If not, write to the Free Software Foundation,
-   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+   51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */
 
 #ifndef _GNUstep_H_NSTabView
@@ -33,12 +34,12 @@
 
 typedef enum {
   NSTopTabsBezelBorder, 
+  NSLeftTabsBezelBorder,
   NSBottomTabsBezelBorder, 
+  NSRightTabsBezelBorder,
   NSNoTabsBezelBorder,
   NSNoTabsLineBorder,
-  NSNoTabsNoBorder,
-  NSLeftTabsBezelBorder,
-  NSRightTabsBezelBorder
+  NSNoTabsNoBorder
 } NSTabViewType;
 
 @class NSFont;
@@ -96,7 +97,7 @@ typedef enum {
 
 - (NSTabViewItem *)tabViewItemAtPoint:(NSPoint)point;
 
-#ifndef STRICT_OPENSTEP
+#if OS_API_VERSION(GS_API_MACOSX, GS_API_LATEST)
 - (NSControlSize)controlSize;
 - (NSControlTint)controlTint;
 - (void)setControlSize:(NSControlSize)controlSize;
