@@ -26,7 +26,8 @@
    You should have received a copy of the GNU Library General Public
    License along with this library; see the file COPYING.LIB.
    If not, write to the Free Software Foundation,
-   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+   51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */
 
 #ifndef _GNUstep_H_NSView
@@ -35,10 +36,11 @@
 #include <AppKit/NSGraphicsContext.h>
 #include <AppKit/NSResponder.h>
 
-@class NSString;
 @class NSArray;
-@class NSMutableArray;
+@class NSAttributedString;
 @class NSData;
+@class NSMutableArray;
+@class NSString;
 
 @class NSWindow;
 @class NSPasteboard;
@@ -52,10 +54,14 @@
 typedef int NSTrackingRectTag;
 typedef int NSToolTipTag;
 
-/*
- * constants representing the four types of borders that
- * can appear around an NSView
- */
+/** Describes the type of border used by an NSView.
+  <list>
+   <item>NSNoBorder</item>
+   <item>NSLineBorder</item>
+   <item>NSBezelBorder</item>
+   <item>NSGrooveBorder</item>
+  </list>
+*/
 typedef enum _NSBorderType {
   NSNoBorder,
   NSLineBorder,
@@ -103,8 +109,33 @@ typedef enum _NSFocusRingType {
   NSMutableArray *_cursor_rects;
   NSRect _invalidRect;
   NSRect _visibleRect;
-  unsigned int _autoresizingMask;
   int _gstate;
+  void *_nextKeyView;
+  void *_previousKeyView;
+
+@public
+  /*
+   * Flags for internal use by NSView and it's subclasses.
+   */
+  struct _rFlagsType {
+    /*
+     * 'flipped_view' is set in NSViews designated initialiser (and other
+     * methods that create views) to be the value returned by [-isFlipped]
+     * This caching assumes that the value returned by [-isFlipped] will
+     * not change during the views lifetime - if it does, the view must
+     * be sure to change the flag accordingly.
+     */
+    unsigned	flipped_view:1;
+    unsigned	has_subviews:1;		/* The view has subviews.	*/
+    unsigned	has_currects:1;		/* The view has cursor rects.	*/
+    unsigned	has_trkrects:1;		/* The view has tracking rects.	*/
+    unsigned	has_draginfo:1;		/* View has drag types. 	*/
+    unsigned	opaque_view:1;		/* For views whose opacity may	*/
+					/* change to keep track of it.	*/
+    unsigned	valid_rects:1;		/* Some cursor rects may be ok.	*/
+    unsigned	needs_display:1;	/* view needs display.   	*/
+    unsigned	has_tooltips:1;		/* The view has tooltips set.	*/
+  } _rFlags;
 
   BOOL _is_rotated_from_base;
   BOOL _is_rotated_or_scaled_from_base;
@@ -117,10 +148,8 @@ typedef enum _NSFocusRingType {
   BOOL _is_hidden;
   BOOL _in_live_resize;
 
+  unsigned int _autoresizingMask;
   NSFocusRingType _focusRingType;
-
-  void *_nextKeyView;
-  void *_previousKeyView;
 }
 
 /*
@@ -140,7 +169,7 @@ typedef enum _NSFocusRingType {
 - (NSView*) opaqueAncestor;
 - (void) removeFromSuperviewWithoutNeedingDisplay;
 - (void) removeFromSuperview;
-#ifndef	NO_GNUSTEP
+#if OS_API_VERSION(GS_API_NONE, GS_API_NONE)
 - (void) removeSubview: (NSView*)aView;
 #endif
 - (void) replaceSubview: (NSView*)oldView
@@ -152,7 +181,7 @@ typedef enum _NSFocusRingType {
 - (NSWindow*) window;
 - (void) viewWillMoveToSuperview: (NSView*)newSuper;
 - (void) viewWillMoveToWindow: (NSWindow*)newWindow;
-#ifndef STRICT_OPENSTEP
+#if OS_API_VERSION(GS_API_MACOSX, GS_API_LATEST)
 - (void) didAddSubview: (NSView *)subview;
 - (void) viewDidMoveToSuperview;
 - (void) viewDidMoveToWindow;
@@ -234,10 +263,13 @@ typedef enum _NSFocusRingType {
 + (NSView*) focusView;
 - (void) lockFocus;
 - (void) unlockFocus;
-#ifndef STRICT_OPENSTEP
+#if OS_API_VERSION(GS_API_MACOSX, GS_API_LATEST)
 - (BOOL) lockFocusIfCanDraw;
 - (void) lockFocusInRect: (NSRect)rect;
 #endif
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_4, GS_API_LATEST)
+- (BOOL) lockFocusIfCanDrawInContext: (NSGraphicsContext *)context;
+#endif
 
 /*
  * Displaying
@@ -253,7 +285,7 @@ typedef enum _NSFocusRingType {
 - (void) setNeedsDisplay: (BOOL)flag;
 - (void) setNeedsDisplayInRect: (NSRect)invalidRect;
 - (BOOL) isOpaque;
-#ifndef STRICT_OPENSTEP
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_3, GS_API_LATEST)
 + (NSFocusRingType) defaultFocusRingType;
 - (void) setKeyboardFocusRingNeedsDisplayInRect: (NSRect)rect;
 - (void) setFocusRingType: (NSFocusRingType)focusRingType;
@@ -271,7 +303,7 @@ typedef enum _NSFocusRingType {
 - (NSRect) visibleRect;
 - (BOOL) canDraw;
 - (BOOL) shouldDrawColor;
-#ifndef STRICT_OPENSTEP
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_3, GS_API_LATEST)
 - (BOOL) wantsDefaultClipping;
 - (BOOL) needsToDrawRect: (NSRect)aRect;
 - (void) getRectsBeingDrawn: (const NSRect **)rects count: (int *)count;
@@ -283,6 +315,12 @@ typedef enum _NSFocusRingType {
 - (void) viewWillStartLiveResize;
 - (void) viewDidEndLiveResize;
 #endif
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_4, GS_API_LATEST)
+- (BOOL) preservesContentDuringLiveResize;
+- (void) getRectsExposedDuringLiveResize: (NSRect[4])exposedRects count: (int *)count;
+- (NSRect) rectPreservedDuringLiveResize;
+#endif
+
 
 /*
  * Graphics State Objects
@@ -298,7 +336,7 @@ typedef enum _NSFocusRingType {
 - (BOOL) mouse: (NSPoint)aPoint
 	inRect: (NSRect)aRect;
 - (BOOL) performKeyEquivalent: (NSEvent*)theEvent;
-#ifndef STRICT_OPENSTEP
+#if OS_API_VERSION(GS_API_MACOSX, GS_API_LATEST)
 - (BOOL) performMnemonic: (NSString *)aString;
 - (BOOL) mouseDownCanMoveWindow;
 #endif
@@ -320,7 +358,7 @@ typedef enum _NSFocusRingType {
 - (void) registerForDraggedTypes: (NSArray*)newTypes;
 - (void) unregisterDraggedTypes;
 - (BOOL) shouldDelayWindowOrderingForEvent: (NSEvent*)anEvent;
-#ifndef STRICT_OPENSTEP
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_2, GS_API_LATEST)
 - (BOOL) dragPromisedFilesOfTypes: (NSArray *)typeArray
                          fromRect: (NSRect)aRect
                            source: (id)sourceObject 
@@ -328,17 +366,44 @@ typedef enum _NSFocusRingType {
                             event: (NSEvent *)theEvent;
 #endif
 
-/*
- * Managing the Cursor
+/**
+ * Adds a cursor rectangle.  This provides for automatic update of the
+ * cursor to be anObject while the mouse is in aRect.<br />
+ * The cursor (anObject) is retained until the cursor rectangle is
+ * removed or discarded.<br />
+ * Generally your subviews should call this in their implementation of
+ * the -resetCursorRects method.<br />
+ * It is your responsibility to ensure that aRect lies within your veiw's
+ * visible rectangle.
  */
 - (void) addCursorRect: (NSRect)aRect
 		cursor: (NSCursor*)anObject;
+
+/**
+ * Removes all the cursor rectancles which have been set up for the
+ * receiver.  This is equivalent to calling -removeCursorRect:cursor:
+ * for all cursor rectangles which have been set up.<br />
+ * This is called automatically before the system calls -resetCursorRects
+ * so you never need to call it.
+ */
 - (void) discardCursorRects;
+
+/**
+ * Removes the cursor rectangle which was set up for the specified
+ * rectangle and cursor.
+ */
 - (void) removeCursorRect: (NSRect)aRect
 		   cursor: (NSCursor*)anObject;
+
+/** <override-subclass/>
+ * This is called to establish a new set of cursor rectangles whenever
+ * the receiver needs to do so (eg the view has been resized).  The default
+ * implementation does nothing, but subclasses should use it to make
+ * calls to -addCursorRect:cursor: to establish their new cursor rectangles.
+ */
 - (void) resetCursorRects;
 
-#ifndef STRICT_OPENSTEP
+#if OS_API_VERSION(GS_API_MACOSX, GS_API_LATEST)
 /*
  * Tool Tips
  */
@@ -351,10 +416,26 @@ typedef enum _NSFocusRingType {
 - (NSString *) toolTip;
 #endif
 
-/*
- * Tracking rectangles
+/**
+ * Removes a tracking rectangle which was previously established using the
+ * -addTrackingRect:owner:userData:assumeInside: method.<br />
+ * The value of tag must be the value returned by the method used to add
+ * the rectangle.
  */
 - (void) removeTrackingRect: (NSTrackingRectTag)tag;
+
+/**
+ * Adds a tracking rectangle to monitor mouse movement and generate
+ * mouse-entered and mouse-exited events.<br />
+ * The event messages are sent to anObject, which is <em>not</em>
+ * retained and must therefore be sure to remove any tracking rectangles
+ * using it before it is deallocated.<br />
+ * The value of data is supplied as the user data in the event objects
+ * generated.<br />
+ * If flag is YES then the mouse is assumed to be inside the tracking
+ * rectangle and the first event generated will therefore be a mouse exit,
+ * if it is NO then the first event generated will be a mouse entry.
+ */
 - (NSTrackingRectTag) addTrackingRect: (NSRect)aRect
 				owner: (id)anObject
 			     userData: (void*)data
@@ -375,7 +456,7 @@ typedef enum _NSFocusRingType {
 - (void) scrollClipView: (NSClipView*)aClipView
 		toPoint: (NSPoint)aPoint;
 
-#ifndef STRICT_OPENSTEP
+#if OS_API_VERSION(GS_API_MACOSX, GS_API_LATEST)
 /*
  * Menu operations
  */
@@ -393,7 +474,7 @@ typedef enum _NSFocusRingType {
 - (void) setPreviousKeyView: (NSView*)aView;
 - (NSView*) previousKeyView;
 - (NSView*) previousValidKeyView;
-#ifndef STRICT_OPENSTEP
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_3, GS_API_LATEST)
 - (BOOL) canBecomeKeyView;
 #endif
 
@@ -405,7 +486,7 @@ typedef enum _NSFocusRingType {
 - (NSData*) dataWithEPSInsideRect: (NSRect)aRect;
 - (void) writeEPSInsideRect: (NSRect)rect
 	       toPasteboard: (NSPasteboard*)pasteboard;
-#ifndef STRICT_OPENSTEP
+#if OS_API_VERSION(GS_API_MACOSX, GS_API_LATEST)
 - (NSData *)dataWithPDFInsideRect:(NSRect)aRect;
 - (void)writePDFInsideRect:(NSRect)aRect 
 	      toPasteboard:(NSPasteboard *)pboard;
@@ -426,7 +507,7 @@ typedef enum _NSFocusRingType {
 - (float) heightAdjustLimit;
 - (BOOL) knowsPagesFirst: (int*)firstPageNum
 		    last: (int*)lastPageNum;
-#ifndef STRICT_OPENSTEP
+#if OS_API_VERSION(GS_API_MACOSX, GS_API_LATEST)
 - (BOOL) knowsPageRange: (NSRange*)range;
 #endif
 - (NSPoint) locationOfPrintRect: (NSRect)aRect;
@@ -460,12 +541,16 @@ typedef enum _NSFocusRingType {
 - (void) endPageSetup;
 - (void) endPage;
 - (void) endTrailer;
-#ifndef STRICT_OPENSTEP
+#if OS_API_VERSION(GS_API_MACOSX, GS_API_LATEST)
 - (void)beginDocument;
 - (void)beginPageInRect:(NSRect)aRect 
 	    atPlacement:(NSPoint)location;
 - (void)endDocument;
 #endif
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_4, GS_API_LATEST)
+- (NSAttributedString *)pageFooter;
+- (NSAttributedString *)pageHeader;
+#endif
 
 @end
 
@@ -476,7 +561,7 @@ typedef enum _NSFocusRingType {
  * GNUstep extensions
  * Methods whose names begin with an underscore must NOT be overridden.
  */
-#ifndef	NO_GNUSTEP
+#if OS_API_VERSION(GS_API_NONE, GS_API_NONE)
 @interface NSView (PrivateMethods)
 
 /*
