@@ -27,7 +27,8 @@
    You should have received a copy of the GNU Library General Public
    License along with this library; see the file COPYING.LIB.
    If not, write to the Free Software Foundation,
-   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+   51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */
 
 #ifndef _GNUstep_H_NSWindow
@@ -46,6 +47,7 @@
 @class NSMutableArray;
 @class NSNotification;
 @class NSString;
+@class NSUndoManager;
 
 @class NSButtonCell;
 @class NSColor;
@@ -101,38 +103,44 @@ typedef enum _NSSelectionDirection {
 APPKIT_EXPORT NSSize NSIconSize;
 APPKIT_EXPORT NSSize NSTokenSize;
 
+/**
+ * <p>An NSWindow instance represents a window, panel or menu on the
+ * screen.<br />
+ * Each window has a style, which determines how the window is decorated:
+ * ie whether it has a border, a title bar, a resize bar, minimise and
+ * close buttons.
+ * </p>
+ * <p>A window has a <em>frame</em>. This is the frame of the <em>entire</em>
+ * window on the screen, including all decorations and borders.  The origin
+ * of the frame represents its bottom left corner and the frame is expressed
+ * in screen coordinates (see [NSScreen]).
+ * </p>
+ * <p>When a window is created, it has a <em>private</em> [NSView] instance
+ * which fills the entire window frame and whose coordinate system is the
+ * same as the base coordinate system of the window (ie zero x and
+ * y coordinates are at the bottom left corner of the window, with increasing
+ * x and y corresponding to points to the right and above the origin).<br />
+ * This view may be used by the library internals (and theme engines) to
+ * draw window decorations if the backend library is not handling the
+ * window decorations.
+ * </p>
+ * <p>A window always contains a <em>content view</em> which is the highest
+ * level view available for public (application) use.  This view fills the
+ * area of the window inside any decoration/border.<br />
+ * This is the only part of the window that application programmers are
+ * allowed to draw in directly.
+ * </p>
+ * <p>You can convert between view coordinates and window base coordinates
+ * using the [NSView-convertPoint:fromView:], [NSView-convertPoint:toView:],
+ * [NSView-convertRect:fromView:], and [NSView-convertRect:toView:]
+ * methods with a nil view argument.<br />
+ * You can convert between window and screen coordinates using the
+ * -convertBaseToScreen: and -convertScreenToBase: methods.
+ * </p>
+ */
 @interface NSWindow : NSResponder <NSCoding>
 {
-  /*
-  A window really has three interesting frames:
-  
-  The screen frame. This is the frame of the _entire_ window on the screen,
-  including all decorations and borders (regardless of where they come from).
-  (On X, we can only guess what the screen frame is.)
-
-  The window frame. This is the frame of the backend window for this window,
-  and is thus the base of the coordinate system for the window. IOW, it's
-  the frame of the area we can draw into.
-
-  The contect rect. This is the frame of the content view.
-
-  Wrt. size, ScreenFrame >= WindowFrame >= ContentRect. When -gui doesn't
-  manage the window decorations, WindowFrame == ContentRect. When -gui does
-  manage the window decorations, WindowFrame will include the decorations,
-  and ScreenFrame == WindowFrame.
-
-
-  To get coordinate transforms and stuff right wrt. OpenStep, we really want
-  the window frame here.
-
-  For hysterical reasons, _frame used to be the screen frame. However, the
-  resulting inconsistencies caused a bunch of problems. Thus, _frame is the
-  window frame. The other rectangles/sizes passed around in NSWindow
-  methods are supposed to all be window frames.
-  */
   NSRect        _frame;
-
-
   NSSize        _minimumSize;
   NSSize        _maximumSize;
   NSSize        _increments;
@@ -199,6 +207,7 @@ APPKIT_EXPORT NSSize NSTokenSize;
     unsigned	can_hide:1;
     unsigned	has_shadow:1;
     unsigned	is_opaque:1;
+    unsigned	views_need_display:1;
     // 3 bits reserved for subclass use
     unsigned subclass_bool_one: 1;
     unsigned subclass_bool_two: 1;
@@ -219,21 +228,29 @@ APPKIT_EXPORT NSSize NSTokenSize;
  * Computing frame and content rectangles
  */
 
-/* These methods convert between the various frames discussed above. */
+/**
+ * Returns the rectangle which would be used for the content view of
+ * a window whose on-screen size and position is specified by aRect
+ * and which is decorated with the border and title etc given by aStyle.<br />
+ * Both rectangles are expressed in screen coordinates.
+ */
 + (NSRect) contentRectForFrameRect: (NSRect)aRect
 			 styleMask: (unsigned int)aStyle;
 
+/**
+ * Returns the rectangle which would be used for the on-screen frame of
+ * a window if that window had a content view occupying the rectangle aRect
+ * and was decorated with the border and title etc given by aStyle.<br />
+ * Both rectangles are expressed in screen coordinates.
+ */
 + (NSRect) frameRectForContentRect: (NSRect)aRect
 			 styleMask: (unsigned int)aStyle;
 
-+ (NSRect) screenRectForFrameRect: (NSRect)aRect
-			styleMask: (unsigned int)aStyle;
-
-+ (NSRect) frameRectForScreenRect: (NSRect)aRect
-			styleMask: (unsigned int)aStyle;
-
-/* Returns the smallest window width that will fit the given title and
-style. */
+/**
+ * Returns the smallest frame width that will fit the given title
+ * and style.  This is the on-screen width of the window including
+ * decorations.
+ */
 + (float) minFrameWidthWithTitle: (NSString *)aTitle
 		       styleMask: (unsigned int)aStyle;
 
@@ -246,31 +263,81 @@ style. */
 		   backing: (NSBackingStoreType)bufferingType
 		     defer: (BOOL)flag;
 
+/**
+ * Creates a new window with the specified characteristics.<br />
+ * The contentRect is expressed in screen coordinates (for aScreen)
+ * and the window frame is calculated from the content rectangle and
+ * the window style mask.
+ */
 - (id) initWithContentRect: (NSRect)contentRect
 		 styleMask: (unsigned int)aStyle
 		   backing: (NSBackingStoreType)bufferingType
 		     defer: (BOOL)flag
 		    screen: (NSScreen*)aScreen;
 
-/*
- * Converting coordinates
+/**
+ * Converts aPoint from the base coordinate system of the receiver
+ * to a point in the screen coordinate system.
  */
 - (NSPoint) convertBaseToScreen: (NSPoint)aPoint;
+
+/**
+ * Converts aPoint from the screen coordinate system to a point in
+ * the base coordinate system of the receiver.
+ */
 - (NSPoint) convertScreenToBase: (NSPoint)aPoint;
 
-/*
- * Moving and resizing the window
+/**
+ * Returns the frame of the receiver ... the rectangular area that the window
+ * (including any border, title, and other decorations) occupies on screen.
  */
 - (NSRect) frame;
+
+/**
+ * <p>Sets the frame for the receiver to frameRect and if flag is YES causes
+ * the window contents to be refreshed.  The value of frameRect is the
+ * desired on-screen size and position of the window including all
+ * border/decoration.
+ * </p>
+ * <p>The size of the frame is constrained to the minimum and maximum
+ * sizes set for the receiver (if any).<br />
+ * Its position is constrained to be on screen if it is a titled window.
+ * </p>
+ */
 - (void) setFrame: (NSRect)frameRect
 	  display: (BOOL)flag;
+
+/**
+ * Sets the origin (bottom left corner) of the receiver's frame to be the
+ * specified point (in screen coordinates).
+ */
 - (void) setFrameOrigin: (NSPoint)aPoint;
+
+/**
+ * Sets the top left corner of the receiver's frame to be the
+ * specified point (in screen coordinates).
+ */
 - (void) setFrameTopLeftPoint: (NSPoint)aPoint;
+
+/**
+ * Sets the size of the receiver's content view  to aSize, implicitly
+ * adjusting the size of the receiver's frame to match.
+ */
 - (void) setContentSize: (NSSize)aSize;
+
+/**
+ * Positions the receiver at topLeftPoint (or if topLeftPoint is NSZeroPoint,
+ * leaves the receiver unmoved except for any necessary constraint to fit
+ * on screen).<br />
+ * Returns the position of the top left corner of the receivers content
+ * view (after repositioning), so that another window cascaded at the
+ * returned point will not obscure the title bar of the receiver.
+ */
 - (NSPoint) cascadeTopLeftFromPoint: (NSPoint)topLeftPoint;
+
 - (void) center;
 - (int) resizeFlags;
-#ifndef STRICT_OPENSTEP
+#if OS_API_VERSION(GS_API_MACOSX, GS_API_LATEST)
 - (void) setFrame: (NSRect)frameRect
 	  display: (BOOL)displayFlag
 	  animate: (BOOL)animationFlag;
@@ -290,7 +357,7 @@ style. */
 - (void) setMaxSize: (NSSize)aSize;
 - (NSRect) constrainFrameRect: (NSRect)frameRect
 		     toScreen: (NSScreen*)screen;
-#ifndef STRICT_OPENSTEP
+#if OS_API_VERSION(GS_API_MACOSX, GS_API_LATEST)
 - (NSSize) aspectRatio;
 - (void) setAspectRatio: (NSSize)ratio;
 - (NSSize) resizeIncrements;
@@ -307,9 +374,9 @@ style. */
 - (void) setFrameFromString: (NSString*)string;
 - (BOOL) setFrameUsingName: (NSString*)name;
 - (NSString*) stringWithSavedFrame;
-#ifndef STRICT_OPENSTEP
+#if OS_API_VERSION(GS_API_MACOSX, GS_API_LATEST)
 - (BOOL) setFrameUsingName: (NSString *)name
-		    force: (BOOL)force;
+		     force: (BOOL)force;
 #endif
 
 /*
@@ -337,7 +404,7 @@ style. */
 - (void) resignKeyWindow;
 - (void) resignMainWindow;
 
-#ifndef STRICT_OPENSTEP
+#if OS_API_VERSION(GS_API_MACOSX, GS_API_LATEST)
 - (NSButtonCell*) defaultButtonCell;
 - (void) setDefaultButtonCell: (NSButtonCell*)aCell;
 - (void) disableKeyEquivalentForDefaultButtonCell;
@@ -362,7 +429,7 @@ style. */
 - (void) flushWindow;
 - (void) flushWindowIfNeeded;
 
-#ifndef STRICT_OPENSTEP
+#if OS_API_VERSION(GS_API_MACOSX, GS_API_LATEST)
 - (void) cacheImageInRect: (NSRect)aRect;
 - (void) discardCachedImage;
 - (void) restoreCachedImage;
@@ -378,6 +445,10 @@ style. */
 - (void) setBackingType: (NSBackingStoreType)type;
 - (BOOL) isOneShot;
 - (void) setOneShot: (BOOL)flag;
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_4, GS_API_LATEST)
+- (NSGraphicsContext*) graphicsContext;
+#endif
+
 
 /*
  * Screens and window depths
@@ -439,7 +510,7 @@ style. */
 - (NSText*) fieldEditor: (BOOL)createFlag
 	      forObject: (id)anObject;
 
-#ifndef STRICT_OPENSTEP
+#if OS_API_VERSION(GS_API_MACOSX, GS_API_LATEST)
 - (NSView*) initialFirstResponder;
 - (NSSelectionDirection) keyViewSelectionDirection;
 - (void) selectKeyViewFollowingView: (NSView*)aView;
@@ -481,11 +552,11 @@ style. */
 - (NSString*) miniwindowTitle;
 - (void) setMiniwindowImage: (NSImage*)image;
 - (void) setMiniwindowTitle: (NSString*)title;
-#ifndef	NO_GNUSTEP
+#if OS_API_VERSION(GS_API_NONE, GS_API_NONE)
 - (NSWindow*) counterpart;
 #endif
 
-#ifndef STRICT_OPENSTEP
+#if OS_API_VERSION(GS_API_MACOSX, GS_API_LATEST)
 + (void) menuChanged: (NSMenu*)aMenu;
 #endif
 
@@ -521,7 +592,7 @@ style. */
 - (BOOL) hidesOnDeactivate;
 - (void) setHidesOnDeactivate: (BOOL)flag;
 - (BOOL) worksWhenModal;
-#ifndef STRICT_OPENSTEP
+#if OS_API_VERSION(GS_API_MACOSX, GS_API_LATEST)
 - (void) setCanHide: (BOOL)flag;
 - (BOOL) canHide;
 #endif
@@ -534,7 +605,7 @@ style. */
 - (void) setBackgroundColor: (NSColor*)color;
 - (NSColor*) backgroundColor;
 - (unsigned int) styleMask;
-#ifndef STRICT_OPENSTEP
+#if OS_API_VERSION(GS_API_MACOSX, GS_API_LATEST)
 - (void) setHasShadow: (BOOL)hasShadow;
 - (BOOL) hasShadow;
 - (void) setAlphaValue: (float)windowAlpha;
@@ -555,8 +626,8 @@ style. */
 - (void) fax: (id)sender;
 - (void) print: (id)sender;
 - (NSData*) dataWithEPSInsideRect: (NSRect)rect;
-#ifndef STRICT_OPENSTEP
-- (NSData *)dataWithPDFInsideRect:(NSRect)aRect;
+#if OS_API_VERSION(GS_API_MACOSX, GS_API_LATEST)
+- (NSData*) dataWithPDFInsideRect:(NSRect)aRect;
 #endif
 
 /*
@@ -571,7 +642,7 @@ style. */
 - (void) setWindowController: (NSWindowController*)windowController;
 - (id) windowController;
 
-#ifndef STRICT_OPENSTEP
+#if OS_API_VERSION(GS_API_MACOSX, GS_API_LATEST)
 - (NSArray *) drawers;
 - (id) initWithWindowRef: (void *)windowRef;
 - (void *)windowRef;
@@ -579,7 +650,7 @@ style. */
 #endif
 @end
 
-#ifndef NO_GNUSTEP
+#if OS_API_VERSION(GS_API_NONE, GS_API_NONE)
 /*
  * GNUstep backend methods
  */
@@ -605,7 +676,7 @@ style. */
 @end
 #endif
 
-#ifndef NO_GNUSTEP
+#if OS_API_VERSION(GS_API_NONE, GS_API_NONE)
 @interface NSWindow (GNUstepTextView)
 /*
  * Called from NSTextView's resignFirstResponder to know which is 
@@ -622,9 +693,16 @@ style. */
 #ifdef GNUSTEP
 @interface NSObject (NSWindowDelegate)
 - (BOOL) windowShouldClose: (id)sender;
-#ifndef STRICT_OPENSTEP
+#if OS_API_VERSION(GS_API_MACOSX, GS_API_LATEST)
+- (NSRect) window: (NSWindow*)window
+willPositionSheet: (NSWindow*)sheet
+        usingRect: (NSRect)rect;
+- (void) windowDidChangeScreenProfile: (NSNotification*)aNotification;
+- (void) windowDidEndSheet: (NSNotification*)aNotification;
 - (BOOL) windowShouldZoom: (NSWindow*)sender
 		  toFrame: (NSRect)aFrame;
+- (void) windowWillBeginSheet: (NSNotification*)aNotification;
+- (NSUndoManager*) windowWillReturnUndoManager: (NSWindow*)sender;
 - (NSRect) windowWillUseStandardFrame: (NSWindow*)sender
 			 defaultFrame: (NSRect)aFrame;
 #endif
