@@ -18,7 +18,8 @@
    
    You should have received a copy of the GNU Library General Public
    License along with this library; if not, write to the Free
-   Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111 USA.
+   Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02111 USA.
    */
 
 #ifndef _PSOperators_h_INCLUDE
@@ -26,7 +27,7 @@
 
 #include <AppKit/DPSOperators.h>
 
-#ifndef NO_GNUSTEP
+#if OS_API_VERSION(GS_API_NONE, GS_API_NONE)
 #define	DEFCTXT	GSCurrentContext()
 #else
 #define	DEFCTXT	[NSGraphicsContext currentContext]
