@@ -537,7 +537,7 @@ void __dummy_GMAppKit_functionForLinking() {}
 
   [archiver encodeObject:[self documentView] withName:@"documentView"];
   [archiver encodeBOOL:[self copiesOnScroll] withName:@"copiesOnScroll"];
-  if([self respondsToSelector: @selector(drawsBackground)])
+  if ([self respondsToSelector: @selector(drawsBackground)])
     [archiver encodeBOOL:[self drawsBackground] withName:@"drawsBackground"];
   [archiver encodeObject:[self backgroundColor] withName:@"backgroundColor"];
 }
@@ -548,7 +548,7 @@ void __dummy_GMAppKit_functionForLinking() {}
 
   [self setDocumentView:[unarchiver decodeObjectWithName:@"documentView"]];
   [self setCopiesOnScroll:[unarchiver decodeBOOLWithName:@"copiesOnScroll"]];
-  if([self respondsToSelector: @selector(setDrawsBackground:)])
+  if ([self respondsToSelector: @selector(setDrawsBackground:)])
     [self setDrawsBackground:[unarchiver decodeBOOLWithName:@"drawsBackground"]];
   [self setBackgroundColor:[unarchiver decodeObjectWithName:@"backgroundColor"]];
   return self;
@@ -756,6 +756,8 @@ void __dummy_GMAppKit_functionForLinking() {}
 
 @implementation NSImage (GMArchiverMethods)
 
+extern id _nibOwner;
+
 - (void)encodeWithModelArchiver:(GMArchiver*)archiver
 {
   [archiver encodeString:[self name] withName:@"name"];
@@ -770,7 +772,16 @@ void __dummy_GMAppKit_functionForLinking() {}
   imageName = [unarchiver decodeStringWithName:@"name"];
 
   if (imageName)
+  {
     image = [NSImage imageNamed: imageName];
+    if (image == nil)
+    {
+       NSBundle *bundle = [NSBundle bundleForClass:[_nibOwner class]];
+       NSString *path = [bundle pathForImageResource:imageName];
+
+       image = [[NSImage alloc] initByReferencingFile:path];
+    }
+  }
 
   if (image == nil)
     image = [NSImage imageNamed:@"GNUstepMenuImage"];
@@ -1100,14 +1111,14 @@ void __dummy_GMAppKit_functionForLinking() {}
 - (void)encodeWithModelArchiver:(GMArchiver*)archiver
 {
   [super encodeWithModelArchiver:archiver];
-  if([self respondsToSelector: @selector(echosBullets)])
+  if ([self respondsToSelector: @selector(echosBullets)])
     [archiver encodeBOOL:[self echosBullets] withName:@"echosBullets"];
 }
 
 - (id)initWithModelUnarchiver:(GMUnarchiver*)unarchiver
 {
   self = [super initWithModelUnarchiver:unarchiver];
-  if([self respondsToSelector: @selector(setEchosBullets:)])
+  if ([self respondsToSelector: @selector(setEchosBullets:)])
     [self setEchosBullets:[unarchiver decodeBOOLWithName:@"echosBullets"]];
 
   return self;
