@@ -98,15 +98,16 @@
 {
   /* Save this for the view to look at. Seems like there should
      be a better way to pass it to beginDocument */
-  [[_printInfo dictionary] setObject: [NSValue valueWithRect: _rect]
-                              forKey: @"NSPrintSheetBounds"];
+  [[[self printInfo] dictionary] setObject: [NSValue valueWithRect: _rect]
+				 forKey: @"NSPrintSheetBounds"];
                               
   [_view beginDocument];
-  
   [_view beginPageInRect: _rect 
              atPlacement: NSMakePoint(0,0)];
              
   [_view displayRectIgnoringOpacity: _rect];
+
+  [_view endPage];
   [_view endDocument];
 }
 
@@ -123,7 +124,7 @@
 
       eps = [NSString stringWithContentsOfFile: _path];
       
-      [_data setData: [eps dataUsingEncoding:NSASCIIStringEncoding]];
+      [_data setData: [eps dataUsingEncoding: NSASCIIStringEncoding]];
     }
 
   return YES;
@@ -136,7 +137,7 @@
   if (_context)
     return _context;
 
-  info = [_printInfo dictionary];
+  info = [[self printInfo] dictionary];
   
   [info setObject: _path 
            forKey: @"NSOutputFile"];
