@@ -30,11 +30,13 @@
 #include "AppKit/NSFont.h"
 #include "AppKit/NSImage.h"
 #include "AppKit/NSTextField.h"
-#include "GNUstepGUI/GSInfoPanel.h"
 #include <Foundation/NSBundle.h>
 #include <Foundation/NSDictionary.h>
 #include <Foundation/NSString.h>
 #include <Foundation/NSProcessInfo.h>
+#include "GNUstepGUI/GSInfoPanel.h"
+#include "GNUstepGUI/GSTheme.h"
+
 
 static id
 value_from_info_plist_for_key (NSString *key)
@@ -156,7 +158,7 @@ new_label (NSString *value)
     }
 }
 
--(id) initWithDictionary: (NSDictionary *)dictionary;
+- (id) initWithDictionary: (NSDictionary *)dictionary;
 {
   /* Info to show */
   NSString *name = nil;
@@ -168,6 +170,7 @@ new_label (NSString *value)
   NSString *url = nil;
   NSString *copyright = nil;
   NSString *copyrightDescription = nil;
+  NSString *theme = nil;
 
   /* GUI Objects used to show the Info */
   NSButton *iconButton;
@@ -179,6 +182,7 @@ new_label (NSString *value)
   NSTextField *urlLabel = nil;
   NSTextField *copyrightLabel;
   NSTextField *copyrightDescriptionLabel = nil;
+  NSTextField *themeLabel = nil;
   NSFont      *smallFont;
 
   /* Minimum size we use for the panel */
@@ -398,6 +402,12 @@ new_label (NSString *value)
       [copyrightDescriptionLabel sizeToFit];
     }
 
+  theme = [NSString stringWithFormat: @"%@: %@",
+    _(@"Current theme"), [[GSTheme theme] name]];
+  themeLabel = new_label (theme);
+  [themeLabel setFont: smallFont];
+  [themeLabel sizeToFit];
+
   /*
    * Compute width and height of the panel
    */
@@ -450,6 +460,10 @@ new_label (NSString *value)
 	width = tmp_A;
     }
 
+  tmp_A = [themeLabel frame].size.width;
+  if (tmp_A > width)
+    width = tmp_A;
+
   /* height */
   /* Warning: we implicitly assume icon height is approx of the
      standard height of 48.  The code tries to be nice so that 50 or
@@ -479,6 +493,9 @@ new_label (NSString *value)
       tmp_A += [copyrightDescriptionLabel frame].size.height;
     }
 
+  tmp_A += 5;
+  tmp_A += [themeLabel frame].size.height;
+
   if (tmp_A > height)
     height = tmp_A;
 
@@ -590,7 +607,19 @@ new_label (NSString *value)
       [copyrightDescriptionLabel setFrame: f];
     }
 
+  f = [themeLabel frame];
+  f.origin.x = (width - f.size.width) / 2;
+  f.origin.y = tmp_b - 25 - f.size.height;
+  tmp_b = f.origin.y;
+  [cv addSubview: themeLabel];
+  [themeLabel setEnabled: YES];
+  [themeLabel setFrame: f];
+  [themeLabel setTarget: [GSTheme class]];
+  [themeLabel setAction: @selector(orderFrontSharedThemePanel:)];
+  [themeLabel sendActionOn: NSLeftMouseUpMask];
+
   [self center];
   return self;
 }
+
 @end
