@@ -43,6 +43,7 @@
 #include <Foundation/NSPathUtilities.h>
 #include <Foundation/NSUserDefaults.h>
 #include <Foundation/NSSerialization.h>
+#include <Foundation/NSPort.h>
 #include <Foundation/NSPortNameServer.h>
 #include <Foundation/NSTask.h>
 #include <Foundation/NSObjCRuntime.h>
@@ -507,7 +508,8 @@ static NSString         *disabledName = @".GNUstepDisabled";
 + (GSServicesManager*) newWithApplication: (NSApplication*)app
 {
   NSString	*str;
-  NSString	*path;
+  NSArray       *paths;
+  NSString      *path = nil;
 
   if (manager != nil)
     {
@@ -520,9 +522,21 @@ static NSString         *disabledName = @".GNUstepDisabled";
 
   manager = [GSServicesManager alloc];
 
-  str = [NSSearchPathForDirectoriesInDomains(NSUserDirectory,
-          NSUserDomainMask, YES) objectAtIndex: 0];
-  str = [str stringByAppendingPathComponent: @"Library/Services"];
+  paths = NSSearchPathForDirectoriesInDomains(NSLibraryDirectory,
+					      NSUserDomainMask, YES);
+  if ((paths != nil) && ([paths count] > 0))
+    {
+      str = [paths objectAtIndex: 0];
+    }
+  /*
+   * If standard search paths are not set up, try a default location.
+   */
+  if (str == nil)
+    {
+      str = [[NSHomeDirectory() stringByAppendingPathComponent:
+			       @"GNUstep"] stringByAppendingPathComponent: @"Library"];
+    }
+  str = [str stringByAppendingPathComponent: @"Services"];
   path = [str stringByAppendingPathComponent: servicesName];
   manager->_servicesPath = [path copy];
   path = [str stringByAppendingPathComponent: disabledName];
