@@ -55,19 +55,14 @@
 /* Maximum number of planes */
 #define MAX_PLANES 5
 
-/* FIXME: By default the libtiff library (v3.5.7 and less at least) do
-   not support LZW compression, but it's not possible to find out if it
-   does or not until after we've already written an image :-(.  */
-static BOOL supports_lzw_compression = NO;
-
 /* Backend methods (optional) */
 @interface NSBitmapImageRep (GSPrivate)
 // GNUstep extension
 - _initFromTIFFImage: (TIFF *)image number: (int)imageNumber;
 
 // Internal
-- (int) _localFromCompressionType: (NSTIFFCompression)type;
-- (NSTIFFCompression) _compressionTypeFromLocal: (int)type;
++ (int) _localFromCompressionType: (NSTIFFCompression)type;
++ (NSTIFFCompression) _compressionTypeFromLocal: (int)type;
 @end
 
 /**
@@ -164,7 +159,7 @@ static BOOL supports_lzw_compression = NO;
 
 /** <p>Returns a newly allocated NSBitmapImageRep object representing the
     image stored in imageData. If the image data contains more than one
-    image, the first one is choosen.</p><p>See Also: +imageRepWithData:</p>  
+    image, the first one is choosen.</p><p>See Also: +imageRepsWithData:</p>  
 */
 + (id) imageRepWithData: (NSData *)imageData
 {
@@ -314,6 +309,7 @@ static BOOL supports_lzw_compression = NO;
   return self;
 }
 
+/** Initialize with bitmap data from a rect within the focused view */
 - (id) initWithFocusedViewRect: (NSRect)rect
 {
   int bps, spp, alpha;
@@ -526,6 +522,7 @@ static BOOL supports_lzw_compression = NO;
     {
       [self setOpaque: YES];
     }
+  _properties = [[NSMutableDictionary alloc] init];
   return self;
 }
 
@@ -555,6 +552,7 @@ static BOOL supports_lzw_compression = NO;
 {
   NSZoneFree([self zone],_imagePlanes);
   RELEASE(_imageData);
+  RELEASE(_properties);
   [super dealloc];
 }
 
@@ -763,7 +761,7 @@ static BOOL supports_lzw_compression = NO;
     }
 
   info.extraSamples = (_hasAlpha) ? 1 : 0;
-  info.compression = [self _localFromCompressionType: type];
+  info.compression = [NSBitmapImageRep _localFromCompressionType: type];
   if (factor < 0)
     factor = 0;
   if (factor > 255)
@@ -786,27 +784,96 @@ static BOOL supports_lzw_compression = NO;
   return [NSData dataWithBytesNoCopy: bytes length: length];
 }
 
+/** <p> Returns a data object in the selected format with multiple images.</p>
+  <p> See Also: -setProperty:withValue: for the options supported in the properties.</p>
+  <p> FIXME: returns only the first image in the array, and only works for
+  NSBitmapImageRep or subclasses thereof. </p>
+*/
 + (NSData *)representationOfImageRepsInArray:(NSArray *)imageReps 
 				   usingType:(NSBitmapImageFileType)storageType
 				  properties:(NSDictionary *)properties
 {
-  // TODO
+  // Partial implementation only returns data for the first imageRep in the array
+  // and only works for NSBitmapImageRep or subclasses thereof. 
+  //FIXME: This only outputs one of the ImageReps
+  NSEnumerator *enumerator = [imageReps objectEnumerator];
+  NSImageRep *rep;
+
+  while ((rep = [enumerator nextObject]) != nil)
+    {
+      if ([rep isKindOfClass: self])
+        {
+	  return [(NSBitmapImageRep*)rep representationUsingType: storageType
+		     properties: properties];
+	}
+    }
+
   return nil;
 }
 
+/** <p> Returns a data object in one of the supported bitmap graphics file types. 
+  A limited set of options may be passed via the properties. If the passed in properties is nil,
+  it falls back to the options set with -setProperty:withValue:. File types not yet
+  implemented return nil and log an error message.</p>
+  <p> See Also: -setProperty:withValue: for supported options in the properties. </p>
+*/
 - (NSData *)representationUsingType:(NSBitmapImageFileType)storageType 
 			 properties:(NSDictionary *)properties
 {
-  // TODO
+  // if it exists, the passed in properties takes precedence over the internal _properties
+  NSDictionary * __properties;
+  __properties = (properties)? properties : (NSDictionary *)_properties;
+
+  switch (storageType)
+  {
+    case NSTIFFFileType:
+    {
+      NSNumber * property;
+      float factor = _comp_factor;
+      NSTIFFCompression compression = _compression;
+      if ((property = [__properties objectForKey: NSImageCompressionMethod]))
+        compression =  [property unsignedShortValue];
+      if ((property = [__properties objectForKey: NSImageCompressionFactor]))
+        factor = [property floatValue];
+      if ([self canBeCompressedUsing: compression] == NO)
+        {
+          factor = 0.0;
+          compression = NSTIFFCompressionNone;
+        }
+      return [self TIFFRepresentationUsingCompression: compression factor: factor];
+    }
+
+    case NSBMPFileType:
+      NSLog(@"BMP representation is not yet implemented");
+      return nil;
+
+    case NSGIFFileType:
+      return [self _GIFRepresentationWithProperties: __properties
+                                       errorMessage: NULL];
+
+    case NSJPEGFileType:
+      return [self _JPEGRepresentationWithProperties: __properties
+                                        errorMessage: NULL];
+
+    case NSPNGFileType:
+      return [self _PNGRepresentationWithProperties: __properties];
+    
+    case NSJPEG2000FileType:
+      NSLog(@"JPEG2000 representation is not yet implemented");
+      return nil;
+  }
   return nil;
 }
 
 //
 // Setting and Checking Compression Types 
 //
+/** Returns a C-array of available TIFF compression types.
+ */
 + (void) getTIFFCompressionTypes: (const NSTIFFCompression **)list
 			   count: (int *)numTypes
 {
+  // the GNUstep supported types
   static NSTIFFCompression	types[] = {
     NSTIFFCompressionNone,
     NSTIFFCompressionCCITTFAX3,
@@ -817,13 +884,25 @@ static BOOL supports_lzw_compression = NO;
     NSTIFFCompressionPackBits,
     NSTIFFCompressionOldJPEG
   };
-
+  
+  // check with libtiff to see what is really available
+  int i, j;
+  static NSTIFFCompression checkedTypes[8];
+  for (i = 0, j = 0; i < 8; i++)
+  {
+    if (NSTiffIsCodecConfigured([NSBitmapImageRep _localFromCompressionType: types[i]]))
+    {
+      checkedTypes[j] = types[i];
+      j++;
+    }
+  }
   if (list)
-    *list = types;
+    *list = checkedTypes;
   if (numTypes)
-    *numTypes = sizeof(types)/sizeof(*types);
+    *numTypes = j;
 }
 
+/** Returns a localized string describing a TIFF compression type. */
 + (NSString*) localizedNameForTIFFCompressionType: (NSTIFFCompression)type
 {
   switch (type)
@@ -845,30 +924,26 @@ static BOOL supports_lzw_compression = NO;
 - (BOOL) canBeCompressedUsing: (NSTIFFCompression)compression
 {
   BOOL does;
+  int codecConf =
+    NSTiffIsCodecConfigured([NSBitmapImageRep _localFromCompressionType: compression]);
   switch (compression)
     {
       case NSTIFFCompressionCCITTFAX3:
       case NSTIFFCompressionCCITTFAX4:
-	if (_numColors == 1 && _bitsPerSample == 1)
+	if (_numColors == 1 && _bitsPerSample == 1 && codecConf != 0)
 	  does = YES;
 	else
 	  does = NO;
 	break;
 
       case NSTIFFCompressionLZW: 
-	does = supports_lzw_compression;
-	break;
-	
       case NSTIFFCompressionNone:
-      case NSTIFFCompressionJPEG:
+      case NSTIFFCompressionJPEG:	// this is a GNUstep extension; Cocoa does not support
       case NSTIFFCompressionPackBits:
       case NSTIFFCompressionOldJPEG:
-	does = YES;
-	break;
-
       case NSTIFFCompressionNEXT:
       default:
-	does = NO;
+	does = (codecConf != 0);
     }
   return does;
 }
@@ -892,15 +967,57 @@ static BOOL supports_lzw_compression = NO;
   _comp_factor = factor;
 }
 
+/** <p> Properties are key-value pairs associated with the representation. Arbitrary
+  key-value pairs may be set. If the value is nil, the key is erased from properties.
+  There are standard keys that are used to pass information
+  and options related to the standard file types that may be read from or written to.
+  Certain properties are automatically set when reading in image data.
+  Certain properties may be set by the user prior to writing image data in order to set options
+  for the data format. </p>
+  <deflist>
+    <term> NSImageCompressionMethod </term>
+    <desc> NSNumber; automatically set when reading TIFF data; writing TIFF data </desc>
+    <term> NSImageCompressionFactor </term>
+    <desc> NSNumber 0.0 to 255.0; writing JPEG data 
+    (GNUstep extension: JPEG-compressed TIFFs too) </desc>
+    <term> NSImageProgressive </term>
+    <desc> NSNumber boolean; automatically set when reading JPEG data; writing JPEG data.
+    Note: progressive display is not supported in GNUstep at this time. </desc>
+    <term> NSImageInterlaced </term>
+    <desc> NSNumber boolean; only for writing PNG data </desc>
+    <term> NSImageGamma </term>
+    <desc> NSNumber 0.0 to 1.0; only for reading or writing PNG data </desc>
+    <term> NSImageRGBColorTable </term>
+    <desc> NSData; automatically set when reading GIF data; writing GIF data </desc>
+    <term> NSImageFrameCount </term>
+    <desc> NSNumber integer; automatically set when reading animated GIF data.
+    Not currently implemented. </desc>
+    <term> NSImageCurrentFrame </term>
+    <desc> NSNumber integer; only for animated GIF files. Not currently implemented. </desc>
+    <term> NSImageCurrentFrameDuration </term>
+    <desc> NSNumber float; automatically set when reading animated GIF data </desc>
+    <term> NSImageLoopCount </term>
+    <desc> NSNumber integer; automatically set when reading animated GIF data </desc>
+    <term> NSImageDitherTranparency </term>
+    <desc> NSNumber boolean; only for writing GIF data. Not currently supported. </desc>
+  </deflist>
+*/
 - (void)setProperty:(NSString *)property withValue:(id)value
 {
-  // TODO
+  if (value)
+  {
+    [_properties setObject: value forKey: property];
+  }
+  else  // clear the property
+  {
+    [_properties removeObjectForKey: property];
+  }
 }
 
+/** Returns the value of a property */
 - (id)valueForProperty:(NSString *)property
 {
-  // TODO
-  return nil;
+  return [_properties objectForKey: property];
 }
 
 // NSCopying protocol
@@ -948,7 +1065,7 @@ static BOOL supports_lzw_compression = NO;
   NSData *data = [self TIFFRepresentation];
 
   [super encodeWithCoder: aCoder];
-  if([aCoder allowsKeyedCoding])
+  if ([aCoder allowsKeyedCoding])
     {
       [aCoder encodeObject: data forKey: @"NSTIFFRepresentation"];
     }
@@ -978,7 +1095,7 @@ static BOOL supports_lzw_compression = NO;
 
 @implementation NSBitmapImageRep (GSPrivate)
 
-- (int) _localFromCompressionType: (NSTIFFCompression)type
++ (int) _localFromCompressionType: (NSTIFFCompression)type
 {
   switch (type)
     {
@@ -996,7 +1113,7 @@ static BOOL supports_lzw_compression = NO;
   return COMPRESSION_NONE;
 }
 
-- (NSTIFFCompression) _compressionTypeFromLocal: (int)type
++ (NSTIFFCompression) _compressionTypeFromLocal: (int)type
 {
   switch (type)
     {
@@ -1057,9 +1174,15 @@ static BOOL supports_lzw_compression = NO;
 		colorSpaceName: space
 		bytesPerRow: 0
 		bitsPerPixel: 0];
-  _compression = [self _compressionTypeFromLocal: info->compression];
+  _compression = [NSBitmapImageRep _compressionTypeFromLocal: info->compression];
   _comp_factor = 255 * (1 - ((float)info->quality)/100.0);
 
+  // Note that Cocoa does not do this, even though the docs say it should
+  [_properties setObject: [NSNumber numberWithUnsignedShort: _compression]
+                  forKey: NSImageCompressionMethod];
+  [_properties setObject: [NSNumber numberWithFloat: _comp_factor]
+                  forKey: NSImageCompressionFactor];
+
   if (NSTiffRead(image, info, [self bitmapData]))
     {
       OBJC_FREE(info);
