@@ -38,7 +38,7 @@
 #include "AppKit/NSGraphics.h"
 #include "AppKit/NSTextFieldCell.h"
 #include "AppKit/NSWindow.h"
-#include "GNUstepGUI/GSDrawFunctions.h"
+#include "GNUstepGUI/GSTheme.h"
 
 #include <math.h>
 
@@ -67,8 +67,13 @@
 //
 - (id) initWithFrame: (NSRect)frameRect
 {
-  [super initWithFrame: frameRect];
+  NSView *cv;
+
+  self = [super initWithFrame: frameRect];
 	
+  if (!self)
+    return self;
+
   _cell = [[NSCell alloc] initTextCell: @"Title"];
   [_cell setAlignment: NSCenterTextAlignment];
   [_cell setBordered: NO];
@@ -80,10 +85,10 @@
   _title_position = NSAtTop;
   _title_rect = NSZeroRect;
   [self setAutoresizesSubviews: NO];
-  _content_view = [NSView new];
-  [super addSubview: _content_view];
-  [_content_view setFrame: [self calcSizesAllowingNegative: NO]];
-  RELEASE(_content_view);
+
+  cv = [NSView new];
+  [self setContentView: cv];
+  RELEASE(cv);
 
   return self;
 }
@@ -445,10 +450,10 @@
       NSFrameRect(_border_rect);
       break;
     case NSBezelBorder:
-      [GSDrawFunctions drawDarkBezel: _border_rect : rect];
+      [[GSTheme theme] drawDarkBezel: _border_rect withClip: rect];
       break;
     case NSGrooveBorder: 
-      [GSDrawFunctions drawGroove: _border_rect : rect];
+      [[GSTheme theme] drawGroove: _border_rect withClip: rect];
       break;
     }
 
