@@ -52,7 +52,7 @@
 #include "AppKit/NSEvent.h"
 #include "AppKit/NSWindow.h"
 #include "AppKit/NSBezierPath.h"
-#include "GNUstepGUI/GSDrawFunctions.h"
+#include "GNUstepGUI/GSTheme.h"
 
 DEFINE_RINT_IF_MISSING
 
@@ -152,7 +152,7 @@ static NSTextFieldCell *titleCell;
 
 - (void) encodeWithCoder: (NSCoder *)aCoder
 {
-  if([aCoder allowsKeyedCoding])
+  if ([aCoder allowsKeyedCoding])
     {
     }
   else
@@ -169,7 +169,7 @@ static NSTextFieldCell *titleCell;
   
 - (id) initWithCoder: (NSCoder *)aDecoder
 {
-  if([aDecoder allowsKeyedCoding])
+  if ([aDecoder allowsKeyedCoding])
     {
       
     }
@@ -206,7 +206,7 @@ static NSTextFieldCell *titleCell;
       return;
     }
 
-  [GSDrawFunctions drawGrayBezel: cellFrame : NSZeroRect];
+  [[GSTheme theme] drawGrayBezel: cellFrame withClip: NSZeroRect];
   [self drawInteriorWithFrame: cellFrame  inView: controlView];
 }
 @end
@@ -2008,6 +2008,11 @@ static NSTextFieldCell *titleCell;
 
   selectedCellsCount = [selectedCells count];
 
+/* FIXME why were we reselecting already selected cells?
+ * this caused bug #18881 because -selectCell: will scroll the row to visible.
+ */
+#if 0
+
   // Select cells that should be selected
   if (selectedCellsCount > 0)
     {
@@ -2015,6 +2020,7 @@ static NSTextFieldCell *titleCell;
       while ((cell = [enumerator nextObject]))
 	[sender selectCell: cell];
     }
+#endif
 
   [self setLastColumn: column];
   // Single selection
@@ -2219,7 +2225,7 @@ static NSTextFieldCell *titleCell;
 
       if ((NSIntersectsRect (scrollerBorderRect, rect) == YES) && _window)
       	{
-          [GSDrawFunctions drawGrayBezel: scrollerBorderRect : rect];
+          [[GSTheme theme] drawGrayBezel: scrollerBorderRect withClip: rect];
 	}
     }
 
@@ -2230,7 +2236,7 @@ static NSTextFieldCell *titleCell;
       float   hScrollerWidth = _hasHorizontalScroller ? scrollerWidth : 0;
       
       // Columns borders
-      [GSDrawFunctions drawGrayBezel: _bounds : rect];
+      [[GSTheme theme] drawGrayBezel: _bounds withClip: rect];
       
       [[NSColor blackColor] set];
       visibleColumns = [self numberOfVisibleColumns]; 
@@ -2501,7 +2507,7 @@ static NSTextFieldCell *titleCell;
 - (void) encodeWithCoder: (NSCoder*)aCoder
 {
   [super encodeWithCoder: aCoder];
-  if([aCoder allowsKeyedCoding])
+  if ([aCoder allowsKeyedCoding])
     {
       long flags = 0;
 
