@@ -323,9 +323,6 @@ static NSFont *_leafFont;
   // Draw the body of the cell
   [self _drawAttributedText: [self attributedStringValue]
 	inFrame: title_rect];
-
-  if (_cell.shows_first_responder == YES)
-    NSDottedFrameRect(cellFrame);
 }
 
 - (BOOL) isOpaque
@@ -339,7 +336,7 @@ static NSFont *_leafFont;
 - (void) encodeWithCoder: (NSCoder*)aCoder
 {
   [super encodeWithCoder: aCoder];
-  if([aCoder allowsKeyedCoding])
+  if ([aCoder allowsKeyedCoding])
     {
       // simply encodes prescence...
     }
