@@ -51,7 +51,7 @@
 #include "AppKit/NSImage.h"
 #include "AppKit/NSSound.h"
 #include "AppKit/NSWindow.h"
-#include "GNUstepGUI/GSDrawFunctions.h"
+#include "GNUstepGUI/GSTheme.h"
 #include "GNUstepGUI/GSNibCompatibility.h"
 
 #include <math.h>
@@ -103,12 +103,6 @@ typedef struct _GSButtonCellFlags
 #endif
 } GSButtonCellFlags;
 
-@interface NSButtonCell (Private)
-// Overriden private internal method
-- (void) _drawImage: (NSImage *)anImage inFrame: (NSRect)aRect 
-  isFlipped: (BOOL)flipped;
-@end
-
 /**<p> TODO Description</p>
  */
 @implementation NSButtonCell
@@ -119,7 +113,7 @@ typedef struct _GSButtonCellFlags
 + (void) initialize
 {
   if (self == [NSButtonCell class])
-    [self setVersion: 1];
+    [self setVersion: 2];
 }
 
 /*
@@ -130,19 +124,16 @@ typedef struct _GSButtonCellFlags
   // Implicitly performed by allocation:
   //
   //_buttoncell_is_transparent = NO;
-  //_altContents = nil;
 
   [self setAlignment: NSCenterTextAlignment];
   _cell.is_bordered = YES;
-  _showAltStateMask = NSNoCellMask;	// configure as a NSMomentaryPushButton
-  _highlightsByMask = NSPushInCellMask | NSChangeGrayCellMask;
+  [self setButtonType: NSMomentaryPushInButton];
   _delayInterval = 0.4;
   _repeatInterval = 0.075;
   _keyEquivalentModifierMask = NSCommandKeyMask;
   _keyEquivalent = @"";
   _altContents = @"";
   _gradient_type = NSGradientNone;
-  _image_dims_when_disabled = NO;
 
   return self;
 }
@@ -175,6 +166,7 @@ typedef struct _GSButtonCellFlags
   RELEASE(_keyEquivalent);
   RELEASE(_keyEquivalentFont);
   RELEASE(_sound);
+  RELEASE(_backgroundColor);
 
   [super dealloc];
 }
@@ -387,7 +379,7 @@ typedef struct _GSButtonCellFlags
 - (void)setTitleWithMnemonic:(NSString *)aString
 {
   // TODO
-  [super setTitleWithMnemonic: aString];    
+  [super setTitleWithMnemonic: aString];
 }
 
 - (NSString *)alternateMnemonic
@@ -704,7 +696,7 @@ typedef struct _GSButtonCellFlags
 	[self setShowsStateBy: NSNoCellMask];
 	[self setImageDimsWhenDisabled: YES];
 	break;
-      case NSMomentaryPushButton: 
+      case NSMomentaryPushInButton: 
 	[self setHighlightsBy: NSPushInCellMask | NSChangeGrayCellMask];
 	[self setShowsStateBy: NSNoCellMask];
 	[self setImageDimsWhenDisabled: YES];
@@ -834,36 +826,108 @@ typedef struct _GSButtonCellFlags
   return [NSColor controlTextColor];
 }
 
-- (void) drawWithFrame: (NSRect)cellFrame inView: (NSView*)controlView
+- (NSColor *) backgroundColor
 {
-  // Save last view drawn to
-  if (_control_view != controlView)
-    _control_view = controlView;
+  return _backgroundColor;
+}
 
-  // transparent buttons never draw
-  if (_buttoncell_is_transparent)
-    return;
+- (void) setBackgroundColor: (NSColor *)color
+{
+  ASSIGN(_backgroundColor, color);
+}
 
-  // do nothing if cell's frame rect is zero
-  if (NSIsEmptyRect(cellFrame))
-    return;
+- (void) drawBezelWithFrame: (NSRect)cellFrame inView: (NSView *)controlView
+{
+  unsigned		mask;
+  GSThemeControlState	buttonState = GSThemeNormalState;
 
-  // draw the border if needed
-  if ((_cell.is_bordered) && 
-      (!_shows_border_only_while_mouse_inside || _mouse_inside))
+  // set the mask
+  if (_cell.is_highlighted)
     {
-      // FIXME Should check the bezel and gradient style
-      if (_cell.is_highlighted && (_highlightsByMask & NSPushInCellMask))
+      mask = _highlightsByMask;
+      if (_cell.state)
         {
-	  [GSDrawFunctions drawGrayBezel: cellFrame : NSZeroRect];
-        }
-      else
-        {
-	  [GSDrawFunctions drawButton: cellFrame : NSZeroRect];
-        }
+	  mask &= ~_showAltStateMask;
+	}
+    }
+  else if (_cell.state)
+    mask = _showAltStateMask;
+  else
+    mask = NSNoCellMask;
+
+  /* Determine the background color. 
+     We draw when there is a border or when highlightsByMask
+     is NSChangeBackgroundCellMask or NSChangeGrayCellMask,
+     as required by our nextstep-like look and feel.  */
+  if (mask & (NSChangeGrayCellMask | NSChangeBackgroundCellMask))
+    {
+      buttonState = GSThemeHighlightedState;
     }
 
-  [self drawInteriorWithFrame: cellFrame inView: controlView];
+  /* Pushed in buttons contents are displaced to the bottom right 1px.  */
+  if (mask & NSPushInCellMask)
+    {
+      buttonState = GSThemeSelectedState;
+    }
+
+  [[GSTheme theme] drawButton: cellFrame 
+		   in: self 
+		   view: controlView
+		   style: _bezel_style
+		   state: buttonState];
+}
+
+- (void) drawImage: (NSImage*)anImage 
+	 withFrame: (NSRect)aRect 
+	    inView: (NSView*)controlView
+{
+  // Draw image
+  if (anImage != nil)
+    {
+      NSSize size;
+      NSPoint position;
+      
+      size = [anImage size];
+      position.x = MAX(NSMidX(aRect) - (size.width / 2.), 0.);
+      position.y = MAX(NSMidY(aRect) - (size.height / 2.), 0.);
+      
+      /*
+       * Images are always drawn with their bottom-left corner at the origin
+       * so we must adjust the position to take account of a flipped view.
+       */
+      if ([controlView isFlipped])
+        {
+	  position.y += size.height;
+	}
+      
+      if (_cell.is_disabled && _image_dims_when_disabled)
+        {
+	  [anImage dissolveToPoint: position fraction: 0.5];
+	}
+      else
+        {
+	  [anImage compositeToPoint: position 
+		          operation: NSCompositeSourceOver];
+	}
+    }
+}
+
+- (void) drawTitle: (NSAttributedString*)titleToDisplay 
+	 withFrame: (NSRect)frame 
+	    inView: (NSView*)control
+{
+  [self _drawAttributedText: titleToDisplay
+	inFrame: frame];
+}
+
+// Private helper method overridden in subclasses
+- (void) _drawBorderAndBackgroundWithFrame: (NSRect)cellFrame inView: (NSView*)controlView
+{
+  if ((_cell.is_bordered)
+    && (!_shows_border_only_while_mouse_inside || _mouse_inside))
+    {
+      [self drawBezelWithFrame: cellFrame inView: controlView];
+    }
 }
 
 - (void) drawGradientWithFrame: (NSRect)cellFrame inView: (NSView *)controlView
@@ -884,47 +948,47 @@ typedef struct _GSButtonCellFlags
 
   switch (_gradient_type)
     {
-    case NSGradientNone:
-      return;
-      break;
+      case NSGradientNone:
+	return;
+	break;
 
-    case NSGradientConcaveWeak:
-      [gray getHue: &h saturation: &s brightness: &v alpha: &a];
-      start_white = [lightGray brightnessComponent];
-      end_white = [gray brightnessComponent];
-      break;
-      
-    case NSGradientConvexWeak:
-      [darkGray getHue: &h saturation: &s brightness: &v alpha: &a];
-      start_white = [gray brightnessComponent];
-      end_white = [lightGray brightnessComponent];
-      break;
-      
-    case NSGradientConcaveStrong:
-      [lightGray getHue: &h saturation: &s brightness: &v alpha: &a];
-      start_white = [lightGray brightnessComponent];
-      end_white = [darkGray brightnessComponent];
-      break;
-      
-    case NSGradientConvexStrong:
-      [darkGray getHue: &h saturation: &s brightness: &v alpha: &a];
-      start_white = [darkGray brightnessComponent];
-      end_white = [lightGray brightnessComponent];
-      break;
+      case NSGradientConcaveWeak:
+	[gray getHue: &h saturation: &s brightness: &v alpha: &a];
+	start_white = [lightGray brightnessComponent];
+	end_white = [gray brightnessComponent];
+	break;
+	
+      case NSGradientConvexWeak:
+	[darkGray getHue: &h saturation: &s brightness: &v alpha: &a];
+	start_white = [gray brightnessComponent];
+	end_white = [lightGray brightnessComponent];
+	break;
+	
+      case NSGradientConcaveStrong:
+	[lightGray getHue: &h saturation: &s brightness: &v alpha: &a];
+	start_white = [lightGray brightnessComponent];
+	end_white = [darkGray brightnessComponent];
+	break;
+	
+      case NSGradientConvexStrong:
+	[darkGray getHue: &h saturation: &s brightness: &v alpha: &a];
+	start_white = [darkGray brightnessComponent];
+	end_white = [lightGray brightnessComponent];
+	break;
 
-    default:
-      break;
+      default:
+	break;
     }
 
   white = start_white;
-  white_step = fabs(start_white - end_white)/
-               (cellFrame.size.width + cellFrame.size.height);
+  white_step = fabs(start_white - end_white)
+    / (cellFrame.size.width + cellFrame.size.height);
 
   // Start from top left
-  p1 = NSMakePoint(cellFrame.origin.x, 
-		   cellFrame.size.height + cellFrame.origin.y);
+  p1 = NSMakePoint(cellFrame.origin.x,
+    cellFrame.size.height + cellFrame.origin.y);
   p2 = NSMakePoint(cellFrame.origin.x, 
-		   cellFrame.size.height + cellFrame.origin.y);
+    cellFrame.size.height + cellFrame.origin.y);
 
   // Move by Y
   while (p1.y > cellFrame.origin.y)
@@ -974,7 +1038,6 @@ typedef struct _GSButtonCellFlags
   NSRect	titleRect;
   NSSize	imageSize = {0, 0};
   NSSize        titleSize = {0, 0};
-  NSColor	*backgroundColor = nil;
   BOOL		flippedView = [controlView isFlipped];
   NSCellImagePosition ipos = _cell.image_position;
 
@@ -998,38 +1061,6 @@ typedef struct _GSButtonCellFlags
   else
     mask = NSNoCellMask;
 
-  /* Pushed in buttons contents are displaced to the bottom right 1px.  */
-  if (_cell.is_bordered && (mask & NSPushInCellMask))
-    {
-      cellFrame = NSOffsetRect(cellFrame, 1., flippedView ? 1. : -1.);
-    }
-
-  /* Draw the cell's background color.  
-     We draw when there is a border or when highlightsByMask
-     is NSChangeBackgroundCellMask or NSChangeGrayCellMask,
-     as required by our nextstep-like look and feel.  */
-  if (_cell.is_bordered 
-      || (_highlightsByMask & NSChangeBackgroundCellMask)
-      || (_highlightsByMask & NSChangeGrayCellMask))
-    {
-      /* Determine the background color. */
-      if (mask & (NSChangeGrayCellMask | NSChangeBackgroundCellMask))
-        {
-          backgroundColor = [NSColor selectedControlColor];
-        }
-      else if (_cell.is_bordered) 
-        {
-          backgroundColor = [NSColor controlBackgroundColor];
-        }
-      
-      if (backgroundColor != nil) 
-        {
-          [backgroundColor set];
-          NSRectFill (cellFrame);
-        }
-      
-    }
-
   /*
    * Determine the image and the title that will be
    * displayed. If the NSContentsCellMask is set the
@@ -1096,7 +1127,7 @@ typedef struct _GSButtonCellFlags
       case NSNoImage: 
 	imageToDisplay = nil;
 	titleRect = cellFrame;
-	imageRect = NSZeroRect;
+	 imageRect = NSZeroRect;
 	if (titleSize.width + 6 <= titleRect.size.width)
 	  {
 	    titleRect.origin.x += 3;
@@ -1195,7 +1226,8 @@ typedef struct _GSButtonCellFlags
 	imageRect.origin.x = cellFrame.origin.x;
 	imageRect.origin.y = cellFrame.origin.y;
 	imageRect.size.width = cellFrame.size.width;
-	imageRect.size.height = titleRect.origin.y - GSCellTextImageYDist - imageRect.origin.y;
+	imageRect.size.height
+	  = titleRect.origin.y - GSCellTextImageYDist - imageRect.origin.y;
 
 	if (_cell.is_bordered || _cell.is_bezeled) 
 	  {
@@ -1223,26 +1255,22 @@ typedef struct _GSButtonCellFlags
   // Draw gradient
   if (!_cell.is_highlighted && _gradient_type != NSGradientNone)
     {
+	// FIXME: I think this method is wrong.
       [self drawGradientWithFrame: cellFrame inView: controlView];
     }
 
   // Draw image
   if (imageToDisplay != nil)
     {
-      [self _drawImage: imageToDisplay inFrame: imageRect isFlipped: flippedView];
+      [self drawImage: imageToDisplay
+	    withFrame: imageRect
+	       inView: controlView];
     }
 
   // Draw title
   if (titleToDisplay != nil)
     {
-      [self _drawAttributedText: titleToDisplay inFrame: titleRect];
-    }
-
-  // Draw first responder
-  if (_cell.shows_first_responder
-      && [[controlView window] firstResponder] == controlView)
-    {
-      NSDottedFrameRect(cellFrame);
+      [self drawTitle: titleToDisplay withFrame: titleRect inView: controlView];
     }
 }
 
@@ -1331,40 +1359,83 @@ typedef struct _GSButtonCellFlags
   
   // Get border size
   if (_cell.is_bordered)
-    // Buttons only have three paths for border (NeXT looks)
-    borderSize = NSMakeSize (3.0, 3.0);
+    {
+      GSThemeControlState	buttonState = GSThemeNormalState;
+
+      /* Determine the background color. 
+	 We draw when there is a border or when highlightsByMask
+	 is NSChangeBackgroundCellMask or NSChangeGrayCellMask,
+	 as required by our nextstep-like look and feel.  */
+      if (mask & (NSChangeGrayCellMask | NSChangeBackgroundCellMask))
+        {
+	  buttonState = GSThemeHighlightedState;
+	}
+      
+      /* Pushed in buttons contents are displaced to the bottom right 1px.  */
+      if (mask & NSPushInCellMask)
+        {
+	  buttonState = GSThemeSelectedState;
+	}
+
+      borderSize = [[GSTheme theme] buttonBorderForStyle: _bezel_style 
+				                   state: buttonState];
+    }
   else
     borderSize = NSZeroSize;
 
-  if ((_cell.is_bordered && (_cell.image_position != NSImageOnly))
-      || _cell.is_bezeled)
-    {
-      borderSize.width += 6;
-      borderSize.height += 6;
-    }
-
   // Add border size
-  s.width += borderSize.width;
-  s.height += borderSize.height;
+  s.width += 2 * borderSize.width;
+  s.height += 2 * borderSize.height;
 
   return s;
 }
 
 - (NSRect) drawingRectForBounds: (NSRect)theRect
 {
-  // FIXME
   if (_cell.is_bordered)
     {
-      /*
-       * Special case:  Buttons have only three different paths for border.
-       * One white path at the top left corner, one black path at the
-       * bottom right and another in dark gray at the inner bottom right.
-       */
-      float yDelta = [_control_view isFlipped] ? 1. : 2.;
-      return NSMakeRect (theRect.origin.x + 1.,
-			 theRect.origin.y + yDelta,
-			 theRect.size.width - 3.,
-			 theRect.size.height - 3.);
+      NSSize borderSize;
+      unsigned	mask;
+      GSThemeControlState buttonState = GSThemeNormalState;
+      NSRect interiorFrame;
+
+      if (_cell.is_highlighted)
+        {
+	  mask = _highlightsByMask;
+
+	  if (_cell.state)
+	    mask &= ~_showAltStateMask;
+	}
+      else if (_cell.state)
+	mask = _showAltStateMask;
+      else
+	mask = NSNoCellMask;
+  
+      /* Determine the background color. 
+	 We draw when there is a border or when highlightsByMask
+	 is NSChangeBackgroundCellMask or NSChangeGrayCellMask,
+	 as required by our nextstep-like look and feel.  */
+      if (mask & (NSChangeGrayCellMask | NSChangeBackgroundCellMask))
+        {
+	  buttonState = GSThemeHighlightedState;
+	}
+      
+      if (mask & NSPushInCellMask)
+        {
+	  buttonState = GSThemeSelectedState;
+	}
+
+      borderSize = [[GSTheme theme] buttonBorderForStyle: _bezel_style 
+				                   state: buttonState];
+      interiorFrame = NSInsetRect(theRect, borderSize.width, borderSize.height);
+
+      /* Pushed in buttons contents are displaced to the bottom right 1px.  */
+      if (mask & NSPushInCellMask)
+	{
+	  interiorFrame
+	    = NSOffsetRect(interiorFrame, 1.0, [_control_view isFlipped] ? 1.0 : -1.0);
+	}
+      return interiorFrame;
     }
   else
     {
@@ -1428,11 +1499,12 @@ typedef struct _GSButtonCellFlags
 {
   NSButtonCell	*c = [super copyWithZone: zone];
   
-  /* Hmmm. */
   c->_altContents = [_altContents copyWithZone: zone];
-  TEST_RETAIN (_altImage);
-  TEST_RETAIN (_keyEquivalent);
-  TEST_RETAIN (_keyEquivalentFont);
+  TEST_RETAIN(_altImage);
+  TEST_RETAIN(_keyEquivalent);
+  TEST_RETAIN(_keyEquivalentFont);
+  TEST_RETAIN(_sound);
+  TEST_RETAIN(_backgroundColor);
 
   return c;
 }
@@ -1445,7 +1517,7 @@ typedef struct _GSButtonCellFlags
   BOOL tmp;
 
   [super encodeWithCoder: aCoder];
-  if([aCoder allowsKeyedCoding])
+  if ([aCoder allowsKeyedCoding])
     {
       GSButtonCellFlags buttonCellFlags;
       unsigned int bFlags = 0;
@@ -1453,15 +1525,15 @@ typedef struct _GSButtonCellFlags
       NSImage *image = [self image];
       NSButtonImageSource *bi = nil;
 
-      if([self keyEquivalent] != nil)
+      if ([self keyEquivalent] != nil)
 	{
 	  [aCoder encodeObject: [self keyEquivalent] forKey: @"NSKeyEquivalent"];
 	}
-      if([self image] != nil)
+      if ([self image] != nil)
 	{
 	  [aCoder encodeObject: [self image] forKey: @"NSNormalImage"];
 	}
-      if([self alternateTitle] != nil)
+      if ([self alternateTitle] != nil)
 	{
 	  [aCoder encodeObject: [self alternateTitle] forKey: @"NSAlternateContents"];
 	}
@@ -1496,19 +1568,19 @@ typedef struct _GSButtonCellFlags
 
       // style and border.
       bFlags2 != [self showsBorderOnlyWhileMouseInside] ? 0x8 : 0;
-      bFlags2 |= [self bezelStyle];
+      bFlags2 |= (([self bezelStyle] & 0x7) | (([self bezelStyle] & 0x18) << 2));
       [aCoder encodeInt: bFlags2 forKey: @"NSButtonFlags2"];
 
       // alternate image encoding...
-      if(image != nil)
+      if (image != nil)
 	{
 	  if ([image isKindOfClass: [NSImage class]] && buttonCellFlags.useButtonImageSource)
 	    {
-	      if([NSImage imageNamed: @"NSSwitch"] == image)
+	      if ([NSImage imageNamed: @"NSSwitch"] == image)
 		{
 		  bi = [[NSButtonImageSource alloc] initWithImageNamed: @"NSHighlightedSwitch"];
 		}
-	      else if([NSImage imageNamed: @"NSRadioButton"] == image)
+	      else if ([NSImage imageNamed: @"NSRadioButton"] == image)
 		{
 		  bi = [[NSButtonImageSource alloc] initWithImageNamed: @"NSHighlightedRadioButton"];
 		}
@@ -1516,11 +1588,11 @@ typedef struct _GSButtonCellFlags
 	}
 
       // encode button image source, if it exists...
-      if(bi != nil)
+      if (bi != nil)
 	{
 	  [aCoder encodeObject: bi forKey: @"NSAlternateImage"];      
 	}
-      else if(_altImage != nil)
+      else if (_altImage != nil)
 	{
 	  [aCoder encodeObject: _altImage forKey: @"NSAlternateImage"];
 	}
@@ -1531,7 +1603,6 @@ typedef struct _GSButtonCellFlags
     }
   else
     {
-      // FIXME: Add new ivars
       [aCoder encodeObject: _keyEquivalent];
       [aCoder encodeObject: _keyEquivalentFont];
       [aCoder encodeObject: _altContents];
@@ -1545,7 +1616,23 @@ typedef struct _GSButtonCellFlags
 	      at: &_highlightsByMask];
       [aCoder encodeValueOfObjCType: @encode(unsigned int)
 	      at: &_showAltStateMask];
-      
+
+      [aCoder encodeObject: _sound];
+      [aCoder encodeObject: _backgroundColor];
+      [aCoder encodeValueOfObjCType: @encode(float)
+	      at: &_delayInterval];
+      [aCoder encodeValueOfObjCType: @encode(float)
+	      at: &_repeatInterval];
+      [aCoder encodeValueOfObjCType: @encode(unsigned int)
+	      at: &_bezel_style];
+      [aCoder encodeValueOfObjCType: @encode(unsigned int)
+	      at: &_gradient_type];
+      tmp = _image_dims_when_disabled;
+      [aCoder encodeValueOfObjCType: @encode(BOOL)
+	      at: &tmp];
+      tmp = _shows_border_only_while_mouse_inside;
+      [aCoder encodeValueOfObjCType: @encode(BOOL)
+	      at: &tmp];
     }
 }
 
@@ -1603,42 +1690,7 @@ typedef struct _GSButtonCellFlags
 
 	  bFlags2 = [aDecoder decodeIntForKey: @"NSButtonFlags2"];
 	  [self setShowsBorderOnlyWhileMouseInside: (bFlags2 & 0x8)];
-
-	  // FIXME
-	  switch (bFlags2 & 0x7)
-	    {
-	      case 1:
-		[self setBezelStyle: NSRoundedBezelStyle];
-		break;
-	      case 2:
-		[self setBezelStyle: NSRegularSquareBezelStyle];
-		break;
-	      case 3:
-		[self setBezelStyle: NSThickSquareBezelStyle];
-		break;
-	      case 4:
-		[self setBezelStyle: NSThickerSquareBezelStyle];
-		break;
-	      case 5:
-		//[self setBezelStyle: NSDisclosureBezelStyle];
-		break;
-	      case 6:
-		[self setBezelStyle: NSShadowlessSquareBezelStyle];
-		break;
-	      case 7:
-		[self setBezelStyle: NSCircularBezelStyle];
-		break;
-/*
-	      case 32:
-		[self setBezelStyle: NSTexturedSquareBezelStyle];
-		break;
-	      case 33:
-		[self setBezelStyle: NSHelpButtonBezelStyle];
-		break;
-*/
-	      default:
-		break;
-	    }
+	  [self setBezelStyle: (bFlags2 & 0x7) | ((bFlags2 & 0x20) >> 2)];
 	}
       if ([aDecoder containsValueForKey: @"NSAlternateImage"])
         {
@@ -1654,18 +1706,18 @@ typedef struct _GSButtonCellFlags
 	  image = [aDecoder decodeObjectForKey: @"NSAlternateImage"];
 	  if ([image isKindOfClass: [NSImage class]])
 	    {
-	      if([NSImage imageNamed: @"NSSwitch"] == image)
+	      if ([NSImage imageNamed: @"NSSwitch"] == image)
 		{
 		  image = [NSImage imageNamed: @"NSHighlightedSwitch"];
-		  if([self image] == nil)
+		  if ([self image] == nil)
 		    {
 		      [self setImage: [NSImage imageNamed: @"NSSwitch"]];
 		    }		    
 		}
-	      else if([NSImage imageNamed: @"NSRadioButton"] == image)
+	      else if ([NSImage imageNamed: @"NSRadioButton"] == image)
 		{
 		  image = [NSImage imageNamed: @"NSHighlightedRadioButton"];
-		  if([self image] == nil)
+		  if ([self image] == nil)
 		    {
 		      [self setImage: [NSImage imageNamed: @"NSRadioButton"]];
 		    }		    
@@ -1686,7 +1738,6 @@ typedef struct _GSButtonCellFlags
     }
   else
     {
-      // FIXME: Add new ivars
       BOOL tmp;
       
       [aDecoder decodeValueOfObjCType: @encode(id) at: &_keyEquivalent];
@@ -1701,45 +1752,24 @@ typedef struct _GSButtonCellFlags
 		                   at: &_highlightsByMask];
       [aDecoder decodeValueOfObjCType: @encode(unsigned int)
 		                   at: &_showAltStateMask];
+
+      if ([aDecoder versionForClassName: @"NSButtonCell"] >= 2)
+      {
+	  [aDecoder decodeValueOfObjCType: @encode(id) at: &_sound];
+	  [aDecoder decodeValueOfObjCType: @encode(id) at: &_backgroundColor];
+	  [aDecoder decodeValueOfObjCType: @encode(float) at: &_delayInterval];
+	  [aDecoder decodeValueOfObjCType: @encode(float) at: &_repeatInterval];
+	  [aDecoder decodeValueOfObjCType: @encode(unsigned int)
+		                       at: &_bezel_style];
+	  [aDecoder decodeValueOfObjCType: @encode(unsigned int)
+		                       at: &_gradient_type];
+	  [aDecoder decodeValueOfObjCType: @encode(BOOL) at: &tmp];
+	  _image_dims_when_disabled = tmp;
+	  [aDecoder decodeValueOfObjCType: @encode(BOOL) at: &tmp];
+	  _shows_border_only_while_mouse_inside = tmp;
+      }
     }
   return self;
 }
 
 @end
-
-@implementation NSButtonCell (Private)
-
-// Overriden private internal method
-- (void) _drawImage: (NSImage *)anImage inFrame: (NSRect)aRect 
-  isFlipped: (BOOL)flipped
-{
-  // To keep partially in sync with the NSCell overriden method
-  
-  NSSize size;
-  NSPoint position;
-
-  size = [anImage size];
-  position.x = MAX(NSMidX(aRect) - (size.width / 2.), 0.);
-  position.y = MAX(NSMidY(aRect) - (size.height / 2.), 0.);
-  
-  /*
-   * Images are always drawn with their bottom-left corner at the origin
-   * so we must adjust the position to take account of a flipped view.
-   */
-  if (flipped)
-    {
-      position.y += size.height;
-    }
-	
-  if (_cell.is_disabled && _image_dims_when_disabled)
-    {
-      [anImage dissolveToPoint: position fraction: 0.5];
-    }
-  else
-    {
-      [anImage compositeToPoint: position 
-	                     operation: NSCompositeSourceOver];
-    }
-}
-
-@end
