@@ -86,30 +86,22 @@ static inline NSRect integralRect (NSRect rect, NSView *view)
 */
 @implementation NSClipView
 
-- (id) init
+- (id) initWithFrame: (NSRect)frameRect
 {
-  [super init];
-  [self setAutoresizesSubviews: YES];
-  [self setBackgroundColor: [NSColor controlColor]];
-  _copiesOnScroll = YES;
-  _drawsBackground = YES;
+  self = [super initWithFrame:frameRect];
+  if (self)
+    {
+      [self setAutoresizesSubviews: YES];
+      [self setBackgroundColor: [NSColor controlBackgroundColor]];
+      _copiesOnScroll = YES;
+      _drawsBackground = YES;
+    }
   return self;
 }
 
 - (void) dealloc
 {
-  if (_documentView != nil)
-    {
-      NSNotificationCenter *nc = [NSNotificationCenter defaultCenter];
-      
-      [nc removeObserver: self  name: nil  object: _documentView];
-      if ([_documentView isKindOfClass: [NSTableView class]])
-	{
-	  [nc removeObserver: _documentView name:nil object:self];
-	}
-
-      /* Don't RELEASE(_documentView), since it's already in our subviews. */
-    }
+  [self setDocumentView: nil];
   RELEASE(_cursor);
   RELEASE(_backgroundColor);
 
@@ -133,13 +125,21 @@ static inline NSRect integralRect (NSRect rect, NSView *view)
   nc = [NSNotificationCenter defaultCenter];
   if (_documentView)
     {
-      [nc removeObserver: self  name: nil  object: _documentView];
+      [nc removeObserver: self
+	  name: NSViewFrameDidChangeNotification
+	  object: _documentView];
+      [nc removeObserver: self
+	  name: NSViewBoundsDidChangeNotification
+	  object: _documentView];
+
       /* if our documentView was a tableview, unregister its
        * observers
        */
       if ([_documentView isKindOfClass: [NSTableView class]])
 	{
-	  [nc removeObserver: _documentView name: nil object: self];
+	  [nc removeObserver: _documentView 
+	      name: NSViewFrameDidChangeNotification 
+	      object: self];
 	}
       [_documentView removeFromSuperview];
     }
@@ -189,7 +189,6 @@ static inline NSRect integralRect (NSRect rect, NSView *view)
        */
       if ([_documentView isKindOfClass: [NSTableView class]])
 	{
-	  [nc removeObserver: _documentView name: nil object: self];
 	  [self setPostsFrameChangedNotifications: YES];
 	  [nc addObserver: _documentView
 	         selector: @selector(superviewFrameChanged:)
@@ -214,6 +213,20 @@ static inline NSRect integralRect (NSRect rect, NSView *view)
   [self setBoundsOrigin: [self constrainScrollPoint: aPoint]];
 }
 
+- (void) setBounds: (NSRect)b
+{
+  // FIXME: Shouldn't the document view be marked as needing a redraw?
+  [super setBounds: b];
+  [_super_view reflectScrolledClipView: self];
+}
+
+- (void) setBoundsSize: (NSSize)aSize
+{
+  // FIXME: Shouldn't the document view be marked as needing a redraw?
+  [super setBoundsSize: aSize];
+  [_super_view reflectScrolledClipView: self];
+}
+
 - (void) setBoundsOrigin: (NSPoint)aPoint
 {
   NSRect originalBounds = _bounds;
@@ -222,7 +235,7 @@ static inline NSRect integralRect (NSRect rect, NSView *view)
 
   newBounds.origin = aPoint;
 
-  if (NSEqualPoints (originalBounds.origin, newBounds.origin))
+  if (NSEqualPoints(originalBounds.origin, newBounds.origin))
     {
       return;
     }
@@ -235,8 +248,8 @@ static inline NSRect integralRect (NSRect rect, NSView *view)
   if (_copiesOnScroll && _window && [_window gState])
     {
       /* Copy the portion of the view that is common before and after
-	 scrolling.  Then, document view needs to redraw the remaining
-	 areas. */
+         scrolling.  Then, document view needs to redraw the remaining
+         areas. */
 
 	
 
@@ -245,110 +258,99 @@ static inline NSRect integralRect (NSRect rect, NSView *view)
       intersection = NSIntersectionRect (originalBounds, newBounds);
 
       /* but we must make sure we only copy from visible rect - we
-	 can't copy bits which have been clipped (ie discarded) */
+         can't copy bits which have been clipped (ie discarded) */
       intersection = NSIntersectionRect (intersection, [self visibleRect]);
 
       /* Copying is done in device space so we only can copy by
-	 integral rects in device space - adjust our copy rect */
+         integral rects in device space - adjust our copy rect */
       intersection = integralRect (intersection, self);
 
       /* At this point, intersection is the rectangle containing the
-	 image we can recycle from the old to the new situation.  We
-	 must not make any assumption on its position/size, because it
-	 has been intersected with visible rect, which is an arbitrary
-	 rectangle as far as we know. */
+         image we can recycle from the old to the new situation.  We
+         must not make any assumption on its position/size, because it
+         has been intersected with visible rect, which is an arbitrary
+         rectangle as far as we know. */
       if (NSEqualRects (intersection, NSZeroRect))
-	{
-	  // no recyclable part -- docview should redraw everything
-	  // from scratch
-	  [super setBoundsOrigin: newBounds.origin];
-	  [_documentView setNeedsDisplayInRect: 
-			   [self documentVisibleRect]];
-	}
+        {
+          // no recyclable part -- docview should redraw everything
+          // from scratch
+          [super setBoundsOrigin: newBounds.origin];
+          [_documentView setNeedsDisplayInRect: 
+                             [self documentVisibleRect]];
+        }
       else
-	{
-	  /* Copy the intersection to the new position */
-	  NSPoint destPoint = intersection.origin;
-	  float dx = newBounds.origin.x - originalBounds.origin.x;
-	  float dy = newBounds.origin.y - originalBounds.origin.y;
-	  NSRect redrawRect;
-	  
-	  /* It is assumed these dx and dy will be integer in device
-	     space because they are the difference of the bounds
-	     origins, both of which should be integers in device space
-	     because of the code at the end of
-	     constrainScrollPoint:. */
-	  destPoint.x -= dx;
-	  destPoint.y -= dy;
+        {
+          /* It is assumed these dx and dy will be integer in device
+             space because they are the difference of the bounds
+             origins, both of which should be integers in device space
+             because of the code at the end of
+             constrainScrollPoint:. */
+          float dx = newBounds.origin.x - originalBounds.origin.x;
+          float dy = newBounds.origin.y - originalBounds.origin.y;
+          NSRect redrawRect;
+                    
+          /* Copy the intersection to the new position */
+          [self scrollRect: intersection by: NSMakeSize(dx, dy)];
 
-	  /* Now copy ! */
-	  [self lockFocus];
-	  /* NB: Because of all the previous comments, we are sure the
-             following is copying an integer rectangle by an integer
-             amount (`integer' in device space) - which should cause
-             no problems */
-	  NSCopyBits (0, intersection, destPoint);
-	  [self unlockFocus];
-
-	  /* Change coordinate system to the new one */
-	  [super setBoundsOrigin: newBounds.origin];
-
-	  /* Get the rectangle representing intersection in the new
+          /* Change coordinate system to the new one */
+          [super setBoundsOrigin: newBounds.origin];
+        
+          /* Get the rectangle representing intersection in the new
              bounds (mainly to keep code readable) */
-	  intersection.origin.x = destPoint.x;
-	  intersection.origin.y = destPoint.y;
-	  // intersection.size is the same
-
-	  /* Now mark everything which is outside intersection as
+          intersection.origin.x -= dx;
+          intersection.origin.y -= dy;
+          // intersection.size is the same
+          
+          /* Now mark everything which is outside intersection as
              needing to be redrawn by hand.  NB: During simple usage -
              scrolling in a single direction (left/rigth/up/down) -
              and a normal visible rect, only one of the following
              rects will be non-empty. */
-
-	  /* To the left of intersection */
-	  redrawRect = NSMakeRect (NSMinX (_bounds), _bounds.origin.y,
-				   NSMinX (intersection) - NSMinX (_bounds),
-				   _bounds.size.height);
-	  if (NSIsEmptyRect (redrawRect) == NO)
-	    {
-	      [_documentView setNeedsDisplayInRect: 
-			       [self convertRect: redrawRect 
-				     toView: _documentView]];
-	    }
-
-	  /* Right */
-	  redrawRect = NSMakeRect (NSMaxX (intersection), _bounds.origin.y,
-				   NSMaxX (_bounds) - NSMaxX (intersection),
-				   _bounds.size.height);
-	  if (NSIsEmptyRect (redrawRect) == NO)
-	    {
-	      [_documentView setNeedsDisplayInRect: 
-			       [self convertRect: redrawRect 
-				     toView: _documentView]];
-	    }
-
-	  /* Up (or Down according to whether it's flipped or not) */
-	  redrawRect = NSMakeRect (_bounds.origin.x, NSMinY (_bounds),
-				   _bounds.size.width, 
-				   NSMinY (intersection) - NSMinY (_bounds));
-	  if (NSIsEmptyRect (redrawRect) == NO)
-	    {
-	      [_documentView setNeedsDisplayInRect: 
-			       [self convertRect: redrawRect 
-				     toView: _documentView]];
-	    }
-
-	  /* Down (or Up) */
-	  redrawRect = NSMakeRect (_bounds.origin.x, NSMaxY (intersection),
-				   _bounds.size.width, 
-				   NSMaxY (_bounds) - NSMaxY (intersection));
-	  if (NSIsEmptyRect (redrawRect) == NO)
-	    {
-	      [_documentView setNeedsDisplayInRect: 
-			       [self convertRect: redrawRect 
-				     toView: _documentView]];
-	    }
-	}
+          
+          /* To the left of intersection */
+          redrawRect = NSMakeRect(NSMinX(_bounds), _bounds.origin.y,
+                                  NSMinX(intersection) - NSMinX(_bounds),
+                                  _bounds.size.height);
+          if (NSIsEmptyRect(redrawRect) == NO)
+            {
+              [_documentView setNeedsDisplayInRect: 
+                                 [self convertRect: redrawRect 
+                                       toView: _documentView]];
+            }
+          
+          /* Right */
+          redrawRect = NSMakeRect(NSMaxX(intersection), _bounds.origin.y,
+                                  NSMaxX(_bounds) - NSMaxX(intersection),
+                                  _bounds.size.height);
+          if (NSIsEmptyRect(redrawRect) == NO)
+            {
+              [_documentView setNeedsDisplayInRect: 
+                                 [self convertRect: redrawRect 
+                                       toView: _documentView]];
+            }
+          
+          /* Up (or Down according to whether it's flipped or not) */
+          redrawRect = NSMakeRect(_bounds.origin.x, NSMinY(_bounds),
+                                  _bounds.size.width, 
+                                  NSMinY(intersection) - NSMinY(_bounds));
+          if (NSIsEmptyRect(redrawRect) == NO)
+            {
+              [_documentView setNeedsDisplayInRect: 
+                                 [self convertRect: redrawRect 
+                                       toView: _documentView]];
+            }
+          
+          /* Down (or Up) */
+          redrawRect = NSMakeRect(_bounds.origin.x, NSMaxY(intersection),
+                                  _bounds.size.width, 
+                                  NSMaxY(_bounds) - NSMaxY(intersection));
+          if (NSIsEmptyRect(redrawRect) == NO)
+            {
+              [_documentView setNeedsDisplayInRect: 
+                                 [self convertRect: redrawRect 
+                                       toView: _documentView]];
+            }
+        }
     }
   else
     {
@@ -425,15 +427,13 @@ static inline NSRect integralRect (NSRect rect, NSView *view)
      If _copiesOnScroll is set, we make sure the difference between old
      position and new position is an integer so we can copy the image 
      easily. 
+     FIXME: Why should this help? If the value is integral in user space this does 
+     not mean anything in device space.
   */
   if (_copiesOnScroll)
     {
-      new.x =
-	_bounds.origin.x + 
-	(rint(new.x - _bounds.origin.x));
-      new.y =
-	_bounds.origin.y +
-	(rint(new.y - _bounds.origin.y));
+      new.x = _bounds.origin.x + (rint(new.x - _bounds.origin.x));
+      new.y = _bounds.origin.y + (rint(new.y - _bounds.origin.y));
     }
 
   return new;
@@ -462,26 +462,14 @@ static inline NSRect integralRect (NSRect rect, NSView *view)
   return rect;
 }
 
-/**<p>Returns the document visible rectangle. Returns NSZeroRect if the 
-   document view does not exists.</p>
- <p>See Also: -documentRect [NSView-convertRect:toView:]</p>
+/**<p>Returns the document visible rectangle in the document views coordinate
+ * system.
+ * </p>
+ * <p>See Also: -documentRect [NSView-convertRect:toView:]</p>
  */
 - (NSRect) documentVisibleRect
 {
-  NSRect documentBounds;
-  NSRect clipViewBounds;
-  NSRect rect;
-
-  if (_documentView == nil)
-    {
-      return NSZeroRect;
-    }
-
-  documentBounds = [_documentView bounds];
-  clipViewBounds = [self convertRect: _bounds  toView: _documentView];
-  rect = NSIntersectionRect (documentBounds, clipViewBounds);
-
-  return rect;
+  return [self convertRect: _bounds toView:_documentView];
 }
 
 - (void) drawRect: (NSRect)rect
@@ -546,7 +534,7 @@ static inline NSRect integralRect (NSRect rect, NSView *view)
  */
 - (void) viewFrameChanged: (NSNotification*)aNotification
 {
-  [self setBoundsOrigin: [self constrainScrollPoint: _bounds.origin]];
+  [self scrollToPoint: _bounds.origin];
 
   /* If document frame does not completely cover _bounds */
   if (NSContainsRect([_documentView frame], _bounds) == NO)
@@ -566,12 +554,6 @@ static inline NSRect integralRect (NSRect rect, NSView *view)
   [_super_view reflectScrolledClipView: self];
 }
 
-- (void) setBoundsSize: (NSSize)aSize
-{
-  [super setBoundsSize: aSize];
-  [_super_view reflectScrolledClipView: self];
-}
-
 - (void) setFrameSize: (NSSize)aSize
 {
   [super setFrameSize: aSize];
@@ -627,7 +609,7 @@ static inline NSRect integralRect (NSRect rect, NSView *view)
  */
 - (void) setDocumentCursor: (NSCursor*)aCursor
 {
-  ASSIGN (_cursor, aCursor);
+  ASSIGN(_cursor, aCursor);
 }
 
 /**<p>Returns the cursor of the document view</p>
@@ -674,7 +656,7 @@ static inline NSRect integralRect (NSRect rect, NSView *view)
   
 }
 
-- (void) setDrawsBackground:(BOOL)flag
+- (void) setDrawsBackground: (BOOL)flag
 {
   if (_drawsBackground != flag)
     {
@@ -753,16 +735,16 @@ static inline NSRect integralRect (NSRect rect, NSView *view)
 - (void) encodeWithCoder: (NSCoder*)aCoder
 {
   [super encodeWithCoder: aCoder];
-  if([aCoder allowsKeyedCoding])
+  if ([aCoder allowsKeyedCoding])
     {
       unsigned int flags = 0;
       [aCoder encodeObject: [self backgroundColor] forKey: @"NSBGColor"];
       [aCoder encodeObject: [self documentCursor] forKey: @"NSCursor"];
       [aCoder encodeObject: [self documentView] forKey: @"NSDocView"];
       
-      if([self drawsBackground])
+      if ([self drawsBackground])
 	flags |= 4;
-      if([self copiesOnScroll] == NO)
+      if ([self copiesOnScroll] == NO)
 	flags |= 2;
 
       [aCoder encodeInt: flags forKey: @"NScvFlags"];
