@@ -50,7 +50,7 @@
 #include "AppKit/NSTableColumn.h"
 #include "AppKit/NSTableView.h"
 #include "AppKit/NSTextView.h"
-#include "GNUstepGUI/GSDrawFunctions.h"
+#include "GNUstepGUI/GSTheme.h"
 
 static NSNotificationCenter *nc;
 static const BOOL ForceBrowser = NO;
@@ -697,21 +697,25 @@ static GSComboWindow *gsWindow = nil;
     {
       NSText	*textObject = nil;
       id	cv = [_cell controlView];
+      int 	index = [_cell indexOfSelectedItem];
       
       if ([cv isKindOfClass: [NSControl class]])
         {
 	  textObject = [(NSControl *)cv currentEditor];
 	}
       
-      [_cell setStringValue: [_cell _stringValueAtIndex: 
-        [_cell indexOfSelectedItem]]]; 
-      // Will update the editor when needed
+      if (index != -1)
+        {
+          [_cell setStringValue: [_cell _stringValueAtIndex: 
+            [_cell indexOfSelectedItem]]]; 
+          // Will update the editor when needed
       
-      // FIXME: Because NSCell doesn't behave correctly the line just over has 
-      // no effect, to correct this fact, the code below is needed.
-      [textObject setString: [_cell _stringValueAtIndex:
-        [_cell indexOfSelectedItem]]];
-      // End of the code to remove 
+          // FIXME: Because NSCell doesn't behave correctly the line just over has 
+          // no effect, to correct this fact, the code below is needed.
+          [textObject setString: [_cell _stringValueAtIndex:
+          [_cell indexOfSelectedItem]]];
+          // End of the code to remove 
+        }
       
       if  (textObject != nil)
         {
@@ -1654,7 +1658,7 @@ static inline NSRect buttonCellFrameFromRect(NSRect cellRect)
 {
   [super encodeWithCoder: coder];
 
-  if([coder allowsKeyedCoding])
+  if ([coder allowsKeyedCoding])
     {
       [coder encodeBool: [self hasVerticalScroller] forKey: @"NSHasVerticalScroller"];
       [coder encodeInt: [self numberOfVisibleItems] forKey: @"NSVisibleItemCount"];
@@ -1981,10 +1985,7 @@ static inline NSRect buttonCellFrameFromRect(NSRect cellRect)
     {
       [self _setSelectedItem: index];
     }
-  else 
-    {
-      [self _setSelectedItem: -1];
-    }
+  // Otherwise keep old selection
 }
 
 @end
