@@ -31,6 +31,7 @@
 
 #include <Foundation/NSDebug.h>
 #include <Foundation/NSException.h>
+#include <Foundation/NSNotification.h>
 #include "AppKit/NSActionCell.h"
 #include "AppKit/NSApplication.h"
 #include "AppKit/NSCell.h"
@@ -47,6 +48,7 @@
 static Class usedCellClass;
 static Class cellClass;
 static Class actionCellClass;
+static NSNotificationCenter *nc;
 
 /**<p>TODO Description</p>
  */
@@ -64,6 +66,8 @@ static Class actionCellClass;
       cellClass = [NSCell class];
       usedCellClass = cellClass;
       actionCellClass = [NSActionCell class];
+      // Cache the notifiaction centre for editing notifications
+      nc = [NSNotificationCenter defaultCenter];
     }
 }
 
@@ -440,6 +444,21 @@ static Class actionCellClass;
   return [_cell formatter];
 }
 
+- (NSWritingDirection) baseWritingDirection
+{
+  return [_cell baseWritingDirection];
+}
+
+- (void) setBaseWritingDirection: (NSWritingDirection)direction
+{
+  if (_cell)
+    {
+      [_cell setBaseWritingDirection: direction];
+      if (![_cell isKindOfClass: actionCellClass])
+	[self setNeedsDisplay: YES];
+    }
+}
+
 /**<p>Sends an [NSCell-endEditing:] message to the current object used to
    edit the NSControl. Returns NO if the the currentEditor does not exists, 
    YES otherwise.</p>
@@ -508,6 +527,70 @@ static Class actionCellClass;
     }
 }
 
+/* 
+ * Text delegate methods 
+ */
+
+/**<p>Invokes when the text cell starts to be editing.This methods posts 
+   a NSControlTextDidBeginEditingNotification with a dictionary containing 
+   the NSFieldEditor as user info </p><p>See Also:
+   [NSNotificationCenter-postNotificationName:object:userInfo:]</p>
+*/
+- (void) textDidBeginEditing: (NSNotification *)aNotification
+{
+  NSMutableDictionary *dict;
+
+  dict = [[NSMutableDictionary alloc] initWithDictionary: 
+					[aNotification userInfo]];
+  [dict setObject: [aNotification object] forKey: @"NSFieldEditor"];
+
+  [nc postNotificationName: NSControlTextDidBeginEditingNotification
+      object: self
+      userInfo: dict];
+  RELEASE(dict);
+}
+
+/**<p>Invokes when the text cell is changed. This methods posts a 
+   NSControlTextDidChangeNotification with a dictionary containing the
+   NSFieldEditor as user info </p><p>See Also: 
+   [NSNotificationCenter-postNotificationName:object:userInfo:]</p>
+*/
+- (void) textDidChange: (NSNotification *)aNotification
+{
+  NSMutableDictionary *dict;
+
+  dict = [[NSMutableDictionary alloc] initWithDictionary: 
+				     [aNotification userInfo]];
+  [dict setObject: [aNotification object] forKey: @"NSFieldEditor"];
+
+  [nc postNotificationName: NSControlTextDidChangeNotification
+      object: self
+      userInfo: dict];
+  RELEASE(dict);
+}
+
+/**<p>Invokes when the text cell is changed.
+   This methods posts a NSControlTextDidEndEditingNotification
+   a dictionary containing the NSFieldEditor as user info </p><p>See Also:
+   [NSNotificationCenter-postNotificationName:object:userInfo:]</p>
+*/
+- (void) textDidEndEditing: (NSNotification *)aNotification
+{
+  NSMutableDictionary *dict;
+
+  [self validateEditing];
+  [self abortEditing];
+
+  dict = [[NSMutableDictionary alloc] initWithDictionary: 
+					[aNotification userInfo]];
+  [dict setObject: [aNotification object] forKey: @"NSFieldEditor"];
+
+  [nc postNotificationName: NSControlTextDidEndEditingNotification
+      object: self
+      userInfo: dict];
+  RELEASE(dict);
+}
+
 /**<p>Recalculates the internal size by sending [NSCell-calcDrawInfo:] 
    to the cell.</p>
  */
@@ -675,7 +758,7 @@ static Class actionCellClass;
       return AUTORELEASE([NSAttributedString new]);
     }
 
-  // As this mehtod is not defined for NSActionCell, we have 
+  // As this method is not defined for NSActionCell, we have 
   // to do the validation here.
   [self validateEditing];
 
@@ -726,88 +809,68 @@ static Class actionCellClass;
   return [[self selectedCell] acceptsFirstResponder];
 }
 
-/** <p>This method is invoked when the user click into the NSControl.</p>
-    
- * 
- */
+
 - (void) mouseDown: (NSEvent *)theEvent
 {
-  NSApplication *theApp = [NSApplication sharedApplication];
-  BOOL mouseUp = NO, done = NO;
-  NSEvent *e;
-  int oldActionMask;
-  NSPoint location;
   unsigned int event_mask = NSLeftMouseDownMask | NSLeftMouseUpMask
     | NSMouseMovedMask | NSLeftMouseDraggedMask | NSOtherMouseDraggedMask
     | NSRightMouseDraggedMask;
+  NSEvent *e = nil;
 
+  // If not enabled ignore mouse clicks
   if (![self isEnabled])
     return;
 
+  // Ignore multiple clicks, if configured to do so
   if (_ignoresMultiClick && ([theEvent clickCount] > 1))
     {  
       [super mouseDown: theEvent];
       return;
     }
 
-  if ([_cell isContinuous])
-    {
-      oldActionMask = [_cell sendActionOn: NSPeriodicMask];
-    }
-  else
-    {
-      oldActionMask = [_cell sendActionOn: 0];
-    }
-  
-  [_window _captureMouse: self];
+  // Make sure self does not go away during the processing of the event
+  RETAIN(self); 
 
-  e = theEvent;
   // loop until mouse goes up
-  while (!done)
+  e = theEvent;
+  while (1)
     {
-      location = [e locationInWindow];
-      location = [self convertPoint: location fromView: nil];
-      // ask the cell to track the mouse only
+      NSPoint location = [self convertPoint: [e locationInWindow] 
+			       fromView: nil];
+
+      // ask the cell to track the mouse only,
       // if the mouse is within the cell
       if ([self mouse: location inRect: _bounds])
 	{
+	  BOOL done;
+
 	  [_cell setHighlighted: YES];
 	  [self setNeedsDisplay: YES];
-	  if ([_cell trackMouse: e
-		     inRect: _bounds
-		     ofView: self
-		     untilMouseUp: [[_cell class] prefersTrackingUntilMouseUp]])
-	    done = mouseUp = YES;
-	  else
+	  done = [_cell trackMouse: e
+			inRect: _bounds	
+			ofView: self	
+			untilMouseUp: [[_cell class] prefersTrackingUntilMouseUp]];
+	  [_cell setHighlighted: NO];
+	  [self setNeedsDisplay: YES];
+
+	  if (done)
 	    {
-	      [_cell setHighlighted: NO];
-	      [self setNeedsDisplay: YES];
+	      break;
 	    }
 	}
 
-      if (done)
-	break;
-
-      e = [theApp nextEventMatchingMask: event_mask
-			      untilDate: nil
-				 inMode: NSEventTrackingRunLoopMode
-				dequeue: YES];
+      e = [NSApp nextEventMatchingMask: event_mask
+		 untilDate: nil
+		 inMode: NSEventTrackingRunLoopMode
+		 dequeue: YES];
       if ([e type] == NSLeftMouseUp)
-	done = YES;
+        {
+	  break;
+        }
     }
 
-  [_window _releaseMouse: self];
-
-  if (mouseUp)
-    {
-      [_cell setHighlighted: NO];
-      [self setNeedsDisplay: YES];
-    }
-
-  [_cell sendActionOn: oldActionMask];
-
-  if (mouseUp)
-    [self sendAction: [self action] to: [self target]];
+  // undo initial retain
+  RELEASE(self); 
 }
 
 - (BOOL) shouldBeTreatedAsInkEvent: (NSEvent *)theEvent
@@ -843,7 +906,7 @@ static Class actionCellClass;
 - (void) encodeWithCoder: (NSCoder*)aCoder
 {
   [super encodeWithCoder: aCoder];
-  if([aCoder allowsKeyedCoding])
+  if ([aCoder allowsKeyedCoding])
     {
       [aCoder encodeObject: [self cell] forKey: @"NSCell"];
       [aCoder encodeBool: [self isEnabled] forKey: @"NSEnabled"];
