@@ -24,7 +24,7 @@
    You should have received a copy of the GNU Library General Public
    License along with this library; see the file COPYING.LIB.
    If not, write to the Free Software Foundation,
-   59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */ 
 
 #include "config.h"
@@ -111,8 +111,7 @@ static float sizes[] = {4.0, 6.0, 8.0, 9.0, 10.0, 11.0, 12.0, 13.0,
     }
 }
 
-/*
- * Creating an NSFontPanel 
+/** <p>Creates ( if needed ) and returns the shared NSFontPanel.</p> 
  */
 + (NSFontPanel*) sharedFontPanel
 {
@@ -156,8 +155,8 @@ static float sizes[] = {4.0, 6.0, 8.0, 9.0, 10.0, 11.0, 12.0, 13.0,
   [super dealloc];
 }
 
-/*
- * Enabling
+/** <p>Returns whether the "set" button is enabled.</p>
+    <p>See Also: -setEnabled:</p>
  */
 - (BOOL) isEnabled
 {
@@ -166,6 +165,9 @@ static float sizes[] = {4.0, 6.0, 8.0, 9.0, 10.0, 11.0, 12.0, 13.0,
   return [setButton isEnabled];
 }
 
+/**<p>Sets whether the "set" button is enabled.</p>
+   <p>See Also: -isEnabled</p>
+ */
 - (void) setEnabled: (BOOL)flag
 {
   NSButton *setButton = [[self contentView] viewWithTag: NSFPSetButton];
@@ -213,9 +215,6 @@ static float sizes[] = {4.0, 6.0, 8.0, 9.0, 10.0, 11.0, 12.0, 13.0,
 	isMultiple: [fm isMultiple]];
 }
 
-/*
- * Setting the Font 
- */
 - (void) setPanelFont: (NSFont *)fontObject
 	   isMultiple: (BOOL)flag
 {
@@ -295,8 +294,7 @@ static float sizes[] = {4.0, 6.0, 8.0, 9.0, 10.0, 11.0, 12.0, 13.0,
     }
 }
 
-/*
- * Converting
+/**<p>Converts the NSFont <var>fontObject</var></p>
  */
 - (NSFont *) panelConvertFont: (NSFont *)fontObject
 {
@@ -323,38 +321,24 @@ static float sizes[] = {4.0, 6.0, 8.0, 9.0, 10.0, 11.0, 12.0, 13.0,
   return newFont;
 }
 
-/*
- * Works in modal loops
+/**<p>Overides the NSPanel/NSWindow method to always returns YES</p>
  */
 - (BOOL) worksWhenModal
 {
   return YES;
 }
 
-/*
- * Configuring the NSFontPanel 
+/** <p>Returns the NSFontPanel's accessory view.</p>
+    <p>See Also: -setAccessoryView:</p>
  */
 - (NSView*) accessoryView
 {
   return _accessoryView;
 }
 
-/*
-- (void) setAccessoryView: (NSView*)aView
-{
-
-  // FIXME: We have to resize
-  // Perhaps we could copy the code from NSSavePanel over to here
-  if (_accessoryView != nil)
-    {
-      [_accessoryView removeFromSuperview];
-    }
-
-  ASSIGN(_accessoryView, aView);
-  [[self contentView] addSubview: aView];
-}
-*/
-
+/** <p>Sets the NSFontPanel's accessory view to <var>aView</var></p>
+    <p>See Also: -accessoryView</p>
+ */
 - (void) setAccessoryView: (NSView*)aView
 {
   NSRect accessoryViewFrame, bottomFrame;
