@@ -22,7 +22,7 @@
    You should have received a copy of the GNU Library General Public
    License along with this library; see the file COPYING.LIB.
    If not, write to the Free Software Foundation,
-   59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */ 
 
 #include "config.h"
@@ -80,7 +80,7 @@ static Class defaultCellClass = nil;
      numberOfColumns: (int)colsWide
 {
   self = [super initWithFrame: (NSRect)frameRect
-			 mode: (int)aMode
+		 mode: (int)aMode
 		    prototype: (NSCell*)prototype
 		 numberOfRows: (int)rowsHigh
 	      numberOfColumns: (int)colsWide];
@@ -89,11 +89,19 @@ static Class defaultCellClass = nil;
   return self;
 }
 
+/** <p>Adds a new entry with title as its title at the end of the NSForm
+    and returns the NSFormCell.</p><p>See Also: -insertEntry:atIndex:
+    -removeEntryAtIndex:</p>
+ */
 - (NSFormCell*) addEntry: (NSString*)title
 {
   return [self insertEntry: title atIndex: [self numberOfRows]];
 }
 
+/** <p>Inserts a new entry with title as its title at the index index of
+    the NSForm and returns the NSFormCell.</p>
+    <p>See Also: -addEntry: -removeEntryAtIndex:</p>
+ */
 - (NSFormCell*) insertEntry: (NSString*)title
 		    atIndex: (int)index
 {
@@ -106,6 +114,9 @@ static Class defaultCellClass = nil;
   return new_cell;
 }
 
+/** <p>Removes the entry at index index. </p>
+    <p>See Also: -insertEntry:atIndex: -addEntry:</p>
+ */
 - (void) removeEntryAtIndex: (int)index
 {
   [[NSNotificationCenter defaultCenter] 
@@ -131,7 +142,7 @@ static Class defaultCellClass = nil;
   
   [[NSNotificationCenter defaultCenter]
     addObserver: self
-    selector: @selector(_setTitleWidthNeedsUpdate: )
+    selector: @selector(_setTitleWidthNeedsUpdate:)
     name: _NSFormCellDidChangeTitleWidthNotification
     object: newCell];
 }
@@ -146,6 +157,9 @@ static Class defaultCellClass = nil;
   [super dealloc];
 }
 
+/** <p>Sets whether then NSForm's entries have bezeled border.</p>
+    <p>See Also: [NSCell-setBezeled:]</p>
+ */
 - (void) setBezeled: (BOOL)flag
 {
   int i, count = [self numberOfRows];
@@ -157,6 +171,9 @@ static Class defaultCellClass = nil;
     [[self cellAtRow: i column: 0] setBezeled: flag];
 }
 
+/** <p>Sets whether then NSForm's entries have border</p>
+    <p>See Also: [NSCell-setBordered:]</p>
+ */
 - (void) setBordered: (BOOL)flag
 {
   int i, count = [self numberOfRows];
@@ -168,6 +185,9 @@ static Class defaultCellClass = nil;
     [[self cellAtRow: i column: 0] setBordered: flag];
 }
 
+/**<p>Sets the width of all entries to width</p> 
+   <p>See Also: [NSMatrix-setCellSize:]</p>
+ */
 - (void) setEntryWidth: (float)width
 {
   NSSize size = [self cellSize];
@@ -176,6 +196,9 @@ static Class defaultCellClass = nil;
   [self setCellSize: size];
 }
 
+/** <p>Sets the spacing between all entries to spacing. By default
+    the spacing is 4.</p><p>See Also: [NSMatrix-setIntercellSpacing:]</p>
+ */
 - (void) setInterlineSpacing: (float)spacing
 {
   [self setIntercellSpacing: NSMakeSize(0, spacing)];
@@ -184,6 +207,12 @@ static Class defaultCellClass = nil;
 /* For the title attributes we use the corresponding attributes from the cell.
    For the text attributes we use instead the attributes inherited from the
    NSCell class. */
+
+/** <p>Sets the text alignment of the title to aMode for all entries.
+    See <ref type="type" id="NSTextAlignment">NSTextAlignment</ref> for more
+    informations. The default title alignment is NSLeftTextAlignment</p> 
+    <p>See Also:  [NSFormCell-setTitleAlignment:] -setTextAlignment: </p>
+ */
 - (void) setTitleAlignment: (NSTextAlignment)aMode
 {
   int i, count = [self numberOfRows];
@@ -195,6 +224,11 @@ static Class defaultCellClass = nil;
     [[self cellAtRow: i column: 0] setTitleAlignment: aMode];
 }
 
+/** <p>Sets the text alignment to aMode for all entries. See
+    <ref type="type" id="NSTextAlignment">NSTextAlignment</ref> for more
+    informations. The default text alignment is NSRightTextAlignment</p> 
+    <p>See Also: -setTitleAlignment: [NSCell-setAlignment:]</p>
+ */
 - (void) setTextAlignment: (int)aMode
 {
   int i, count = [self numberOfRows];
@@ -206,6 +240,9 @@ static Class defaultCellClass = nil;
     [[self cellAtRow: i column: 0] setAlignment: aMode];
 }
 
+/** <p>Sets the text font of the title to fontObject for all entries</p>
+    <p>See Also: [NSFormCell-setTitleFont:] -setTextFont:</p>
+ */
 - (void) setTitleFont: (NSFont*)fontObject
 {
   int i, count = [self numberOfRows];
@@ -217,6 +254,9 @@ static Class defaultCellClass = nil;
     [[self cellAtRow: i column: 0] setTitleFont: fontObject];
 }
 
+/** <p>Sets the text font to fontObject for all entries</p>
+    <p>See Also: [NSCell-setFont:] -setTitleFont:</p>
+ */
 - (void) setTextFont: (NSFont*)fontObject
 {
   int i, count = [self numberOfRows];
@@ -228,6 +268,9 @@ static Class defaultCellClass = nil;
     [[self cellAtRow: i column: 0] setFont: fontObject];
 }
 
+/**<p>Returns the index of the entry specified by aTag or -1 if aTag is not 
+   found in entries.</p><p>See Also: [NSMatrix-cellAtRow:column:]</p>
+ */
 - (int) indexOfCellWithTag: (int)aTag
 {
   int i, count = [self numberOfRows];
@@ -238,11 +281,17 @@ static Class defaultCellClass = nil;
   return -1;
 }
 
+/**<p>Returns the index of the current selected entry.</p>
+   <p>[NSMatrix-selectedRow]</p>
+ */
 - (int) indexOfSelectedItem
 {
   return [self selectedRow];
 }
 
+/**<p>Returns the NSFormCell at index <var>index</var></p>
+   <p>See Also: [NSMatrix-cellAtRow:column:]</p>
+ */
 - (id) cellAtIndex: (int)index
 {
   return [self cellAtRow: index column: 0];
@@ -293,6 +342,10 @@ static Class defaultCellClass = nil;
   [super drawRect: rect];
 }
 
+/** <p>Draws the NSFormCell at the specified index</p>
+    <p>See Also: -cellAtIndex: [NSCell-drawWithFrame:inView:]
+    [NSMatrix-cellFrameAtRow:column:]</p>
+ */
 - (void) drawCellAtIndex: (int)index
 {
   id theCell = [self cellAtIndex: index];
@@ -306,6 +359,9 @@ static Class defaultCellClass = nil;
   [self drawCellAtIndex: row];
 }
 
+/** <p>Selects the text in the entry specified by index.</p>
+    <p>[NSMatrix-selectTextAtRow:column:]</p>
+ */
 - (void) selectTextAtIndex: (int)index
 {
   [self selectTextAtRow: index column: 0];
