@@ -23,7 +23,8 @@
    
    You should have received a copy of the GNU Library General Public
    License along with this library; if not, write to the Free
-   Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111 USA.
+   Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02111 USA.
 */
    
 
@@ -295,12 +296,12 @@ NSGraphicsContext	*GSCurrentContext(void)
   return context_info;
 }
 
-- (void)flushGraphics
+- (void) flushGraphics
 {
   [self subclassResponsibility: _cmd];
 }
 
-- (void *)graphicsPort
+- (void *) graphicsPort
 {
   return NULL;
 }
