@@ -27,6 +27,7 @@
 */ 
 
 #include <Foundation/NSUserDefaults.h>
+#include <Foundation/NSData.h>
 #include <Foundation/NSNotification.h>
 #include <Foundation/NSFileManager.h>
 #include <Foundation/NSString.h>
@@ -35,14 +36,22 @@
 #include "AppKit/NSAttributedString.h"
 #include "AppKit/NSApplication.h"
 #include "AppKit/NSWorkspace.h"
+#include "AppKit/NSFileWrapper.h"
 #include "AppKit/NSHelpManager.h"
+#include "AppKit/NSHelpPanel.h"
+#include "AppKit/NSHelpPanel.h"
+#include "AppKit/NSCursor.h"
+#include "AppKit/NSImage.h"
 #include "AppKit/NSGraphics.h"
+#include "AppKit/NSScrollView.h"
+#include "AppKit/NSTextView.h"
+#include "AppKit/NSTextStorage.h"
 
 #include "GNUstepGUI/GSHelpManagerPanel.h"
 
 @implementation NSBundle (NSHelpManager)
 
-- (NSString *)pathForHelpResource:(NSString *)fileName
+- (NSString *) pathForHelpResource: (NSString *)fileName
 {
   NSFileManager *fm = [NSFileManager defaultManager];
   NSMutableArray *array = [NSMutableArray array];
@@ -59,6 +68,7 @@
   while ((language = [enumerator nextObject]))
     {
       NSString *langDir = [NSString stringWithFormat: @"%@.lproj", language];
+
       [array addObject: [primary stringByAppendingPathComponent: langDir]];
     }
   
@@ -71,6 +81,7 @@
   while ((language = [enumerator nextObject]))
     {
       NSString *langDir = [NSString stringWithFormat: @"%@.lproj", language];
+
       [array addObject: [primary stringByAppendingPathComponent: langDir]];
     }
   
@@ -107,7 +118,7 @@
   return nil;
 }
 
-- (NSAttributedString *)contextHelpForKey:(NSString *)key
+- (NSAttributedString *) contextHelpForKey: (NSString *)key
 {
   NSFileManager *fm = [NSFileManager defaultManager];
   NSString *dictPath = [self pathForResource: @"Help" ofType: @"plist"];
@@ -127,18 +138,20 @@
   if (helpFile)
     {
       NSData *data = [helpFile objectForKey: @"NSHelpRTFContents"];
-      return ((data != nil) ? [NSUnarchiver unarchiveObjectWithData: data] :
-        nil) ;
+      return ((data != nil) ? [NSUnarchiver unarchiveObjectWithData: data]
+	: nil);
       
     } 
-    else
+  else
     {
       helpFile = [self pathForHelpResource: key];
 
       if (helpFile)
         {
-          NSString *helpstr = [[NSAttributedString alloc] initWithPath: helpFile
-                                                    documentAttributes: NULL];
+          NSString *helpstr;
+
+          helpstr = [[NSAttributedString alloc] initWithPath: helpFile
+					  documentAttributes: NULL];
           return TEST_AUTORELEASE (helpstr);
         }
     }
@@ -165,25 +178,79 @@
       // "appname.rtfd" or "appname.rtf"
     }
 
-  if (help)
+  if (help != nil)
     {
-      NSString *file;
+      NSString *file = nil;
 
       if ([[help pathExtension] length] == 0)
         {
-          file = [mb pathForHelpResource: [help stringByAppendingPathExtension: @"rtfd"]];
+          file = [mb pathForHelpResource:
+	    [help stringByAppendingPathExtension: @"rtfd"]];
 
           if (file == nil)
             {
-              file = [mb pathForHelpResource: [help stringByAppendingPathExtension: @"rtf"]];
+              file = [mb pathForHelpResource:
+		[help stringByAppendingPathExtension: @"rtf"]];
             }
         }
+      else
+        {
+	  file = [mb pathForHelpResource: help];
+	}
 
-    if (file) {
-      [[NSWorkspace sharedWorkspace] openFile: file];
-      return;
+      if (file != nil)
+	{
+	  if ([[NSWorkspace sharedWorkspace] openFile: file] == YES)
+	    {
+	      return;
+	    }
+	  else
+	    {
+	      NSHelpPanel	*panel = [NSHelpPanel sharedHelpPanel];
+	      NSString		*ext = [file pathExtension];
+	      NSTextView	*tv;
+	      id		object;
+
+	      tv = [(NSScrollView*)[panel contentView] documentView];
+
+	      if (ext == nil  
+		||  [ext isEqualToString: @""]	 
+		|| [ext isEqualToString: @"txt"] 
+		|| [ext isEqualToString: @"text"])
+		{
+		  object = [NSString stringWithContentsOfFile: file];
+		}
+	      else if ([ext isEqualToString: @"rtf"])
+		{
+		  NSData *data = [NSData dataWithContentsOfFile: file];
+		  
+		  object = [[NSAttributedString alloc] initWithRTF: data
+		    documentAttributes: 0];
+		  AUTORELEASE (object);
+		}
+	      else if ([ext isEqualToString: @"rtfd"])
+		{
+		  NSFileWrapper *wrapper;
+		  
+		  wrapper = [[NSFileWrapper alloc] initWithPath: file];
+		  AUTORELEASE (wrapper);
+		  object = [[NSAttributedString alloc]
+		    initWithRTFDFileWrapper: wrapper
+		    documentAttributes: 0];
+		  AUTORELEASE (object);
+		}
+	      
+	      if (object != nil)
+		{
+		  [[tv textStorage] setAttributedString: object];
+		  [tv sizeToFit];
+		}
+	      [tv setNeedsDisplay: YES];
+	      [panel makeKeyAndOrderFront: self];
+	      return;
+	    }
+	}
     }
-  }
   
   NSBeep();
 }
@@ -199,12 +266,13 @@
 
 static NSHelpManager *_gnu_sharedHelpManager = nil;
 static BOOL _gnu_contextHelpActive = NO;
+static NSCursor *helpCursor = nil;
 
 
 //
 // Class methods
 //
-+ (NSHelpManager*)sharedHelpManager
++ (NSHelpManager*) sharedHelpManager
 {
   if (!_gnu_sharedHelpManager)
     {
@@ -214,25 +282,38 @@ static BOOL _gnu_contextHelpActive = NO;
   return _gnu_sharedHelpManager;
 }
 
-+ (BOOL)isContextHelpModeActive
++ (BOOL) isContextHelpModeActive
 {
   return _gnu_contextHelpActive;
 }
 
-+ (void)setContextHelpModeActive: (BOOL) flag
++ (void) setContextHelpModeActive: (BOOL) flag
 {
-  _gnu_contextHelpActive = flag;
-  if (flag)
+  if (flag != _gnu_contextHelpActive)
     {
-      [[NSNotificationCenter defaultCenter] 
-	postNotificationName: NSContextHelpModeDidActivateNotification 
-	object: [self sharedHelpManager]];
-    }
-  else
-    {
-      [[NSNotificationCenter defaultCenter] 
-	postNotificationName: NSContextHelpModeDidDeactivateNotification 
-	object: [self sharedHelpManager]];
+      _gnu_contextHelpActive = flag;
+      if (flag)
+	{
+	  if (helpCursor == nil)
+	    {
+	      helpCursor = [[NSCursor alloc]
+		initWithImage: [NSImage imageNamed: @"common_HelpCursor"]
+		hotSpot: NSMakePoint(8, 2)];
+	      [helpCursor setOnMouseEntered: NO];
+	      [helpCursor setOnMouseExited: NO];
+	    }
+	  [helpCursor push];
+	  [[NSNotificationCenter defaultCenter] 
+	    postNotificationName: NSContextHelpModeDidActivateNotification 
+	    object: [self sharedHelpManager]];
+	}
+      else
+	{
+	  [helpCursor pop];
+	  [[NSNotificationCenter defaultCenter] 
+	    postNotificationName: NSContextHelpModeDidDeactivateNotification 
+	    object: [self sharedHelpManager]];
+	}
     }
 }
 
@@ -284,7 +365,7 @@ static BOOL _gnu_contextHelpActive = NO;
   NSMapRemove(contextHelpTopics, object);
 }
 
-- (void)setContextHelp:(NSAttributedString *)help forObject:(id)object
+- (void) setContextHelp: (NSAttributedString *)help forObject: (id)object
 {
   NSMapInsert(contextHelpTopics, object, help);
 }
@@ -304,10 +385,11 @@ static BOOL _gnu_contextHelpActive = NO;
 
   if (contextHelp)
     {
-	GSHelpManagerPanel *helpPanel = [GSHelpManagerPanel sharedHelpManagerPanel];
+      GSHelpManagerPanel *helpPanel;
 
       // FIXME: We should position the window at point! 
       // runModalForWindow will centre the window.
+      helpPanel = [GSHelpManagerPanel sharedHelpManagerPanel];
       [helpPanel setHelpText: contextHelp];
       [NSApp runModalForWindow: helpPanel];
       return YES;
