@@ -193,9 +193,6 @@ repd_for_rep(NSArray *_reps, NSImageRep *rep)
     }
 }
 
-/** <p>Returns the NSImage named aName. The search is done in the main bundle
-    first and then in the usual images directories</p>
- */
 + (id) imageNamed: (NSString *)aName
 {
   NSString	*realName = [nsmapping objectForKey: aName];
@@ -314,9 +311,6 @@ repd_for_rep(NSArray *_reps, NSImageRep *rep)
   return [self initWithSize: NSMakeSize(0, 0)];
 }
 
-/** <p>Initialize and returns a new NSImage with <var>aSize</var> as specified
-    size.</p><p>See Also: -setSize: -size </p>
- */
 - (id) initWithSize: (NSSize)aSize
 {
   [super init];
@@ -357,11 +351,6 @@ repd_for_rep(NSArray *_reps, NSImageRep *rep)
   return self;
 }
 
-
-/** <p>Initializes and returns a new NSImage from the file 
-    <var>fileName</var>. <var>fileName</var> should be an absolute path.</p>
-    <p>See Also: [NSImageRep+imageRepsWithContentsOfFile:]</p>
- */
 - (id) initWithContentsOfFile: (NSString *)fileName
 {
   if ( ! ( self = [self init] ) )
@@ -377,9 +366,6 @@ repd_for_rep(NSArray *_reps, NSImageRep *rep)
   return self;
 }
 
-/**<p>Initializes and returns a new NSImage from the NSData data.</p>
-   <p>See Also: [NSImageRep+imageRepWithData:]</p>
- */
 - (id) initWithData: (NSData *)data
 {
   if (! ( self = [self init] ) )
@@ -441,11 +427,6 @@ repd_for_rep(NSArray *_reps, NSImageRep *rep)
   return self;
 }
 
-/** <p>Initializes and returns a new NSImage from the data in pasteboard.
-    the pasteboard types can be whose defined in  
-    [NSImageRep+imagePasteboardTypes] or NSFilenamesPboardType</p>
-    <p>See Also: [NSImageRep+imageRepsWithPasteboard:</p>
- */
 - (id) initWithPasteboard: (NSPasteboard *)pasteboard
 {
   NSArray *reps;
@@ -549,10 +530,6 @@ repd_for_rep(NSArray *_reps, NSImageRep *rep)
   return _name;
 }
 
-/** <p>Sets the NSImage size to aSize. Changing the size recreate
-    the cache</p>
-    <p>See Also: -size -initWithSize:</p>
- */
 - (void) setSize: (NSSize)aSize
 {
   // Optimized as this is called very often from NSImageCell
@@ -565,10 +542,6 @@ repd_for_rep(NSArray *_reps, NSImageRep *rep)
   [self recache];
 }
 
-/**<p> Returns NSImage size if the size have been set. Returns the
-   size of the best representation otherwise.</p>
-   <p>See Also: -setSize: -initWithSize:</p>
- */
 - (NSSize) size
 {
   if (_size.width == 0) 
@@ -716,9 +689,6 @@ repd_for_rep(NSArray *_reps, NSImageRep *rep)
   return _flags.scalable;
 }
 
-/**<p>Sets the color of the NSImage's background to <var>aColor</var></p>
-   <p>See Also: -backgroundColor</p>
- */
 - (void) setBackgroundColor: (NSColor *)aColor
 {
   if (aColor == nil)
@@ -728,9 +698,6 @@ repd_for_rep(NSArray *_reps, NSImageRep *rep)
   ASSIGN(_color, aColor);
 }
 
-/**<p>Returns the color of the NSImage's background</p>
-   <p>See Also: -setBackgroundColor:</p>
- */
 - (NSColor *) backgroundColor
 {
   return _color;
@@ -823,7 +790,7 @@ repd_for_rep(NSArray *_reps, NSImageRep *rep)
 }
 
 - (void) compositeToPoint: (NSPoint)aPoint
-		 fromRect: (NSRect)aRect
+		 fromRect: (NSRect)srcRect
 		operation: (NSCompositingOperation)op
 		 fraction: (float)delta
 {
@@ -832,27 +799,28 @@ repd_for_rep(NSArray *_reps, NSImageRep *rep)
   NS_DURING
     { 
       if ([GSCurrentContext() isDrawingToScreen] == YES)
-	  rep = [self _doImageCache];
+	rep = [self _doImageCache];
       if (rep
-	  &&_cacheMode != NSImageCacheNever 
-	  && [rep isKindOfClass: cachedClass])
+	&&_cacheMode != NSImageCacheNever 
+	&& [rep isKindOfClass: cachedClass])
         {
 	  NSRect rect;
 
 	  rect = [(NSCachedImageRep *)rep rect];
 	  NSDebugLLog(@"NSImage", @"composite rect %@ in %@", 
-		      NSStringFromRect(rect), NSStringFromRect(aRect));
+		      NSStringFromRect(rect), NSStringFromRect(srcRect));
 	  // Move the drawing rectangle to the origin of the image rep
 	  // and intersect the two rects.
-	  aRect.origin.x += rect.origin.x;
-	  aRect.origin.y += rect.origin.y;
-	  rect = NSIntersectionRect(aRect, rect);
+	  srcRect.origin.x += rect.origin.x;
+	  srcRect.origin.y += rect.origin.y;
+	  rect = NSIntersectionRect(srcRect, rect);
 
-	  [GSCurrentContext() GScomposite: [[(NSCachedImageRep *)rep window] gState]
-			   toPoint: aPoint
-			   fromRect: rect
-			   operation: op
-			   fraction: delta];
+	  [GSCurrentContext() GScomposite:
+	    [[(NSCachedImageRep *)rep window] gState]
+	    toPoint: aPoint
+	    fromRect: rect
+	    operation: op
+	    fraction: delta];
 	}
       else	
         {
@@ -864,17 +832,18 @@ repd_for_rep(NSArray *_reps, NSImageRep *rep)
     }
   NS_HANDLER
     {
-      NSLog(@"NSImage: compositeToPoint:fromRect:operation:fraction: failed due to %@: %@", 
-	    [localException name], [localException reason]);
+      NSLog(@"NSImage: compositeToPoint:fromRect:operation:fraction:"
+        @"failed due to %@: %@", 
+        [localException name], [localException reason]);
       if ([_delegate respondsToSelector: @selector(imageDidNotDraw:inRect:)])
         {
-	  NSImage *image = [_delegate imageDidNotDraw: self inRect: aRect];
+	  NSImage *image = [_delegate imageDidNotDraw: self inRect: srcRect];
 
 	  if (image != nil)
 	    [image compositeToPoint: aPoint
-		   fromRect: aRect 
-		   operation: op
-		   fraction: delta];
+			   fromRect: srcRect 
+			  operation: op
+			   fraction: delta];
 	}
     }
   NS_ENDHANDLER
@@ -966,7 +935,7 @@ repd_for_rep(NSArray *_reps, NSImageRep *rep)
       if ([GSCurrentContext() isDrawingToScreen] == NO)
 	{
 	  /* Reset alpha for image drawing. */
-	  [[NSColor whiteColor] set];
+	  [[NSColor colorWithCalibratedWhite: 1.0 alpha: 1.0] set];
 	}
     }
 
@@ -995,13 +964,13 @@ repd_for_rep(NSArray *_reps, NSImageRep *rep)
 - (void) drawInRect: (NSRect)dstRect
 	   fromRect: (NSRect)srcRect
 	  operation: (NSCompositingOperation)op
-	   fraction: (float)fraction
+	   fraction: (float)delta
 {
   NSGraphicsContext *ctxt = GSCurrentContext();
   NSAffineTransform *transform;
 
   if (!dstRect.size.width || !dstRect.size.height
-      || !srcRect.size.width || !srcRect.size.height)
+    || !srcRect.size.width || !srcRect.size.height)
     return;
 
   if (![ctxt isDrawingToScreen])
@@ -1042,16 +1011,19 @@ repd_for_rep(NSArray *_reps, NSImageRep *rep)
 
   /* If the effective transform is the identity transform and there's
      no dissolve, we can composite from our cache.  */
-  if (fraction == 1.0
-      && fabs(transform->matrix.m11 - 1.0) < 0.01
-      && fabs(transform->matrix.m12) < 0.01
-      && fabs(transform->matrix.m21) < 0.01
-      && fabs(transform->matrix.m22 - 1.0) < 0.01)
+
+  if (delta == 1.0)
     {
-      [self compositeToPoint: dstRect.origin
-		    fromRect: srcRect
-		   operation: op];
-      return;
+      NSAffineTransformStruct ts = [transform transformStruct];
+      
+      if (fabs(ts.m11 - 1.0) < 0.01 && fabs(ts.m12) < 0.01
+	&& fabs(ts.m21) < 0.01 && fabs(ts.m22 - 1.0) < 0.01)
+	{
+	  [self compositeToPoint: dstRect.origin
+			fromRect: srcRect
+		       operation: op];
+	  return;
+	}
     }
 
   /* We can't composite or dissolve directly from the image reps, so we
@@ -1074,6 +1046,7 @@ repd_for_rep(NSArray *_reps, NSImageRep *rep)
      */
   {
     NSCachedImageRep *cache;
+    NSAffineTransformStruct ts;
     NSSize s;
     NSPoint p;
     double x0, y0, x1, y1, w, h;
@@ -1130,8 +1103,10 @@ repd_for_rep(NSArray *_reps, NSImageRep *rep)
 
     /* Set up the effective transform.  We also save a gState with this
        transform to make it easier to do the final composite.  */
-    transform->matrix.tX = p.x;
-    transform->matrix.tY = p.y;
+    ts = [transform transformStruct];
+    ts.tX = p.x;
+    ts.tY = p.y;
+    [transform setTransformStruct: ts];
     [ctxt GSSetCTM: transform];
 
     gState = [ctxt GSDefineGState];
@@ -1141,9 +1116,9 @@ repd_for_rep(NSArray *_reps, NSImageRep *rep)
 
     /* If we're doing a dissolve, use a DestinationIn composite to lower
        the alpha of the pixels.  */
-    if (fraction != 1.0)
+    if (delta != 1.0)
       {
-	DPSsetalpha(ctxt, fraction);
+	DPSsetalpha(ctxt, delta);
 	DPScompositerect(ctxt, 0, 0, s.width, s.height,
 			 NSCompositeDestinationIn);
       }
@@ -1161,10 +1136,6 @@ repd_for_rep(NSArray *_reps, NSImageRep *rep)
   }
 }
 
-/** <p>Adds the NSImageRep imageRep to the NSImage's representations array.
-    </p><p>See Also: -addRepresentations: removeRepresentation:</p>
- */
-
 - (void) addRepresentation: (NSImageRep *)imageRep
 {
   GSRepData	*repd;
@@ -1175,10 +1146,6 @@ repd_for_rep(NSArray *_reps, NSImageRep *rep)
   RELEASE(repd);
 }
 
-/** <p>Adds the NSImageRep array imageRepArray to the NSImage's
-    representations array.</p>
-    <p>See Also: -addRepresentation: -removeRepresentation:</p>
- */
 - (void) addRepresentations: (NSArray *)imageRepArray
 {
   unsigned	i, count;
@@ -1194,9 +1161,6 @@ repd_for_rep(NSArray *_reps, NSImageRep *rep)
     }
 }
 
-/** <p>Remove the NSImageRep imageRep from the NSImage's representations 
-    array</p><p>See Also: -addRepresentations: -addRepresentation:</p>
- */
 - (void) removeRepresentation: (NSImageRep *)imageRep
 {
   unsigned	i;
@@ -1217,17 +1181,11 @@ repd_for_rep(NSArray *_reps, NSImageRep *rep)
     }
 }
 
-/** <p>Locks the focus on the best representation</p>
-    <p>See Also: -lockFocusOnRepresentation:</p>
- */
 - (void) lockFocus
 {
   [self lockFocusOnRepresentation: nil];
 }
 
-/**<p>Locks the focus in the imageRep. if imageRep is nil this method
-   locks the focus on the best representation</p>
- */
 - (void) lockFocusOnRepresentation: (NSImageRep *)imageRep
 {
   if (_cacheMode != NSImageCacheNever)
@@ -1463,15 +1421,55 @@ repd_for_rep(NSArray *_reps, NSImageRep *rep)
 // Producing TIFF Data for the Image 
 - (NSData *) TIFFRepresentation
 {
-  return [bitmapClass TIFFRepresentationOfImageRepsInArray: [self representations]];
+  NSData *data;
+
+  // As a result of using bitmap representations, new drawing wont show on the tiff data.
+  data = [bitmapClass TIFFRepresentationOfImageRepsInArray: [self representations]];
+
+  if (!data)
+    {
+      NSBitmapImageRep *rep;
+      NSSize size = [self size];
+      
+      // If there isn't a bitmap representation to output, create one and store it.
+      [self lockFocus];
+      rep = [[NSBitmapImageRep alloc] initWithFocusedViewRect: 
+		       NSMakeRect(0.0, 0.0, size.width, size.height)];
+      [self unlockFocus];
+      [self addRepresentation: rep];
+      data = [rep TIFFRepresentation];
+      RELEASE(rep);
+    }
+
+  return data;
 }
 
 - (NSData *) TIFFRepresentationUsingCompression: (NSTIFFCompression)comp
 	factor: (float)aFloat
 {
-  return [bitmapClass TIFFRepresentationOfImageRepsInArray: [self representations]
+  NSData *data;
+
+  // As a result of using bitmap representations, new drawing wont show on the tiff data.
+  data = [bitmapClass TIFFRepresentationOfImageRepsInArray: [self representations]
 		      usingCompression: comp
 		      factor: aFloat];
+
+  if (!data)
+    {
+      NSBitmapImageRep *rep;
+      NSSize size = [self size];
+      
+      // If there isn't a bitmap representation to output, create one and store it.
+      [self lockFocus];
+      rep = [[NSBitmapImageRep alloc] initWithFocusedViewRect: 
+		       NSMakeRect(0.0, 0.0, size.width, size.height)];
+      [self unlockFocus];
+      [self addRepresentation: rep];
+      data = [rep TIFFRepresentationUsingCompression: comp factor: aFloat];
+      RELEASE(rep);
+    }
+
+  return data;
 }
 
 // NSCoding
@@ -1479,11 +1477,11 @@ repd_for_rep(NSArray *_reps, NSImageRep *rep)
 {
   BOOL	flag;
 
-  if([coder allowsKeyedCoding])
+  if ([coder allowsKeyedCoding])
     {
       // FIXME: Not sure this is the way it goes...
       /*
-      if(_flags.archiveByName == NO)
+      if (_flags.archiveByName == NO)
 	{
 	  NSMutableArray *container = [NSMutableArray array];
 	  NSMutableArray *reps = [NSMutableArray array];
@@ -1492,7 +1490,7 @@ repd_for_rep(NSArray *_reps, NSImageRep *rep)
 
 	  // add the reps to the container...
 	  [container addObject: reps];
-	  while((rd = [en nextObject]) != nil)
+	  while ((rd = [en nextObject]) != nil)
 	    {
 	      [reps addObject: rd->rep];
 	    }
