@@ -31,7 +31,7 @@
 #include "AppKit/NSGraphics.h"
 #include "AppKit/NSImageCell.h"
 #include "AppKit/NSImage.h"
-#include "GNUstepGUI/GSDrawFunctions.h"
+#include "GNUstepGUI/GSTheme.h"
 
 @implementation NSImageCell
 
@@ -134,16 +134,16 @@
 	// nada
 	break;
       case NSImageFramePhoto:
-	[GSDrawFunctions drawFramePhoto: cellFrame : NSZeroRect];
+	[[GSTheme theme] drawFramePhoto: cellFrame withClip: NSZeroRect];
 	break;
       case NSImageFrameGrayBezel:
-	[GSDrawFunctions drawGrayBezel: cellFrame : NSZeroRect];
+	[[GSTheme theme] drawGrayBezel: cellFrame withClip: NSZeroRect];
 	break;
       case NSImageFrameGroove:
-	[GSDrawFunctions drawGroove: cellFrame : NSZeroRect];
+	[[GSTheme theme] drawGroove: cellFrame withClip: NSZeroRect];
 	break;
       case NSImageFrameButton:
-	[GSDrawFunctions drawButton: cellFrame : NSZeroRect];
+	[[GSTheme theme] drawButton: cellFrame withClip: NSZeroRect];
 	break;
     }
 
@@ -301,9 +301,6 @@ scaleProportionally(NSSize imageSize, NSRect canvasRect)
 				      realImageSize.height)
 		operation: NSCompositeSourceOver
 		 fraction: 1.0];
-
-  if (_cell.shows_first_responder)
-    NSDottedFrameRect(cellFrame);
 }
 
 - (NSSize) cellSize
@@ -369,7 +366,7 @@ scaleProportionally(NSSize imageSize, NSRect canvasRect)
 - (void) encodeWithCoder: (NSCoder *)aCoder
 {
   [super encodeWithCoder: aCoder];
-  if([aCoder allowsKeyedCoding])
+  if ([aCoder allowsKeyedCoding])
     {
       [aCoder encodeInt: _imageAlignment forKey: @"NSAlign"];
       [aCoder encodeInt: _imageScaling forKey: @"NSScale"];
@@ -387,7 +384,7 @@ scaleProportionally(NSSize imageSize, NSRect canvasRect)
 
 - (id) initWithCoder: (NSCoder *)aDecoder
 {
-  if((self = [super initWithCoder: aDecoder]) != nil)
+  if ((self = [super initWithCoder: aDecoder]) != nil)
     {
       if ([aDecoder allowsKeyedCoding])
 	{
