@@ -153,8 +153,8 @@ static Class imageCellClass;
 
 - (NSDragOperation) draggingEntered: (id <NSDraggingInfo>)sender
 {
-  if (([sender draggingSource] != self) && ([self isEditable]) && 
-      ([NSImage canInitWithPasteboard: [sender draggingPasteboard]]))
+  if (([sender draggingSource] != self) && ([self isEditable])
+    && ([NSImage canInitWithPasteboard: [sender draggingPasteboard]]))
     {
       [_cell setHighlighted: YES];
       return NSDragOperationCopy;
@@ -226,9 +226,8 @@ static Class imageCellClass;
 	      // Center the image on the mouse position ... is this right?
 	      s = [anImage size];
 	      p = [theEvent locationInWindow];
-	      p = [self convertPoint: p fromView: nil];
 	      p.x -= s.width/2;
-	      p.y -= s.width/2;
+	      p.y -= s.height/2;
 	      [_window dragImage: anImage
 		       at: p
 		       offset: NSMakeSize(0, 0)
@@ -279,7 +278,7 @@ static Class imageCellClass;
 - (void) encodeWithCoder: (NSCoder *)aCoder
 {
   [super encodeWithCoder: aCoder];
-  if([aCoder allowsKeyedCoding])
+  if ([aCoder allowsKeyedCoding])
     {
       [aCoder encodeBool: [self isEditable] forKey: @"NSEditable"];
     }
