@@ -42,7 +42,7 @@
 #include "AppKit/NSMenuItemCell.h"
 #include "AppKit/NSMenuView.h"
 #include "AppKit/NSParagraphStyle.h"
-#include "GNUstepGUI/GSDrawFunctions.h"
+#include "GNUstepGUI/GSTheme.h"
 
 
 @implementation NSMenuItemCell
@@ -59,28 +59,32 @@ static NSImage	*arrowImage = nil;	/* Cache arrow image.	*/
     }
 }
 
++ (NSFocusRingType) defaultFocusRingType
+{
+  return NSFocusRingTypeNone;
+}
+
 - (id) init
 {
   [super init];
-  _target = nil;
-  _highlightsByMask = NSChangeBackgroundCellMask;
-  _showAltStateMask = NSNoCellMask;
-  _cell.image_position = NSNoImage;
+  [self setButtonType: NSMomentaryLightButton];
   [self setAlignment: NSLeftTextAlignment];
   [self setFont: [NSFont menuFontOfSize: 0]];
+  [self setNeedsSizing: YES];
 
   return self;
 }
 
 - (void) dealloc
 {
-  RELEASE (_menuItem);
+  RELEASE(_menuItem);
   [super dealloc];
 }
 
 - (void) setHighlighted:(BOOL)flag
 {
   _cell.is_highlighted = flag;
+  [self setNeedsSizing: YES];
 }
 
 - (BOOL) isHighlighted
@@ -89,10 +93,51 @@ static NSImage	*arrowImage = nil;	/* Cache arrow image.	*/
   return _cell.is_highlighted;
 }
 
+- (NSColor *)textColor
+{
+  if(_cell.is_highlighted && [self isEnabled])
+    {
+      return [NSColor selectedMenuItemTextColor];
+    }
+
+  return [super textColor];
+}
+
+- (NSColor *) backgroundColor
+{
+  NSColor *backgroundColor = nil;
+  unsigned  mask;
+
+  if (_cell.is_highlighted)
+    {
+      mask = _highlightsByMask;
+
+      if (_cell.state)
+	mask &= ~_showAltStateMask;
+    }
+  else if (_cell.state)
+    mask = _showAltStateMask;
+  else
+    mask = NSNoCellMask;
+
+  // Determine the background color
+  if (mask & (NSChangeGrayCellMask | NSChangeBackgroundCellMask))
+    {
+      backgroundColor = [NSColor selectedMenuItemColor];
+    }
+
+  // TODO: Should we also check the ivar _backgroundColor?
+  if (backgroundColor == nil)
+    backgroundColor = [NSColor controlBackgroundColor];
+  
+  return backgroundColor;
+}
+
 - (void) setMenuItem: (NSMenuItem *)item
 {
-  ASSIGN (_menuItem, item);
+  ASSIGN(_menuItem, item);
   [self setEnabled: [_menuItem isEnabled]];
+  [self setNeedsSizing: YES];
 }
 
 - (NSMenuItem *) menuItem
@@ -100,6 +145,11 @@ static NSImage	*arrowImage = nil;	/* Cache arrow image.	*/
   return _menuItem;
 }
 
+- (int) tag
+{
+  return [[self menuItem] tag];
+}
+
 - (void) setMenuView: (NSMenuView *)menuView
 {
   /* The menu view is retaining us, we should not retain it.  */
@@ -110,11 +160,15 @@ static NSImage	*arrowImage = nil;	/* Cache arrow image.	*/
   if ([_menuView isHorizontal] == YES)
     {
       [self setAlignment: NSCenterTextAlignment];
+      [self setBordered: NO];
+      [self setImagePosition: NSImageLeft];
     }
   else
     {
       [self setAlignment: NSLeftTextAlignment];
+      [self setBordered: YES];
     }
+  [self setNeedsSizing: YES];
 }
 
 - (NSMenuView *) menuView
@@ -122,6 +176,35 @@ static NSImage	*arrowImage = nil;	/* Cache arrow image.	*/
   return _menuView;
 }
 
+- (NSString*) _keyEquivalentString
+{
+  NSString *key = [_menuItem keyEquivalent];
+  unsigned int m = [_menuItem keyEquivalentModifierMask];
+  NSString *ucKey = [key uppercaseString];
+  BOOL shift;
+  
+  if ((key == nil) || [key isEqualToString: @""])
+    return key;
+  
+  if ([key isEqualToString: @"\\r"])
+    key = @"RET";
+  else if ([key isEqualToString: @"\\e"])
+    key = @"ESC";
+  else if ([key isEqualToString: @"\\d"])
+    key=@"DEL";
+
+  // shift mask and not an upper case string?
+  shift = (m & NSShiftKeyMask) & ![key isEqualToString: ucKey];
+  
+  key = [NSString stringWithFormat:@"%@%@%@%@%@",
+		  (m & NSControlKeyMask) ? @"^" : @"",
+		  (m & NSAlternateKeyMask) ? @"+" : @"",
+		  shift ? @"/" : @"",
+		  (m & NSCommandKeyMask) ? @"#" : @"",
+		  key];
+  return key;
+}
+
 - (void) calcSize
 {
   NSSize   componentSize;
@@ -193,7 +276,7 @@ static NSImage	*arrowImage = nil;	/* Cache arrow image.	*/
   _titleWidth = componentSize.width;
   if (componentSize.height > neededMenuItemHeight)
     neededMenuItemHeight = componentSize.height;
-  componentSize = [self _sizeText: [_menuItem keyEquivalent]];
+  componentSize = [self _sizeText: [self _keyEquivalentString]];
   _keyEquivalentWidth = componentSize.width;
   if (componentSize.height > neededMenuItemHeight)
     neededMenuItemHeight = componentSize.height;
@@ -224,6 +307,16 @@ static NSImage	*arrowImage = nil;	/* Cache arrow image.	*/
   return _needs_sizing;
 }
 
+- (void) setNeedsDisplay:(BOOL)flag
+{
+  _needs_display = flag;
+}
+
+- (BOOL) needsDisplay
+{
+  return _needs_display;
+}
+
 - (float) imageWidth
 {
   if (_needs_sizing)
@@ -259,8 +352,19 @@ static NSImage	*arrowImage = nil;	/* Cache arrow image.	*/
 //
 // Sizes for drawing taking into account NSMenuView adjustments.
 //
-- (NSRect) imageRectForBounds:(NSRect)cellFrame
+- (NSRect) imageRectForBounds: (NSRect)cellFrame
 {
+  if (_needs_sizing)
+    [self calcSize];
+
+  if (_mcell_belongs_to_popupbutton && _cell.image_position)
+    {
+      // Special case: draw image on the extreme right 
+	cellFrame.origin.x  += cellFrame.size.width - _imageWidth - 4;
+	cellFrame.size.width = _imageWidth;
+	return cellFrame;
+    }
+
   if ([_menuView isHorizontal] == YES)
     {
       switch (_cell.image_position)
@@ -295,14 +399,6 @@ static NSImage	*arrowImage = nil;	/* Cache arrow image.	*/
     }
   else
     {
-      if (_mcell_belongs_to_popupbutton && _cell.image_position)
-	{
-	  // Special case: draw image on the extreme right 
-	  cellFrame.origin.x  += cellFrame.size.width - _imageWidth - 4;
-	  cellFrame.size.width = _imageWidth;
-	  return cellFrame;
-	}
-
       // Calculate the image part of cell frame from NSMenuView
       cellFrame.origin.x  += [_menuView imageAndTitleOffset];
       cellFrame.size.width = [_menuView imageAndTitleWidth];
@@ -359,6 +455,9 @@ static NSImage	*arrowImage = nil;	/* Cache arrow image.	*/
 
 - (NSRect) titleRectForBounds:(NSRect)cellFrame
 {
+  if (_needs_sizing)
+    [self calcSize];
+
   if ([_menuView isHorizontal] == YES)
     {
       /* This adjust will center us within the menubar. */
@@ -432,6 +531,62 @@ static NSImage	*arrowImage = nil;	/* Cache arrow image.	*/
   return cellFrame;
 }
 
+- (NSRect) drawingRectForBounds: (NSRect)theRect
+{
+  if ([_menuView isHorizontal] == YES)
+    {
+      /* A horizontal menu does not have borders drawn by the cell,
+       * but it does have a border round the menu as a whole, so we
+       * must inset from that.
+       */
+      return NSMakeRect (theRect.origin.x, theRect.origin.y + 2,
+	theRect.size.width, theRect.size.height - 2);
+    }
+  else
+    {
+      if (_cell.is_bordered)
+        {
+	  float yDelta = [_control_view isFlipped] ? 1. : 2.;
+	  unsigned mask;
+	  NSRect interiorFrame;
+	  
+	  if (_cell.is_highlighted)
+	    {
+	      mask = _highlightsByMask;
+		
+	      if (_cell.state)
+		mask &= ~_showAltStateMask;
+	    }
+	  else if (_cell.state)
+	    mask = _showAltStateMask;
+	  else
+	    mask = NSNoCellMask;
+ 
+	  /*
+	   * Special case:  Buttons have only three different paths for border.
+	   * One white path at the top left corner, one black path at the
+	   * bottom right and another in dark gray at the inner bottom right.
+	   */
+	  interiorFrame = NSMakeRect(theRect.origin.x + 1.,
+				     theRect.origin.y + yDelta,
+				     theRect.size.width - 3.,
+				     theRect.size.height - 3.);
+
+	  // pushed in buttons contents are displaced to the bottom right 1px
+	  if ((mask & NSPushInCellMask))
+	    {
+	      interiorFrame
+		  = NSOffsetRect(interiorFrame, 1., [_control_view isFlipped] ? 1. : -1.);
+	    }
+	  return interiorFrame;
+	}
+      else
+        {
+	  return theRect;
+	}
+    }
+}
+
 //
 // Drawing.
 //
@@ -439,39 +594,35 @@ static NSImage	*arrowImage = nil;	/* Cache arrow image.	*/
 				  inView: (NSView *)controlView
 {
   if ([_menuView isHorizontal] == YES)
-    return;
+    {
+      cellFrame = [self drawingRectForBounds: cellFrame];
+      [[self backgroundColor] set];
+      NSRectFill(cellFrame);
+      return;
+    }
+
+  // Set cell's background color
+  [[self backgroundColor] set];
+  NSRectFill(cellFrame);
 
   if (!_cell.is_bordered)
     return;
 
   if (_cell.is_highlighted && (_highlightsByMask & NSPushInCellMask))
     {
-      [GSDrawFunctions drawGrayBezel: cellFrame : NSZeroRect];
+      [[GSTheme theme] drawGrayBezel: cellFrame withClip: NSZeroRect];
     }
   else
     {
-      [GSDrawFunctions drawButton: cellFrame : NSZeroRect];
+      [[GSTheme theme] drawButton: cellFrame withClip: NSZeroRect];
     }
 }
 
 - (void) drawImageWithFrame: (NSRect)cellFrame
 		     inView: (NSView *)controlView
 {
-  NSSize	size;
-  NSPoint	position;
-
   cellFrame = [self imageRectForBounds: cellFrame];
-  size = [_imageToDisplay size];
-  position.x = MAX(NSMidX(cellFrame) - (size.width/2.), 0.);
-  position.y = MAX(NSMidY(cellFrame) - (size.height/2.), 0.);
-  /*
-   * Images are always drawn with their bottom-left corner at the origin
-   * so we must adjust the position to take account of a flipped view.
-   */
-  if ([controlView isFlipped])
-    position.y += size.height;
-
-  [_imageToDisplay compositeToPoint: position operation: NSCompositeSourceOver];
+  [self drawImage: _imageToDisplay withFrame: cellFrame inView: controlView];
 }
 
 - (void) drawKeyEquivalentWithFrame:(NSRect)cellFrame
@@ -479,7 +630,7 @@ static NSImage	*arrowImage = nil;	/* Cache arrow image.	*/
 {
   cellFrame = [self keyEquivalentRectForBounds: cellFrame];
 
-  if ([_menuItem hasSubmenu])
+  if ([_menuItem hasSubmenu] && arrowImage != nil)
     {
       NSSize	size;
       NSPoint	position;
@@ -506,13 +657,9 @@ static NSImage	*arrowImage = nil;	/* Cache arrow image.	*/
    * equivalent would be, so we do not display the key equivalent,
    * else they would be displayed one over the other one.
    */
-  else if (![[_menuView menu] _ownedByPopUp])
+  else if (![[_menuView menu] _ownedByPopUp] || (_imageToDisplay == nil))
     {    
-      [self _drawText: [_menuItem keyEquivalent] inFrame: cellFrame];
-    }
-  else if (_imageToDisplay == nil)
-    {
-      [self _drawText: [_menuItem keyEquivalent] inFrame: cellFrame];
+      [self _drawText: [self _keyEquivalentString] inFrame: cellFrame];
     }
 }
 
@@ -552,8 +699,9 @@ static NSImage	*arrowImage = nil;	/* Cache arrow image.	*/
       return;
     }
   
-  size = [imageToDisplay size];
   cellFrame = [self stateImageRectForBounds: cellFrame];
+  // FIXME: We could call drawImage:withFrame:inView: here, if we knew that the code there is correct.
+  size = [imageToDisplay size];
   position.x = MAX(NSMidX(cellFrame) - (size.width/2.),0.);
   position.y = MAX(NSMidY(cellFrame) - (size.height/2.),0.);
   /*
@@ -573,6 +721,8 @@ static NSImage	*arrowImage = nil;	/* Cache arrow image.	*/
 {
   if ([_menuView isHorizontal] == YES)
     {
+      // FIXME: Why do we have separate drawing coce here. The alignement already
+      // gets adjusted when the menu view is set and the text colour looks wrong here.
       id value = [NSMutableParagraphStyle defaultParagraphStyle];
       NSDictionary *attr;
       NSRect cf = [self titleRectForBounds: cellFrame];
@@ -586,11 +736,6 @@ static NSImage	*arrowImage = nil;	/* Cache arrow image.	*/
 	[NSColor controlTextColor], NSForegroundColorAttributeName,
 	nil];
 
-      if ([_menuItem isEnabled])
-	_cell.is_disabled = NO;
-      else
-	_cell.is_disabled = YES;
-
       [[_menuItem title] drawInRect: cf withAttributes: attr];
 
       RELEASE(attr);
@@ -602,24 +747,9 @@ static NSImage	*arrowImage = nil;	/* Cache arrow image.	*/
     }
 }
 
-- (void) drawWithFrame: (NSRect)cellFrame inView: (NSView*)controlView
+- (void) _drawBorderAndBackgroundWithFrame: (NSRect)cellFrame inView: (NSView*)controlView
 {
-  // Save last view drawn to
-  if (_control_view != controlView)
-    _control_view = controlView;
-
-  // Transparent buttons never draw
-  if (_buttoncell_is_transparent)
-    return;
-
-  // Do nothing if cell's frame rect is zero
-  if (NSIsEmptyRect(cellFrame))
-    return;
-
-  // Draw the border if needed
   [self drawBorderAndBackgroundWithFrame: cellFrame inView: controlView];
-
-  [self drawInteriorWithFrame: cellFrame inView: controlView];
 }
 
 - (void) drawInteriorWithFrame: (NSRect)cellFrame inView: (NSView*)controlView
@@ -630,59 +760,58 @@ static NSImage	*arrowImage = nil;	/* Cache arrow image.	*/
   if (_buttoncell_is_transparent)
     return;
 
+  if ([_menuItem isSeparatorItem])
+    {
+      [self drawSeparatorItemWithFrame: cellFrame inView: controlView];
+      return;
+    }
+
+  cellFrame = [self drawingRectForBounds: cellFrame];
+  
+  // FIXME: I think all this code belongs into calcSize.
+  if (_cell.is_highlighted)
+    {
+      mask = _highlightsByMask;
+
+      if (_cell.state)
+	mask &= ~_showAltStateMask;
+    }
+  else if (_cell.state)
+    mask = _showAltStateMask;
+  else
+    mask = NSNoCellMask;
+
+  /*
+   * Determine the image and the title that will be
+   * displayed. If the NSContentsCellMask is set the
+   * image and title are swapped only if state is 1 or
+   * if highlighting is set (when a button is pushed it's
+   * content is changed to the face of reversed state).
+   * The results are saved in two ivars for use in other
+   * drawing methods.
+   */
+  if (mask & NSContentsCellMask)
+    {
+      _imageToDisplay = _altImage;
+      if (!_imageToDisplay)
+	_imageToDisplay = [_menuItem image];
+      _titleToDisplay = _altContents;
+      if (_titleToDisplay == nil || [_titleToDisplay isEqual: @""])
+	_titleToDisplay = [_menuItem title];
+    }
+  else
+    {
+      _imageToDisplay = [_menuItem image];
+      _titleToDisplay = [_menuItem title];
+    }
+       
+  if (_imageToDisplay)
+    {
+      _imageWidth = [_imageToDisplay size].width;
+    }
+
   if ([_menuView isHorizontal] == YES)
     {
-      NSColor *backgroundColor = nil;
-
-      cellFrame = [self drawingRectForBounds: cellFrame];
-
-      if (_cell.is_highlighted)
-	{
-	  mask = _highlightsByMask;
-
-	  if (_cell.state)
-	    mask &= ~_showAltStateMask;
-	}
-      else if (_cell.state)
-	mask = _showAltStateMask;
-      else
-	mask = NSNoCellMask;
-
-      /* 
-       * Determine the background color and cache it in an ivar so that the
-       * low-level drawing methods don't need to do it again.
-       */
-      if (mask & (NSChangeGrayCellMask | NSChangeBackgroundCellMask))
-	{
-	  backgroundColor = [NSColor selectedMenuItemColor];
-	}
-      if (backgroundColor == nil)
-	backgroundColor = [NSColor controlBackgroundColor];
-
-      // Set cell's background color
-      [backgroundColor set];
-      NSRectFill(cellFrame);
-      if (mask & NSContentsCellMask)
-	{
-	  _imageToDisplay = _altImage;
-	  if (!_imageToDisplay)
-	    _imageToDisplay = [_menuItem image];
-	  _titleToDisplay = _altContents;
-	  if (_titleToDisplay == nil || [_titleToDisplay isEqual: @""])
-	    _titleToDisplay = [_menuItem title];
-	}
-      else
-	{
-	  _imageToDisplay = [_menuItem image];
-	  _titleToDisplay = [_menuItem title];
-	}
-       
-      if (_imageToDisplay)
-	{
-	  _imageWidth = [_imageToDisplay size].width;
-	  [self setImagePosition: NSImageLeft];
-	}
-	  
       // Draw the image
       if (_imageWidth > 0)
 	[self drawImageWithFrame: cellFrame inView: controlView];
@@ -693,70 +822,6 @@ static NSImage	*arrowImage = nil;	/* Cache arrow image.	*/
     }
   else
     {
-      cellFrame = [self drawingRectForBounds: cellFrame];
-
-      if (_cell.is_highlighted)
-	{
-	  mask = _highlightsByMask;
-
-	  if (_cell.state)
-	    mask &= ~_showAltStateMask;
-	}
-      else if (_cell.state)
-	mask = _showAltStateMask;
-      else
-	mask = NSNoCellMask;
-
-      // pushed in buttons contents are displaced to the bottom right 1px
-      if (_cell.is_bordered && (mask & NSPushInCellMask))
-	{
-	  cellFrame = NSOffsetRect(cellFrame, 1., [controlView isFlipped] ? 1. : -1.);
-	}
-
-      /*
-       * Determine the background color and cache it in an ivar so that the
-       * low-level drawing methods don't need to do it again.
-       */
-      if (mask & (NSChangeGrayCellMask | NSChangeBackgroundCellMask))
-	{
-	  _backgroundColor = [NSColor selectedMenuItemColor];
-	}
-      if (_backgroundColor == nil)
-	_backgroundColor = [NSColor controlBackgroundColor];
-
-      // Set cell's background color
-      [_backgroundColor set];
-      NSRectFill(cellFrame);
-
-      /*
-       * Determine the image and the title that will be
-       * displayed. If the NSContentsCellMask is set the
-       * image and title are swapped only if state is 1 or
-       * if highlighting is set (when a button is pushed it's
-       * content is changed to the face of reversed state).
-       * The results are saved in two ivars for use in other
-       * drawing methods.
-       */
-      if (mask & NSContentsCellMask)
-	{
-	  _imageToDisplay = _altImage;
-	  if (!_imageToDisplay)
-	    _imageToDisplay = [_menuItem image];
-	  _titleToDisplay = _altContents;
-	  if (_titleToDisplay == nil || [_titleToDisplay isEqual: @""])
-	    _titleToDisplay = [_menuItem title];
-	}
-      else
-	{
-	  _imageToDisplay = [_menuItem image];
-	  _titleToDisplay = [_menuItem title];
-	}
-
-      if (_imageToDisplay)
-	{
-	  _imageWidth = [_imageToDisplay size].width;
-	}
-
       // Draw the state image
       if (_stateImageWidth > 0)
 	[self drawStateImageWithFrame: cellFrame inView: controlView];
@@ -772,21 +837,6 @@ static NSImage	*arrowImage = nil;	/* Cache arrow image.	*/
       // Draw the key equivalent
       if (_keyEquivalentWidth > 0)
 	[self drawKeyEquivalentWithFrame: cellFrame inView: controlView];
-
-      _backgroundColor = nil;
-    }
-}
-
-- (NSRect) drawingRectForBounds: (NSRect)theRect
-{
-  if ([_menuView isHorizontal] == YES)
-    {
-      return NSMakeRect (theRect.origin.x, theRect.origin.y + 2,
-	theRect.size.width, theRect.size.height - 2);
-    }
-  else
-    {
-      return [super drawingRectForBounds: theRect];
     }
 }
 
