@@ -74,11 +74,11 @@ static NSMapTable	*viewInfo = 0;
 @class NSButton;
 
 @interface NSMenuView (Private)
-- (BOOL) _rootIsHorizontal;
+- (BOOL) _rootIsHorizontal: (BOOL*)isAppMenu;
 @end
 
 @implementation NSMenuView (Private)
-- (BOOL) _rootIsHorizontal
+- (BOOL) _rootIsHorizontal: (BOOL*)isAppMenu
 {
   NSMenu	*m = _attachedMenu;
 
@@ -87,6 +87,17 @@ static NSMapTable	*viewInfo = 0;
     {
       m = [m supermenu];
     }
+  if (isAppMenu != 0)
+    {
+      if (m == [NSApp mainMenu])
+	{
+	  *isAppMenu = YES;
+	}
+      else
+	{
+	  *isAppMenu = NO;
+	}
+    }
   return [[m menuRepresentation] isHorizontal];
 }
 @end
@@ -121,12 +132,11 @@ _addLeftBorderOffsetToRect(NSRect aRect)
 
   if (height == 0.0)
     {
-      NSFont *font = [NSFont menuFontOfSize: 0.0];
+      NSFont *font = [NSFont menuBarFontOfSize: 0.0];
 
-      /* Should make up 23 for the default font */
-      height = ([font boundingRectForFont].size.height) + 8;
-      if (height < 23)
-	height = 23;
+      height = [font boundingRectForFont].size.height;
+      if (height < 22)
+	height = 22;
     }
 
   return height;
@@ -220,6 +230,8 @@ _addLeftBorderOffsetToRect(NSRect aRect)
 - (void) setMenu: (NSMenu*)menu
 {
   NSNotificationCenter	*theCenter = [NSNotificationCenter defaultCenter];
+  unsigned	count;
+  unsigned	i;
 
   if (_attachedMenu != nil)
     {
@@ -248,30 +260,25 @@ _addLeftBorderOffsetToRect(NSRect aRect)
                     selector: @selector(itemRemoved:)
                         name: NSMenuDidRemoveItemNotification
                       object: _attachedMenu];
-
-      // Force menu view's layout to be recalculated.
-      [self setNeedsSizing: YES];
-      
-      [self update];
     }
-  if (_horizontal)
+
+  count = [[[self menu] itemArray] count];
+  for (i = 0; i < count; i++)
     {
-      unsigned	count = [[[self menu] itemArray] count];
-      unsigned	i;
+      NSNumber	*n = [NSNumber numberWithInt: i];
+      NSDictionary	*d;
 
-      for (i = 0; i < count; i++)
-	{
-	  NSNumber	*n = [NSNumber numberWithInt: i];
-	  NSDictionary	*d;
+      d = [NSDictionary dictionaryWithObject: n forKey: @"NSMenuItemIndex"];
 
-	  d = [NSDictionary dictionaryWithObject: n forKey: @"NSMenuItemIndex"];
-
-	  [self itemAdded: [NSNotification
-	    notificationWithName: NSMenuDidAddItemNotification
-	    object: self
-	    userInfo: d]];
-	}
+      [self itemAdded: [NSNotification
+	notificationWithName: NSMenuDidAddItemNotification
+	object: self
+	userInfo: d]];
     }
+
+  // Force menu view's layout to be recalculated.
+  [self setNeedsSizing: YES];
+  [self update];
 }
 
 - (NSMenu*) menu
@@ -317,7 +324,7 @@ _addLeftBorderOffsetToRect(NSRect aRect)
   
       r = [_font boundingRectForFont];
       /* Should make up 110, 20 for default font */
-      _cellSize = NSMakeSize (r.size.width * 10., r.size.height + 6.);
+      _cellSize = NSMakeSize (r.size.width * 10., r.size.height + 3.);
 
       if (_cellSize.height < 20)
 	_cellSize.height = 20;
@@ -559,43 +566,55 @@ _addLeftBorderOffsetToRect(NSRect aRect)
  */
 - (void) update
 {
-  if (NSInterfaceStyleForKey(@"NSMenuInterfaceStyle", self)
-    == NSMacintoshInterfaceStyle)
+  BOOL	needTitleView;
+  BOOL	rootIsAppMenu;
+
+  NSDebugLLog (@"NSMenu", @"update called on menu view");
+
+  /*
+   * Ensure that a title view exists only if needed.
+   */
+  if (_attachedMenu == nil)
     {
-      [self sizeToFit];
+      needTitleView = NO;
     }
+  else if ([self _rootIsHorizontal: &rootIsAppMenu] == YES)
+    {
+      needTitleView = NO;
+    }
+  else if (rootIsAppMenu == YES)
+    {
+      needTitleView = YES;
+    } 
   else
     {
-      NSDebugLLog (@"NSMenu", @"update called on menu view");
+      needTitleView = ([_attachedMenu _ownedByPopUp] == YES) ? NO : YES;
+    }
 
-      /*
-       * Ensure that a title view exists only if needed.
-       */
-      if (![_attachedMenu _ownedByPopUp] && !_titleView)
+  if (needTitleView == YES && _titleView == nil)
+    {
+      _titleView = [[GSTitleView alloc] initWithOwner: _attachedMenu];
+      [self addSubview: _titleView];
+      RELEASE(_titleView);
+    }
+  if (needTitleView == NO && _titleView != nil)
+    {
+      [_titleView removeFromSuperview];
+      _titleView = nil;
+    }
+
+  [self sizeToFit];
+
+  if ([_attachedMenu _ownedByPopUp] == NO)
+    {
+      if ([_attachedMenu isTornOff] && ![_attachedMenu isTransient])
 	{
-	  _titleView = [[GSTitleView alloc] initWithOwner:_attachedMenu];
-	  [self addSubview: _titleView];
-	  RELEASE(_titleView);
+	  [_titleView
+	    addCloseButtonWithAction: @selector(_performMenuClose:)];
 	}
-      else if ([_attachedMenu _ownedByPopUp] && _titleView)
+      else
 	{
-	  [_titleView removeFromSuperview];
-	  _titleView = nil;
-	}
-
-      [self sizeToFit];
-
-      if ([_attachedMenu _ownedByPopUp] == NO)
-	{
-	  if ([_attachedMenu isTornOff] && ![_attachedMenu isTransient])
-	    {
-	      [_titleView
-		addCloseButtonWithAction: @selector(_performMenuClose:)];
-	    }
-	  else
-	    {
-	      [_titleView removeCloseButton];
-	    }
+	  [_titleView removeCloseButton];
 	}
     }
 }
@@ -809,9 +828,8 @@ _addLeftBorderOffsetToRect(NSRect aRect)
 				     + menuBarHeight)];
       [_titleView setFrame: NSMakeRect (0, howMany * _cellSize.height,
 					NSWidth (_bounds), menuBarHeight)];
-      
-      _needsSizing = NO;
     }
+  _needsSizing = NO;
 }
 
 - (float) stateImageOffset
@@ -893,8 +911,6 @@ _addLeftBorderOffsetToRect(NSRect aRect)
 
       aRect = GSIArrayItemAtIndex(cellRects, index).ext;
 
-      /* FIXME: handle vertical case? */
-
       return aRect.rect;
     }
   else
@@ -969,15 +985,15 @@ _addLeftBorderOffsetToRect(NSRect aRect)
 	    subOrigin.y - NSHeight(submenuFrame) - 3 +
 	    2*[NSMenuView menuBarHeight]);
 	}
-      else if ([self _rootIsHorizontal] == YES)
+      else if ([self _rootIsHorizontal: 0] == YES)
 	{
 	  NSRect aRect = [self rectOfItemAtIndex:
             [_attachedMenu indexOfItemWithSubmenu: aSubmenu]];
 	  NSPoint subOrigin = [_window convertBaseToScreen:
             NSMakePoint(aRect.origin.x, aRect.origin.y)];
-    
+          // FIXME ... why is the offset +1 needed below? 
 	  return NSMakePoint (NSMaxX(frame),
-	    subOrigin.y - NSHeight(submenuFrame) + aRect.size.height);
+	    subOrigin.y - NSHeight(submenuFrame) + aRect.size.height + 1);
 	}
       else
 	{
@@ -1042,7 +1058,8 @@ _addLeftBorderOffsetToRect(NSRect aRect)
 	  // Compute position for popups, if needed
 	  if (selectedItemIndex != -1) 
 	    {
-	      screenFrame.origin.y += screenRect.size.height * selectedItemIndex;
+	      screenFrame.origin.y
+		+= screenRect.size.height * selectedItemIndex;
 	    }
 	}
       else
@@ -1572,7 +1589,7 @@ _addLeftBorderOffsetToRect(NSRect aRect)
 - (void) encodeWithCoder: (NSCoder*)encoder
 {
   [super encodeWithCoder: encoder];
-  if([encoder allowsKeyedCoding] == NO)
+  if ([encoder allowsKeyedCoding] == NO)
     {
       [encoder encodeObject: _itemCells];
       [encoder encodeObject: _font];
@@ -1585,7 +1602,7 @@ _addLeftBorderOffsetToRect(NSRect aRect)
 - (id) initWithCoder: (NSCoder*)decoder
 {
   self = [super initWithCoder: decoder];
-  if([decoder allowsKeyedCoding] == NO)
+  if ([decoder allowsKeyedCoding] == NO)
     {
       [decoder decodeValueOfObjCType: @encode(id) at: &_itemCells];
       
