@@ -98,6 +98,7 @@ static NSImage *unexpandable  = nil;
 - (void) _setObjectValue: (id)value
 	  forTableColumn: (NSTableColumn *)tb
 		     row: (int) index;
+- (int) _numRows;
 @end
 
 // These methods are private...
@@ -122,9 +123,9 @@ static NSImage *unexpandable  = nil;
     {
       [self setVersion: current_version];
       nc = [NSNotificationCenter defaultCenter];
-      collapsed    = [NSImage imageNamed: @"common_outlineCollapsed.tiff"];
-      expanded     = [NSImage imageNamed: @"common_outlineExpanded.tiff"];
-      unexpandable = [NSImage imageNamed: @"common_outlineUnexpandable.tiff"];
+      collapsed    = [NSImage imageNamed: @"common_outlineCollapsed"];
+      expanded     = [NSImage imageNamed: @"common_outlineExpanded"];
+      unexpandable = [NSImage imageNamed: @"common_outlineUnexpandable"];
     }
 }
 
@@ -150,7 +151,6 @@ static NSImage *unexpandable  = nil;
 			       64);
   _items = [[NSMutableArray alloc] init];
   _expandedItems = [[NSMutableArray alloc] init];
-  _selectedItems = [[NSMutableArray alloc] init];
   _levelOfItems = NSCreateMapTable(NSObjectMapKeyCallBacks,
 				   NSObjectMapValueCallBacks,
 				   64);
@@ -161,7 +161,6 @@ static NSImage *unexpandable  = nil;
 {
   RELEASE(_items);
   RELEASE(_expandedItems);
-  RELEASE(_selectedItems);
 
   NSFreeMapTable(_itemDict);
   NSFreeMapTable(_levelOfItems);
@@ -227,7 +226,6 @@ static NSImage *unexpandable  = nil;
   if ([self isExpandable: item] && [self isItemExpanded: item] && canCollapse)
     {
       NSMutableDictionary *infoDict = [NSMutableDictionary dictionary];
-      unsigned int row;
 
       [infoDict setObject: item forKey: @"NSObject"];
       
@@ -237,18 +235,6 @@ static NSImage *unexpandable  = nil;
 	  object: self
 	  userInfo: infoDict];
       
-      // We save the selection
-      [_selectedItems removeAllObjects];
-      row = [_selectedRows firstIndex];
-      while (row != NSNotFound)
-        {
-	  if ([self itemAtRow: row])
-	    {
-	      [_selectedItems addObject: [self itemAtRow: row]];
-	    }
-	  row = [_selectedRows indexGreaterThanIndex: row];
-	}
-
       // collapse...
       [self _closeItem: item];
 
@@ -316,7 +302,6 @@ static NSImage *unexpandable  = nil;
       if (![self isItemExpanded: item] && canExpand)
 	{
 	  NSMutableDictionary *infoDict = [NSMutableDictionary dictionary];
-	  unsigned int row;
 
 	  [infoDict setObject: item forKey: @"NSObject"];
 	  
@@ -326,18 +311,6 @@ static NSImage *unexpandable  = nil;
 	      object: self
 	      userInfo: infoDict];
 	  
-	  // We save the selection
-	  [_selectedItems removeAllObjects];
-	  row = [_selectedRows firstIndex];
-	  while (row != NSNotFound)
-	    {
-	      if ([self itemAtRow: row])
-	        {
-		  [_selectedItems addObject: [self itemAtRow: row]];
-		}
-	      row = [_selectedRows indexGreaterThanIndex: row];
-	    }
-	  
 	  // insert the root element, if necessary otherwise insert the
 	  // actual object.
 	  [self _openItem: item];
@@ -617,52 +590,6 @@ static NSImage *unexpandable  = nil;
   return YES;
 }
 
-
-/**
- *  We override the super class's method.
- */
-- (void) noteNumberOfRowsChanged
-{
-  _numberOfRows = [_items count];
-
-  if (!_selectingColumns)
-    {
-      int i, count, row;
-      
-      /* We restore the selection */
-      [_selectedRows removeAllIndexes];
-      count = [_selectedItems count];
-
-      for (i = 0; i < count; i++)
-	{
-	  row = [self rowForItem: [_selectedItems objectAtIndex: i]];
-
-	  if (row >= 0 && row < _numberOfRows)
-	    {
-	      [_selectedRows addIndex: row];
-	    }
-	}
-    }
-
-  [self setFrame: NSMakeRect (_frame.origin.x, 
-			      _frame.origin.y,
-			      _frame.size.width, 
-			      (_numberOfRows * _rowHeight) + 1)];
-  
-  /* If we are shorter in height than the enclosing clipview, we
-     should redraw us now. */
-  if (_super_view != nil)
-    {
-      NSRect superviewBounds; // Get this *after* [self setFrame:]
-      superviewBounds = [_super_view bounds];
-      if ((superviewBounds.origin.x <= _frame.origin.x) 
-          && (NSMaxY (superviewBounds) >= NSMaxY (_frame)))
-	{
-	  [self setNeedsDisplay: YES];
-	}
-    }
-}
-
 /**
  * Sets the data source for this outline view. 
  */
@@ -782,7 +709,6 @@ static NSImage *unexpandable  = nil;
 				   64);
       _items = [[NSMutableArray alloc] init];
       _expandedItems = [[NSMutableArray alloc] init];
-      _selectedItems = [[NSMutableArray alloc] init];
       _levelOfItems = NSCreateMapTable(NSObjectMapKeyCallBacks,
 				       NSObjectMapValueCallBacks,
 				       64);
@@ -816,7 +742,6 @@ static NSImage *unexpandable  = nil;
 				   64);
       _items = [[NSMutableArray alloc] init];
       _expandedItems = [[NSMutableArray alloc] init];
-      _selectedItems = [[NSMutableArray alloc] init];
       _levelOfItems = NSCreateMapTable(NSObjectMapKeyCallBacks,
 				       NSObjectMapValueCallBacks,
 				       64); 
@@ -832,14 +757,16 @@ static NSImage *unexpandable  = nil;
   _clickedRow = [self rowAtPoint: location];
   _clickedColumn = [self columnAtPoint: location];
 
-  if ([_tableColumns objectAtIndex: _clickedColumn] == _outlineTableColumn)
+  if (_clickedRow != -1
+      && [_tableColumns objectAtIndex: _clickedColumn] == _outlineTableColumn)
     {
       NSImage *image;
-
+      
+      id item = [self itemAtRow:_clickedRow];
       int level = [self levelForRow: _clickedRow];
       int position = 0;
-      
-      if ([self isItemExpanded: [self itemAtRow: _clickedRow]])
+     
+      if ([self isItemExpanded: item])
 	{
 	  image = expanded;
 	}
@@ -855,15 +782,17 @@ static NSImage *unexpandable  = nil;
 
       position += _columnOrigins[_clickedColumn];
 
-      if (location.x >= position && location.x <= position + [image size].width)
+      if ([self isExpandable:item]
+	  && location.x >= position
+      	  && location.x <= position + [image size].width)
 	{
-	  if (![self isItemExpanded: [self itemAtRow: _clickedRow]])
+	  if (![self isItemExpanded: item])
 	    {
-	      [self expandItem: [self itemAtRow: _clickedRow]];
+	      [self expandItem: item];
 	    }
 	  else
 	    {
-	      [self collapseItem: [self itemAtRow: _clickedRow]];
+	      [self collapseItem: item];
 	    }
 	  return;
 	}
@@ -1361,17 +1290,14 @@ static NSImage *unexpandable  = nil;
   NSTableColumn *tb;
   NSRect drawingRect, imageRect;
   unsigned length = 0;
-  id item = nil;
   int level = 0;
   float indentationFactor = 0.0;
-  NSImage *image = nil;
-  NSCell *imageCell = nil;
 
   // We refuse to edit cells if the delegate can not accept results 
   // of editing.
   if (_dataSource_editable == NO)
     {
-      return;
+      flag = YES;
     }
   
   [self scrollRowToVisible: rowIndex];
@@ -1404,14 +1330,13 @@ static NSImage *unexpandable  = nil;
   
   _editedRow = rowIndex;
   _editedColumn = columnIndex;
-  item = [self itemAtRow: _editedRow];
 
   // Prepare the cell
   tb = [_tableColumns objectAtIndex: columnIndex];
   // NB: need to be released when no longer used
   _editedCell = [[tb dataCellForRow: rowIndex] copy];
 
-  [_editedCell setEditable: YES];
+  [_editedCell setEditable: _dataSource_editable];
   [_editedCell setObjectValue: [self _objectValueForTableColumn: tb
 				     row: rowIndex]];
 
@@ -1447,29 +1372,32 @@ static NSImage *unexpandable  = nil;
 
   _textObject = [_editedCell setUpFieldEditorAttributes: t];
 
-  // determine which image to use...
-  if ([self isItemExpanded: item])
-    {
-      image = expanded;
-    }
-  else
-    {
-      image = collapsed;
-    }
-
-  if (![self isExpandable: item])
-    {
-      image = unexpandable;
-    }
-  // move the drawing rect over like in the drawRow routine...
   drawingRect = [self frameOfCellAtColumn: columnIndex  row: rowIndex];
 
   if (tb == [self outlineTableColumn])
     {
+      id item = nil;
+      NSImage *image = nil;
+      NSCell *imageCell = nil;
+
+      item = [self itemAtRow: _editedRow];
+      // determine which image to use...
+      if ([self isItemExpanded: item])
+        {
+	  image = expanded;
+	}
+      else
+        {
+	  image = collapsed;
+	}
+
+      if (![self isExpandable: item])
+        {
+	  image = unexpandable;
+	}
+
       level = [self levelForItem: item];
       indentationFactor = _indentationPerLevel * level;
-      drawingRect.origin.x += indentationFactor + 5 + [image size].width;
-      drawingRect.size.width -= indentationFactor + 5 + [image size].width;
 
       // create the image cell..
       imageCell = [[NSCell alloc] initImageCell: image];
@@ -1484,13 +1412,19 @@ static NSImage *unexpandable  = nil;
 	  imageRect.origin.y = drawingRect.origin.y;
 	}
       
-      // draw...
       imageRect.size.width = [image size].width;
       imageRect.size.height = [image size].height;
 
+      // draw...
       [self lockFocus];
       [imageCell drawWithFrame: imageRect inView: self];
       [self unlockFocus];
+
+      // move the drawing rect over like in the drawRow routine...
+      drawingRect.origin.x += indentationFactor + 5 + [image size].width;
+      drawingRect.size.width -= indentationFactor + 5 + [image size].width;
+
+      RELEASE(imageCell);
     }
 
   if (flag)
@@ -1700,6 +1634,11 @@ static NSImage *unexpandable  = nil;
     }
 }
 
+- (int) _numRows
+{
+  return [_items count];
+}
+
 @end
 
 @implementation NSOutlineView (TableViewInternalPrivate)
@@ -1892,7 +1831,6 @@ static NSImage *unexpandable  = nil;
       NSMapRemove(_itemDict, child); 
       [_items removeObject: child];
       [_expandedItems removeObject: child];
-      [_selectedItems removeObject: child];
     }
   [anarray removeAllObjects];
 }
