@@ -1979,9 +1979,8 @@ static  NSMapTable              *mimeMap = NULL;
 		GSToolsDirectory, NSSystemDomainMask, YES) objectAtIndex: 0]
 		stringByAppendingPathComponent: @"gpbs"]);
 #else
-	      cmd = RETAIN([[@GNUSTEP_INSTALL_PREFIX 
-		stringByAppendingPathComponent: @"Tools"] 
-		stringByAppendingPathComponent: @"gpbs"]);
+	      path = RETAIN([@GNUSTEP_TOOLS_NO_DESTDIR
+			      stringByAppendingPathComponent: @"gpbs"]);
 #endif
 	    }
 	  if (recursion == YES || cmd == nil)
@@ -2007,12 +2006,16 @@ description, [cmd stringByDeletingLastPathComponent]);
 		{
 		  args = [[NSArray alloc] initWithObjects:
 		    @"-NSHost", host,
-		    @"-GSStartupNotification",@"GSStartup-GPBS", nil];
+		    @"-GSStartupNotification", @"GSStartup-GPBS",
+		    @"--auto",
+		    nil];
 		}
 	      else
 		{
 		  args = [[NSArray alloc] initWithObjects:
-		    @"-GSStartupNotification",@"GSStartup-GPBS", nil];
+		    @"-GSStartupNotification",@"GSStartup-GPBS",
+		    @"--auto",
+		    nil];
 		}
 
 	      /*
@@ -2036,7 +2039,7 @@ description, [cmd stringByDeletingLastPathComponent]);
 	      timeoutDate = [NSDate dateWithTimeIntervalSinceNow: 5.0];
 
 	      while ([startIndicator count]
-		     && [timeoutDate timeIntervalSinceNow] > 0.0)
+	        && [timeoutDate timeIntervalSinceNow] > 0.0)
 		{
 		  [[NSRunLoop currentRunLoop]
 		       runMode: NSDefaultRunLoopMode
