@@ -51,6 +51,16 @@ static NSImage *_pbc_image[2];
     }
 }
 
++ (BOOL) prefersTrackingUntilMouseUp
+{
+  return YES;
+}
+
++ (NSFocusRingType) defaultFocusRingType
+{
+  return NSFocusRingTypeDefault;
+}
+
 // Initialization
 /**
  * Initialize a blank cell.
@@ -838,9 +848,10 @@ static NSImage *_pbc_image[2];
   if ([[_menu window] isVisible])
     {
       [self dismissPopUp];
+      return NO;
     }
 
-  return NO;
+  return YES;
 }
 
 /**
@@ -882,12 +893,6 @@ static NSImage *_pbc_image[2];
   [self calcSize];
   [super drawInteriorWithFrame: cellFrame inView: controlView];
 
-  if (_cell.shows_first_responder)
-    {
-      cellFrame = [self drawingRectForBounds: cellFrame];
-      NSDottedFrameRect(cellFrame);
-    }
-
   /* Unset the item to restore balance if a new was created */
   if (new)
     {
@@ -959,7 +964,7 @@ static NSImage *_pbc_image[2];
 - (void) encodeWithCoder: (NSCoder*)aCoder
 {
   [super encodeWithCoder: aCoder];
-  if([aCoder allowsKeyedCoding])
+  if ([aCoder allowsKeyedCoding])
     {
       [aCoder encodeBool: [self altersStateOfSelectedItem] forKey: @"NSAltersState"];
       [aCoder encodeBool: [self usesItemFromMenu] forKey: @"NSUsesItemFromMenu"];
@@ -967,7 +972,7 @@ static NSImage *_pbc_image[2];
       [aCoder encodeInt: [self preferredEdge] forKey: @"NSPreferredEdge"];
       
       // encode the menu, if present.
-      if(_menu != nil)
+      if (_menu != nil)
 	{
 	  [aCoder encodeObject: _menu forKey: @"NSMenu"];
 	}
