@@ -180,14 +180,16 @@
 
 - (void) helpRequested: (NSEvent*)theEvent
 {
-  if (![[NSHelpManager sharedHelpManager]
-	showContextHelpForObject: self
-	locationHint: [theEvent locationInWindow]])
-    if (_next_responder)
-      {
-	[_next_responder helpRequested: theEvent];
-	return;
-      }
+  if ([[NSHelpManager sharedHelpManager]
+    showContextHelpForObject: self
+    locationHint: [theEvent locationInWindow]] == NO)
+    {
+      if (_next_responder)
+	{
+	  [_next_responder helpRequested: theEvent];
+	  return;
+	}
+    }
   [NSHelpManager setContextHelpModeActive: NO];
 }
 
@@ -424,7 +426,10 @@
 
 - (NSUndoManager*) undoManager
 {
-  return nil;
+  if (_next_responder)
+    return [_next_responder undoManager];
+  else
+    return nil;
 }
 
 - (BOOL) shouldBeTreatedAsInkEvent: (NSEvent *)theEvent
@@ -432,4 +437,48 @@
   return NO;
 }
 
+- (BOOL)presentError:(NSError *)error
+{
+  error = [self willPresentError: error];
+
+  if (_next_responder)
+    {
+	return [_next_responder presentError: error];
+    }
+  else
+    {
+      return [NSApp presentError: error];
+    }
+}
+
+- (void)presentError:(NSError *)error
+      modalForWindow:(NSWindow *)window
+	    delegate:(id)delegate 
+  didPresentSelector:(SEL)sel
+	 contextInfo:(void *)context
+{
+  error = [self willPresentError: error];
+  if (_next_responder)
+    {
+      [_next_responder presentError: error
+		       modalForWindow: window
+		       delegate: delegate
+		       didPresentSelector: sel
+		       contextInfo: context];
+    }
+  else
+    {
+      [NSApp presentError: error
+	     modalForWindow: window
+	     delegate: delegate
+	     didPresentSelector: sel
+	     contextInfo: context];
+    }
+}
+
+- (NSError *) willPresentError: (NSError *)error
+{
+  return error;
+}
+
 @end
