@@ -25,22 +25,25 @@
 
    You should have received a copy of the GNU Library General Public
    License along with this library; if not, write to the Free
-   Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111 USA.
+   Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02111 USA.
 */
 
 #include <Foundation/NSDebug.h>
 #include <Foundation/NSException.h>
+#include <Foundation/NSNotification.h>
 #include "AppKit/NSScroller.h"
 #include "AppKit/NSColor.h"
 #include "AppKit/NSCell.h"
 #include "AppKit/NSClipView.h"
+#include "AppKit/NSInterfaceStyle.h"
 #include "AppKit/NSScrollView.h"
 #include "AppKit/NSRulerView.h"
 #include "AppKit/NSTableHeaderView.h"
 #include "AppKit/NSTableView.h"
 #include "AppKit/NSWindow.h"
 #include "AppKit/PSOperators.h"
-#include "GNUstepGUI/GSDrawFunctions.h"
+#include "GNUstepGUI/GSTheme.h"
 
 //
 // For nib compatibility, this is used to properly
@@ -49,20 +52,30 @@
 typedef struct _scrollViewFlags 
 {
 #ifdef WORDS_BIGENDIAN
-  unsigned int __unused4:26;
-  unsigned int hasHScroller:1; // 16
-  unsigned int hasVScroller:1; // 32
+  unsigned int __unused4:22;
+  unsigned int autohidesScrollers:1;
+  unsigned int __unused1:3;
+  unsigned int hasHScroller:1;
+  unsigned int hasVScroller:1;
   unsigned int __unused0:2;
   NSBorderType border:2;
 #else
   NSBorderType border:2;
   unsigned int __unused0:2;
-  unsigned int hasVScroller:1; // 32
-  unsigned int hasHScroller:1; // 16
-  unsigned int __unused4:26;
+  unsigned int hasVScroller:1;
+  unsigned int hasHScroller:1;
+  unsigned int __unused1:3;
+  unsigned int autohidesScrollers:1;
+  unsigned int __unused4:22;
 #endif  
 } GSScrollViewFlags;
 
+@interface	NSScrollView (GSPrivate)
+/* GNUstep private methods */
+- (void) _synchronizeHeaderAndCornerView;
+- (void) _themeDidActivate: (NSNotification*)notification;
+@end
+
 @implementation NSScrollView
 
 /*
@@ -165,20 +178,24 @@ static float scrollerWidth;
   _vPageScroll = 10;
   _borderType = NSNoBorder;
   _scrollsDynamically = YES;
+  //_autohidesScrollers = NO;
+  // FIXME: Not sure here Apple says by default all scrollers are off.
   // For compatibility the ruler should be present but not visible.
   [self setHasHorizontalRuler: YES];
   [self tile];
 
+  [[NSNotificationCenter defaultCenter]
+    addObserver: self
+    selector: @selector(_themeDidActivate:)
+    name: GSThemeDidActivateNotification
+    object: nil];
   return self;
 }
 
-- (id) init
-{
-  return [self initWithFrame: NSZeroRect];
-}
-
 - (void) dealloc
 {
+  [[NSNotificationCenter defaultCenter] removeObserver: self];
+
   DESTROY(_horizScroller);
   DESTROY(_vertScroller);
   DESTROY(_horizRuler);
@@ -311,6 +328,16 @@ static float scrollerWidth;
   [self tile];
 }
 
+- (BOOL) autohidesScrollers
+{
+  return _autohidesScrollers;
+}
+
+- (void) setAutohidesScrollers: (BOOL)flag
+{
+  _autohidesScrollers = flag;
+}
+
 - (void) scrollWheel: (NSEvent *)theEvent
 {
   NSRect	clipViewBounds;
@@ -373,6 +400,90 @@ static float scrollerWidth;
   [_contentView scrollToPoint: point];
 }
 
+- (void) keyDown: (NSEvent *)theEvent
+{
+  NSString *chars = [theEvent characters];
+  unichar c = [chars length] == 1 ? [chars characterAtIndex: 0] : '\0';
+
+  switch (c)
+    {
+      case NSUpArrowFunctionKey:
+	[self scrollLineUp: self];
+	break;
+
+      case NSDownArrowFunctionKey:
+        [self scrollLineDown: self];
+	break;
+
+      case NSPageUpFunctionKey:
+	[self scrollPageUp: self];
+	break;
+
+      case NSPageDownFunctionKey:
+	[self scrollPageDown: self];
+	break;
+
+      default:
+	[super keyDown: theEvent];
+	break;
+    }
+}
+
+/*
+ * This code is based on _doScroll: and still may need some tuning. 
+ */
+- (void) scrollLineUp: (id)sender
+{
+  NSRect  clipViewBounds;
+  NSPoint point;
+  float   amount;
+
+  if (_contentView == nil)
+    {
+      clipViewBounds = NSZeroRect;
+    }
+  else
+    {
+      clipViewBounds = [_contentView bounds];
+    }
+  point = clipViewBounds.origin;
+  amount = _vLineScroll;
+  if (_contentView != nil && !_contentView->_rFlags.flipped_view)
+    {
+      amount = -amount;
+    }
+  point.y = clipViewBounds.origin.y - amount;
+  [_contentView scrollToPoint: point];
+}
+
+
+/*
+ * This code is based on _doScroll: and still may need some tuning. 
+ */
+- (void) scrollLineDown: (id)sender
+{
+  NSRect  clipViewBounds;
+  NSPoint point;
+  float   amount;
+
+  if (_contentView == nil)
+    {
+      clipViewBounds = NSZeroRect;
+    }
+  else
+    {
+      clipViewBounds = [_contentView bounds];
+    }
+  point = clipViewBounds.origin;
+  amount = _vLineScroll;
+  if (_contentView != nil && !_contentView->_rFlags.flipped_view)
+    {
+      amount = -amount;
+    }
+  point.y = clipViewBounds.origin.y + amount;
+  [_contentView scrollToPoint: point];
+}
+
 /**
  * Scrolls the receiver by simply invoking scrollPageUp:
  */
@@ -602,11 +713,24 @@ static float scrollerWidth;
       documentFrame = [documentView frame];
     }
 
+  // FIXME: Should we just hide the scroll bar or remove it?
+  if ((_autohidesScrollers) && (documentFrame.size.height > clipViewBounds.size.height))
+    {
+      [self setHasVerticalScroller: YES];	
+    } 
+ 
   if (_hasVertScroller)
     {
       if (documentFrame.size.height <= clipViewBounds.size.height)
 	{
-	  [_vertScroller setEnabled: NO];
+	  if (_autohidesScrollers)
+	    {
+	      [self setHasVerticalScroller: NO];
+	    }
+	  else
+	    {
+	      [_vertScroller setEnabled: NO];
+	    }
 	}
       else
 	{
@@ -627,11 +751,23 @@ static float scrollerWidth;
 	}
     }
 
+  if ((_autohidesScrollers) && (documentFrame.size.width > clipViewBounds.size.width))
+    {
+      [self setHasHorizontalScroller: YES];	
+    } 
+ 
   if (_hasHorizScroller)
     {
       if (documentFrame.size.width <= clipViewBounds.size.width)
 	{
-	  [_horizScroller setEnabled: NO];
+	  if (_autohidesScrollers)
+	    {
+	      [self setHasHorizontalScroller: NO];
+	    }
+	  else
+	    {
+	      [_horizScroller setEnabled: NO];
+	    }
 	}
       else
 	{
@@ -818,6 +954,15 @@ static float scrollerWidth;
   NSSize border = _sizeForBorderType(_borderType);
   NSRectEdge bottomEdge, topEdge;
   float headerViewHeight = 0;
+  NSRectEdge	verticalScrollerEdge = NSMinXEdge;
+  NSInterfaceStyle	style;
+
+  style = NSInterfaceStyleForKey(@"NSScrollViewInterfaceStyle", nil);
+  if (style == NSMacintoshInterfaceStyle
+    || style == NSWindows95InterfaceStyle)
+    {
+      verticalScrollerEdge = NSMaxXEdge;
+    }
 
   /* Determine edge positions.  */
   if (_rFlags.flipped_view)
@@ -831,8 +976,8 @@ static float scrollerWidth;
       bottomEdge = NSMinYEdge;
     }
 
-  /* Prepare the contentRect by the insetting the borders.  */
-  contentRect = NSInsetRect (_bounds, border.width, border.height);
+  /* Prepare the contentRect by insetting the borders.  */
+  contentRect = NSInsetRect(_bounds, border.width, border.height);
   
   [self _synchronizeHeaderAndCornerView];
   
@@ -868,13 +1013,13 @@ static float scrollerWidth;
       NSRect vertScrollerRect;
 
       NSDivideRect (contentRect, &vertScrollerRect, &contentRect, 
-		    scrollerWidth, NSMinXEdge);
+	scrollerWidth, verticalScrollerEdge);
 
       [_vertScroller setFrame: vertScrollerRect];
 
       /* Substract 1 for the line that separates the vertical scroller
        * from the clip view (and eventually the horizontal scroller).  */
-      NSDivideRect (contentRect, NULL, &contentRect, 1, NSMinXEdge);
+      NSDivideRect (contentRect, NULL, &contentRect, 1, verticalScrollerEdge);
     }
 
   /* Prepare the horizontal scroller.  */
@@ -883,7 +1028,7 @@ static float scrollerWidth;
       NSRect horizScrollerRect;
       
       NSDivideRect (contentRect, &horizScrollerRect, &contentRect, 
-		    scrollerWidth, bottomEdge);
+	scrollerWidth, bottomEdge);
 
       [_horizScroller setFrame: horizScrollerRect];
 
@@ -907,7 +1052,13 @@ static float scrollerWidth;
   /* Now place the corner view.  */
   if (_hasCornerView)
     {
-      [_cornerView setFrameOrigin: headerRect.origin];
+      NSPoint	p = headerRect.origin;
+
+      if (verticalScrollerEdge == NSMaxXEdge)
+        {
+	  p.x += contentRect.size.width;
+	}
+      [_cornerView setFrameOrigin: p];
     }
 
   /* Now place the rulers.  */
@@ -918,7 +1069,7 @@ static float scrollerWidth;
 	  NSRect horizRulerRect;
 	  
 	  NSDivideRect (contentRect, &horizRulerRect, &contentRect,
-			[_horizRuler requiredThickness], topEdge);
+	    [_horizRuler requiredThickness], topEdge);
 	  [_horizRuler setFrame: horizRulerRect];
 	}
 
@@ -927,7 +1078,7 @@ static float scrollerWidth;
 	  NSRect vertRulerRect;
 	  
 	  NSDivideRect (contentRect, &vertRulerRect, &contentRect,
-			[_vertRuler requiredThickness], NSMinXEdge);
+	    [_vertRuler requiredThickness], NSMinXEdge);
 	  [_vertRuler setFrame: vertRulerRect];
 	}
     }
@@ -951,11 +1102,11 @@ static float scrollerWidth;
 	break;
 
       case NSBezelBorder:
-	[GSDrawFunctions drawGrayBezel: _bounds : rect];
+	[[GSTheme theme] drawGrayBezel: _bounds withClip: rect];
 	break;
 
       case NSGrooveBorder:
-	[GSDrawFunctions drawGroove: _bounds : rect];
+	[[GSTheme theme] drawGroove: _bounds withClip: rect];
 	break;
     }
 
@@ -964,8 +1115,20 @@ static float scrollerWidth;
 
   if (_hasVertScroller)
     {
-      DPSmoveto(ctxt, [_vertScroller frame].origin.x + scrollerWidth, 
-		[_vertScroller frame].origin.y - 1);
+      NSInterfaceStyle	style;
+
+      style = NSInterfaceStyleForKey(@"NSScrollViewInterfaceStyle", nil);
+      if (style == NSMacintoshInterfaceStyle
+        || style == NSWindows95InterfaceStyle)
+        {
+          DPSmoveto(ctxt, [_vertScroller frame].origin.x - 1, 
+	    [_vertScroller frame].origin.y - 1);
+	}
+      else
+        {
+          DPSmoveto(ctxt, [_vertScroller frame].origin.x + scrollerWidth, 
+	    [_vertScroller frame].origin.y - 1);
+	}
       DPSrlineto(ctxt, 0, [_vertScroller frame].size.height + 1);
       DPSstroke(ctxt);
     }
@@ -1005,12 +1168,12 @@ static float scrollerWidth;
   return [_contentView backgroundColor];
 }
 
-- (void)setDrawsBackground:(BOOL)flag
+- (void) setDrawsBackground: (BOOL)flag
 {
   [_contentView setDrawsBackground: flag];
 }
 
-- (BOOL)drawsBackground
+- (BOOL) drawsBackground
 {
   return [_contentView drawsBackground];
 }
@@ -1218,7 +1381,7 @@ static float scrollerWidth;
 {
   [super encodeWithCoder: aCoder];
       
-  if([aCoder allowsKeyedCoding])
+  if ([aCoder allowsKeyedCoding])
     {
       unsigned long flags = 0;
       GSScrollViewFlags scrollViewFlags;
@@ -1228,7 +1391,7 @@ static float scrollerWidth;
       [aCoder encodeObject: _contentView forKey: @"NSContentView"];
 
       // only encode this, if it's not null...
-      if(_headerClipView != nil)
+      if (_headerClipView != nil)
 	{
 	  [aCoder encodeObject: _headerClipView forKey: @"NSHeaderClipView"];
 	}
@@ -1297,12 +1460,14 @@ static float scrollerWidth;
 
       if ([aDecoder containsValueForKey: @"NSsFlags"])
         {
-	  unsigned long flags = [aDecoder decodeIntForKey: @"NSsFlags"];
+	  int flags = [aDecoder decodeInt32ForKey: @"NSsFlags"];
 	  GSScrollViewFlags scrollViewFlags;
+	  // FIXME: Why not just use a cast?
 	  memcpy((void *)&scrollViewFlags,(void *)&flags,sizeof(struct _scrollViewFlags));
 
 	  _hasVertScroller = scrollViewFlags.hasVScroller;
 	  _hasHorizScroller = scrollViewFlags.hasHScroller;
+	  _autohidesScrollers = scrollViewFlags.autohidesScrollers;
 	  // _scrollsDynamically = (!scrollViewFlags.notDynamic);
 	  // _rulersVisible = scrollViewFlags.rulersVisible;
 	  // _hasHorizRuler = scrollViewFlags.hasHRuler;
@@ -1313,10 +1478,11 @@ static float scrollerWidth;
 
       if (content != nil)
         {
+          // FIXME: I think this is not needed as we re-tile anyway.
 	  NSRect frame = [content frame];
 	  float w = [vScroller frame].size.width;
 
-	  if(_hasVertScroller)
+	  if (_hasVertScroller)
 	    {
 	      //
 	      // Slide the content view over, since on Mac OS X the scroller is on the
@@ -1327,6 +1493,7 @@ static float scrollerWidth;
 	      [content setFrame: frame];
 	    }
 
+	  // FIXME: No idea what is going on here.
 	  // retain the view and reset the content view...
 	  RETAIN(content);
 	  [self setContentView: content];
@@ -1348,7 +1515,8 @@ static float scrollerWidth;
 	{
 	  _hasHeaderView = YES;
 	  _hasCornerView = YES;	  
-	  ASSIGN(_headerClipView, [aDecoder decodeObjectForKey: @"NSHeaderClipView"]);
+	  ASSIGN(_headerClipView,
+	    [aDecoder decodeObjectForKey: @"NSHeaderClipView"]);
 	}
 
       [self tile];
@@ -1408,6 +1576,10 @@ static float scrollerWidth;
   return self;
 }
 
+@end
+
+@implementation	NSScrollView (GSPrivate)
+
 /* GNUstep private method */
 
 /* we update both of these at the same time during -tile
@@ -1418,6 +1590,7 @@ static float scrollerWidth;
   BOOL hadHeaderView = _hasHeaderView;
   BOOL hadCornerView = _hasCornerView;
   NSView *aView = nil;
+
   _hasHeaderView = ([[self documentView] 
                         respondsToSelector: @selector(headerView)]
                     && (aView=[(NSTableView *)[self documentView] headerView]));
@@ -1439,8 +1612,8 @@ static float scrollerWidth;
     {
       aView = nil; 
       _hasCornerView =
-              ([[self documentView] respondsToSelector: @selector(cornerView)]
-               && (aView=[(NSTableView *)[self documentView] cornerView]));
+	([[self documentView] respondsToSelector: @selector(cornerView)]
+	 && (aView=[(NSTableView *)[self documentView] cornerView]));
       
       if (aView == _cornerView)
         return;
@@ -1448,7 +1621,7 @@ static float scrollerWidth;
         {
           if (hadCornerView == NO)
             {
- 	      [self addSubview:aView];
+ 	      [self addSubview: aView];
 	    }
           else
             {
@@ -1469,4 +1642,10 @@ static float scrollerWidth;
     }
 }
 
+- (void) _themeDidActivate: (NSNotification*)notification
+{
+  [self tile];
+}
+
 @end
+
