@@ -117,7 +117,14 @@
   /* Draw background, then ... */ 
   if (_textfieldcell_draws_background)
     {
-      [_background_color set];
+      if ([self isEnabled])
+	{
+	  [_background_color set];
+	}
+      else
+	{
+	  [[NSColor controlBackgroundColor] set];
+	}
       NSRectFill ([self drawingRectForBounds: cellFrame]);
     }
   /* .. do nothing.  */
@@ -135,7 +142,7 @@
 - (id) initWithCoder: (NSCoder *)decoder
 {
   self = [super initWithCoder: decoder];
-  if([decoder allowsKeyedCoding])
+  if ([decoder allowsKeyedCoding])
     {
       // do nothing for now...
     }
