@@ -178,8 +178,7 @@ static id<GSSoundSvr> the_server = nil;
 								objectAtIndex: 0]
 			     stringByAppendingPathComponent: @"gnustep_sndd"]);
 #else
-	      cmd = RETAIN([[@GNUSTEP_INSTALL_PREFIX 
-			      stringByAppendingPathComponent: @"Tools"] 
+	      cmd = RETAIN([@GNUSTEP_TOOLS_NO_DESTDIR
 			     stringByAppendingPathComponent: @"gnustep_sndd"]);
 #endif
 	    }
@@ -667,7 +666,7 @@ return NO; \
 //
 - (void) encodeWithCoder: (NSCoder *)coder
 {
-  if([coder allowsKeyedCoding])
+  if ([coder allowsKeyedCoding])
     {
       // TODO_NIB: Determine keys for NSSound.
     }
@@ -701,7 +700,7 @@ return NO; \
 
 - (id) initWithCoder: (NSCoder*)decoder
 {	
-  if([decoder allowsKeyedCoding])
+  if ([decoder allowsKeyedCoding])
     {
       // TODO_NIB: Determine keys for NSSound.
     }
