@@ -35,19 +35,34 @@
 #include "AppKit/NSTabView.h"
 #include "AppKit/NSTabViewItem.h"
 #include "AppKit/PSOperators.h"
-#include "GNUstepGUI/GSDrawFunctions.h"
+#include "GNUstepGUI/GSTheme.h"
 
 @implementation NSTabView
 
+/*
+ * Class methods
+ */
++ (void) initialize
+{
+  if (self == [NSTabView class])
+    {
+      [self setVersion: 2];
+    }
+}
+
 - (id) initWithFrame: (NSRect)rect
 {
-  [super initWithFrame: rect];
+  self = [super initWithFrame: rect];
 
-  // setup variables  
-
-  ASSIGN (_items, [NSMutableArray array]);
-  ASSIGN (_font, [NSFont systemFontOfSize: 0]);
-  _selected = nil;
+  if (self)
+    {
+      // setup variables  
+      ASSIGN(_items, [NSMutableArray array]);
+      ASSIGN(_font, [NSFont systemFontOfSize: 0]);
+      _selected_item = NSNotFound;
+      //_selected = nil;
+      //_truncated_label = NO;
+    }
 
   return self;
 }
@@ -72,6 +87,11 @@
   [tabViewItem _setTabView: self];
   [_items insertObject: tabViewItem atIndex: index];
 
+  if ((_selected_item != NSNotFound) && (index <= _selected_item))
+    {
+      _selected_item++;
+    }
+
   if ([_delegate respondsToSelector: 
     @selector(tabViewDidChangeNumberOfTabViewItems:)])
     {
@@ -91,12 +111,19 @@
 
   if ([tabViewItem isEqual: _selected])
     {
+      // We cannot call [self selectTabViewItem: nil] here as the delegate might refuse this
       [[_selected view] removeFromSuperview];
       _selected = nil;
+      _selected_item = NSNotFound;
     }
 
   [_items removeObjectAtIndex: i];
 
+  if ((_selected_item != NSNotFound) && (i <= _selected_item))
+    {
+      _selected_item--;
+    }
+
   if ([_delegate respondsToSelector: 
     @selector(tabViewDidChangeNumberOfTabViewItems:)])
     {
@@ -156,18 +183,23 @@
 
 - (void) selectNextTabViewItem: (id)sender
 {
-  if ((unsigned)(_selected_item + 1) < [_items count])
-    [self selectTabViewItemAtIndex: _selected_item+1];
+  if ((_selected_item != NSNotFound) && ((unsigned)(_selected_item + 1) < [_items count]))
+    {
+      [self selectTabViewItemAtIndex: _selected_item + 1];
+    }
 }
 
 - (void) selectPreviousTabViewItem: (id)sender
 {
-  if (_selected_item > 0)
-    [self selectTabViewItemAtIndex: _selected_item-1];
+  if ((_selected_item != NSNotFound) && (_selected_item > 0))
+    {
+      [self selectTabViewItemAtIndex: _selected_item - 1];
+    }
 }
 
 - (NSTabViewItem*) selectedTabViewItem
 {
+  // FIXME: Why not just return _selected?
   if (_selected_item == NSNotFound || [_items count] == 0)
     return nil;
   return [_items objectAtIndex: _selected_item];
@@ -197,14 +229,13 @@
 	  [[_selected view] removeFromSuperview];
 	}
 
-      _selected = tabViewItem;
-
       if ([_delegate respondsToSelector: 
 	@selector(tabView: willSelectTabViewItem:)])
 	{
-	  [_delegate tabView: self willSelectTabViewItem: _selected];
+	  [_delegate tabView: self willSelectTabViewItem: tabViewItem];
 	}
 
+      _selected = tabViewItem;
       _selected_item = [_items indexOfObject: _selected];
       [_selected _setTabState: NSSelectedTab];
 
@@ -236,9 +267,10 @@
     [self selectTabViewItem: [_items objectAtIndex: index]];
 }
 
-- (void) selectTabViewItemWithIdentifier:(id)identifier 
+- (void) selectTabViewItemWithIdentifier: (id)identifier 
 {
   int index = [self indexOfTabViewItemWithIdentifier: identifier];
+
   [self selectTabViewItemAtIndex: index];
 }
 
@@ -318,14 +350,22 @@
 
 - (NSSize) minimumSize
 {
+  // FIXME: This should allow some space for the tabs
   switch (_type)
     {
       case NSTopTabsBezelBorder:
 	return NSMakeSize(2, 19.5);
       case NSNoTabsBezelBorder:
 	return NSMakeSize(2, 3);
+      case NSNoTabsLineBorder:
+	return NSMakeSize(2, 3);
       case NSBottomTabsBezelBorder:
 	return NSMakeSize(2, 16);
+      case NSLeftTabsBezelBorder:
+	return NSMakeSize(16, 3);
+      case NSRightTabsBezelBorder:
+	return NSMakeSize(16, 3);
+      case NSNoTabsNoBorder:
       default:
 	return NSZeroSize;
     }
@@ -335,26 +375,46 @@
 {
   NSRect cRect = _bounds;
 
-  if (_type == NSTopTabsBezelBorder)
+  /* 
+     FIXME: All these numbers seem wrong to me.
+     For a bezel border we loose 2 pixel on each side, 
+     for a line border 1 pixel. On top of that we will 
+     need the space for the tab.
+  */
+  switch (_type)
     {
-      cRect.origin.y += 1; 
-      cRect.origin.x += 0.5; 
-      cRect.size.width -= 2;
-      cRect.size.height -= 18.5;
-    }
-  
-  if (_type == NSNoTabsBezelBorder)
-    {
-      cRect.origin.y += 1; 
-      cRect.origin.x += 0.5; 
-      cRect.size.width -= 2;
-      cRect.size.height -= 2;
-    }
-
-  if (_type == NSBottomTabsBezelBorder)
-    {
-      cRect.size.height -= 8;
-      cRect.origin.y = 8;
+      case NSTopTabsBezelBorder:
+	cRect.origin.y += 1; 
+	cRect.origin.x += 0.5; 
+	cRect.size.width -= 2;
+	cRect.size.height -= 18.5;
+	break;
+      case NSNoTabsBezelBorder:
+	cRect.origin.y += 1; 
+	cRect.origin.x += 0.5; 
+	cRect.size.width -= 2;
+	cRect.size.height -= 2;
+	break;
+      case NSNoTabsLineBorder:
+	cRect.origin.y += 1; 
+	cRect.origin.x += 0.5; 
+	cRect.size.width -= 2;
+	cRect.size.height -= 2;
+	break;
+      case NSBottomTabsBezelBorder:
+	cRect.size.height -= 8;
+	cRect.origin.y = 8;
+	break;
+      case NSLeftTabsBezelBorder:
+	cRect.size.width -= 16;
+	cRect.origin.x += 16;
+	break;
+      case NSRightTabsBezelBorder:
+	cRect.size.width -= 16;
+	break;
+      case NSNoTabsNoBorder:
+      default:
+	break;
     }
 
   return cRect;
@@ -365,11 +425,18 @@
 - (void) drawRect: (NSRect)rect
 {
   NSGraphicsContext     *ctxt = GSCurrentContext();
+  GSTheme		*theme = [GSTheme theme];
   int			howMany = [_items count];
   int			i;
-  NSRect		previousRect = NSMakeRect(0, 0, 0, 0);
   int			previousState = 0;
   NSRect		aRect = _bounds;
+  NSColor *lineColour = [NSColor highlightColor];
+  NSColor *backgroundColour = [[self window] backgroundColor];
+  BOOL truncate = [self allowsTruncatedLabels];
+
+  // Make sure some tab is selected
+  if (!_selected && howMany > 0)
+    [self selectFirstTabViewItem: nil];
 
   DPSgsave(ctxt);
 
@@ -378,18 +445,29 @@
       default:
       case NSTopTabsBezelBorder: 
 	aRect.size.height -= 16;
-	[GSDrawFunctions drawButton: aRect : NSZeroRect];
+	[theme drawButton: aRect withClip: rect];
 	break;
 
       case NSBottomTabsBezelBorder: 
 	aRect.size.height -= 16;
 	aRect.origin.y += 16;
-	[GSDrawFunctions drawButton: aRect : rect];
+	[theme drawButton: aRect withClip: rect];
 	aRect.origin.y -= 16;
 	break;
 
+      case NSLeftTabsBezelBorder: 
+	aRect.size.width -= 18;
+	aRect.origin.x += 18;
+	[theme drawButton: aRect withClip: rect];
+	break;
+
+      case NSRightTabsBezelBorder: 
+	aRect.size.width -= 18;
+	[theme drawButton: aRect withClip: rect];
+	break;
+
       case NSNoTabsBezelBorder: 
-	[GSDrawFunctions drawButton: aRect : rect];
+	[theme drawButton: aRect withClip: rect];
 	break;
 
       case NSNoTabsLineBorder: 
@@ -401,90 +479,50 @@
 	break;
     }
 
-  if (!_selected && howMany > 0)
-    [self selectFirstTabViewItem: nil];
-
-  if (_type == NSNoTabsBezelBorder || _type == NSNoTabsLineBorder)
-    {
-      DPSgrestore(ctxt);
-      return;
-    }
-
   if (_type == NSBottomTabsBezelBorder)
     {
+      NSPoint iP;
+
+      iP.x = _bounds.origin.x;
+      iP.y = _bounds.origin.y;
+	      
       for (i = 0; i < howMany; i++) 
 	{
-	  // where da tab be at?
-	  NSSize	s;
-	  NSRect	r;
-	  NSPoint	iP;
+	  NSRect r;
+	  NSRect fRect;
 	  NSTabViewItem *anItem = [_items objectAtIndex: i];
-	  NSTabState	itemState;
-
-	  itemState = [anItem tabState];
-
-	  s = [anItem sizeOfLabel: NO];
+	  NSTabState itemState = [anItem tabState];
+	  NSSize s = [anItem sizeOfLabel: truncate];
+	  
+	  [backgroundColour set];
 
 	  if (i == 0)
 	    {
-	      int iFlex = 0;
-	      iP.x = aRect.origin.x;
-	      iP.y = aRect.origin.y;
-	      
-	      [[NSColor controlBackgroundColor] set];
-
 	      if (itemState == NSSelectedTab)
 		{
 		  iP.y += 1;
-	          NSRectFill (NSMakeRect (iP.x, iP.y, 14, 17));
-		  [[NSImage imageNamed: @"common_TabDownSelectedLeft.tiff"]
+	          NSRectFill(NSMakeRect(iP.x, iP.y, 14, 17));
+		  [[NSImage imageNamed: @"common_TabDownSelectedLeft"]
 		    compositeToPoint: iP operation: NSCompositeSourceOver];
 		  iP.y -= 1;
-		  iFlex = 1;
 		}
 	      else if (itemState == NSBackgroundTab)
 		{
-		  iP.y += 1;
-	          NSRectFill (NSMakeRect (iP.x, iP.y, 14, 17));
-		  [[NSImage imageNamed: @"common_TabDownUnSelectedLeft.tiff"]
+	          NSRectFill(NSMakeRect(iP.x, iP.y, 14, 17));
+		  [[NSImage imageNamed: @"common_TabDownUnSelectedLeft"]
 		    compositeToPoint: iP operation: NSCompositeSourceOver];
-		  iP.y -= 1;
 		}
 	      else
 		NSLog(@"Not finished yet. Luff ya.\n");
-
-	      r.origin.x = aRect.origin.x + 13;
-	      r.origin.y = aRect.origin.y + 2;
-	      r.size.width = s.width;
-	      r.size.height = 15 + iFlex;
-
-	      DPSsetlinewidth(ctxt,1);
-	      DPSsetgray(ctxt, NSWhite);
-	      DPSmoveto(ctxt, r.origin.x, r.origin.y-1);
-	      DPSrlineto(ctxt, r.size.width, 0);
-	      DPSstroke(ctxt);      
-
-	      [anItem drawLabel: NO inRect: r];
-
-	      previousRect = r;
-	      previousState = itemState;
 	    }
 	  else
 	    {
-	      int	iFlex = 0;
-
-	      iP.x = previousRect.origin.x + previousRect.size.width;
-	      iP.y = aRect.origin.y;
-	      
-	      [[NSColor controlBackgroundColor] set];
-
 	      if (itemState == NSSelectedTab) 
 		{
 		  iP.y += 1;
-		  iFlex = 1;
-	          NSRectFill (NSMakeRect (iP.x, iP.y, 14, 17));
+	          NSRectFill(NSMakeRect(iP.x, iP.y, 14, 17));
 		  [[NSImage imageNamed:
-		    @"common_TabDownUnSelectedToSelectedJunction.tiff"]
+		    @"common_TabDownUnSelectedToSelectedJunction"]
 		    compositeToPoint: iP operation: NSCompositeSourceOver];
 		  iP.y -= 1;
 		}
@@ -493,65 +531,68 @@
 		  if (previousState == NSSelectedTab)
 		    {
 		      iP.y += 1;
-	              NSRectFill (NSMakeRect (iP.x, iP.y, 14, 17));
+	              NSRectFill(NSMakeRect(iP.x, iP.y, 14, 17));
 		      [[NSImage imageNamed:
-			@"common_TabDownSelectedToUnSelectedJunction.tiff"]
+			@"common_TabDownSelectedToUnSelectedJunction"]
 			compositeToPoint: iP operation: NSCompositeSourceOver];
 		      iP.y -= 1;
-		      iFlex = -1;
 		    }
 		  else
 		    {
-		      //		    iP.y += 1;
-	              NSRectFill (NSMakeRect (iP.x, iP.y, 14, 17));
+	              NSRectFill(NSMakeRect(iP.x, iP.y, 14, 17));
 		      [[NSImage imageNamed:
-			@"common_TabDownUnSelectedJunction.tiff"]
+			@"common_TabDownUnSelectedJunction"]
 			compositeToPoint: iP operation: NSCompositeSourceOver];
-		      //iP.y -= 1;
-		      iFlex = -1;
 		    }
 		} 
 	      else
 		NSLog(@"Not finished yet. Luff ya.\n");
-	      
-	      r.origin.x = iP.x + 13;
-	      r.origin.y = aRect.origin.y + 2;
-	      r.size.width = s.width;
-	      r.size.height = 15 + iFlex; // was 15
-
-	      iFlex = 0;
-
-	      DPSsetlinewidth(ctxt,1);
-	      DPSsetgray(ctxt, NSWhite);
-	      DPSmoveto(ctxt, r.origin.x, r.origin.y - 1);
-	      DPSrlineto(ctxt, r.size.width, 0);
-	      DPSstroke(ctxt);      
-
-	      [anItem drawLabel: NO inRect: r];
-	      
-	      previousRect = r;
-	      previousState = itemState;
 	    }  
 
-	  if (i == howMany-1)
-	    {
-	      iP.x += s.width + 13;
+	  r.origin.x = iP.x + 13;
+	  r.origin.y = iP.y + 2;
+	  r.size.width = s.width;
+	  r.size.height = 15;
 
-	      [[NSColor controlBackgroundColor] set];
+	  fRect = r;
+	  if (itemState == NSSelectedTab)
+	    {
+	      // Undraw the line that separates the tab from its view.
+	      fRect.origin.y += 1;
+	      fRect.size.height += 1;
+	    }
+	  NSRectFill(fRect);
+
+	  // Draw the line at the bottom of the item
+	  [lineColour set];
+	  DPSsetlinewidth(ctxt, 1);
+	  DPSmoveto(ctxt, r.origin.x, r.origin.y - 1);
+	  DPSrlineto(ctxt, r.size.width, 0);
+	  DPSstroke(ctxt);
+	  
+	  // Label
+	  [anItem drawLabel: truncate inRect: r];
+	  
+	  iP.x += s.width + 13;
+	  previousState = itemState;
+
+	  if (i == howMany - 1)
+	    {
+	      [backgroundColour set];
 
 	      if ([anItem tabState] == NSSelectedTab)
 	        {
-	          NSRectFill (NSMakeRect (iP.x, iP.y, 14, 17));
-		  [[NSImage imageNamed: @"common_TabDownSelectedRight.tiff"]
+		  iP.y += 1;
+	          NSRectFill(NSMakeRect(iP.x, iP.y, 14, 17));
+		  [[NSImage imageNamed: @"common_TabDownSelectedRight"]
 		    compositeToPoint: iP operation: NSCompositeSourceOver];
+		  iP.y -= 1;
 	        }
 	      else if ([anItem tabState] == NSBackgroundTab)
 		{
-		  //		  iP.y += 1;
-	          NSRectFill (NSMakeRect (iP.x, iP.y, 14, 17));
-		  [[NSImage imageNamed: @"common_TabDownUnSelectedRight.tiff"]
+	          NSRectFill(NSMakeRect(iP.x, iP.y, 14, 17));
+		  [[NSImage imageNamed: @"common_TabDownUnSelectedRight"]
 		    compositeToPoint: iP operation: NSCompositeSourceOver];
-		  //		  iP.y -= 1;
 		}
 	      else
 		NSLog(@"Not finished yet. Luff ya.\n");
@@ -560,128 +601,118 @@
     }
   else if (_type == NSTopTabsBezelBorder)
     {
+      NSPoint iP;
+
+      iP.x = _bounds.origin.x;
+      // FIXNE: Why not NSMaxY(_bounds)?
+      iP.y = _bounds.size.height - 16;
+
       for (i = 0; i < howMany; i++) 
 	{
-	  // where da tab be at?
-	  NSSize s;
 	  NSRect r;
-	  NSPoint iP;
+	  NSRect fRect;
 	  NSTabViewItem *anItem = [_items objectAtIndex: i];
-	  NSTabState itemState;
-	  
-	  itemState = [anItem tabState];
-	  
-	  s = [anItem sizeOfLabel: NO];
+	  NSTabState itemState = [anItem tabState];
+	  NSSize s = [anItem sizeOfLabel: truncate];
+
+	  [backgroundColour set];
 	  
 	  if (i == 0)
 	    {
-	      iP.x = aRect.origin.x;
-	      iP.y = aRect.size.height;
-
-	      [[NSColor controlBackgroundColor] set];
-	      
 	      if (itemState == NSSelectedTab)
 		{
 		  iP.y -= 1;
-	          NSRectFill (NSMakeRect (iP.x, iP.y, 14, 17));
-		  [[NSImage imageNamed: @"common_TabSelectedLeft.tiff"]
+	          NSRectFill(NSMakeRect(iP.x, iP.y, 14, 17));
+		  [[NSImage imageNamed: @"common_TabSelectedLeft"]
 		    compositeToPoint: iP operation: NSCompositeSourceOver];
+		  iP.y += 1;
 		}
 	      else if (itemState == NSBackgroundTab)
 	        {
-	          NSRectFill (NSMakeRect (iP.x, iP.y, 14, 17));
-		  [[NSImage imageNamed: @"common_TabUnSelectedLeft.tiff"]
+	          NSRectFill(NSMakeRect(iP.x, iP.y, 14, 17));
+		  [[NSImage imageNamed: @"common_TabUnSelectedLeft"]
 		    compositeToPoint: iP operation: NSCompositeSourceOver];
 	        }
 	      else
 		NSLog(@"Not finished yet. Luff ya.\n");
-
-	      r.origin.x = aRect.origin.x + 13;
-	      r.origin.y = aRect.size.height;
-	      r.size.width = s.width;
-	      r.size.height = 15;
-	      
-	      DPSsetlinewidth(ctxt,1);
-	      DPSsetgray(ctxt, NSWhite);
-	      DPSmoveto(ctxt, r.origin.x, r.origin.y+16);
-	      DPSrlineto(ctxt, r.size.width, 0);
-	      DPSstroke(ctxt);      
-	      
-	      [anItem drawLabel: NO inRect: r];
-	      
-	      previousRect = r;
-	      previousState = itemState;
 	    }
 	  else
 	    {
-	      iP.x = previousRect.origin.x + previousRect.size.width;
-	      iP.y = aRect.size.height;
-	      
-	      [[NSColor controlBackgroundColor] set];
-
 	      if (itemState == NSSelectedTab)
 		{
 		  iP.y -= 1;
-	          NSRectFill (NSMakeRect (iP.x, iP.y, 14, 17));
+	          NSRectFill(NSMakeRect(iP.x, iP.y, 14, 17));
 		  [[NSImage imageNamed:
-		    @"common_TabUnSelectToSelectedJunction.tiff"]
+		    @"common_TabUnSelectToSelectedJunction"]
 		    compositeToPoint: iP operation: NSCompositeSourceOver];
+		  iP.y += 1;
 		}
 	      else if (itemState == NSBackgroundTab)
 		{
 		  if (previousState == NSSelectedTab)
 		    {
 		      iP.y -= 1;
-	              NSRectFill (NSMakeRect (iP.x, iP.y, 14, 17));
+	              NSRectFill(NSMakeRect(iP.x, iP.y, 14, 17));
 		      [[NSImage imageNamed:
-			@"common_TabSelectedToUnSelectedJunction.tiff"]
+			@"common_TabSelectedToUnSelectedJunction"]
 			compositeToPoint: iP operation: NSCompositeSourceOver];
 		      iP.y += 1;
 		    }
 		  else
 		    {
-	              NSRectFill (NSMakeRect (iP.x, iP.y, 14, 17));
+	              NSRectFill(NSMakeRect(iP.x, iP.y, 14, 17));
 		      [[NSImage imageNamed:
-			@"common_TabUnSelectedJunction.tiff"]
+			@"common_TabUnSelectedJunction"]
 			compositeToPoint: iP operation: NSCompositeSourceOver];
 		    }
 		} 
 	      else
 		NSLog(@"Not finished yet. Luff ya.\n");
-
-	      r.origin.x = iP.x + 13;
-	      r.origin.y = aRect.size.height;
-	      r.size.width = s.width;
-	      r.size.height = 15;
-
-	      DPSsetlinewidth(ctxt,1);
-	      DPSsetgray(ctxt, NSWhite);
-	      DPSmoveto(ctxt, r.origin.x, r.origin.y+16);
-	      DPSrlineto(ctxt, r.size.width, 0);
-	      DPSstroke(ctxt);      
-	      
-	      [anItem drawLabel: NO inRect: r];
-	      
-	      previousRect = r;
-	      previousState = itemState;
 	    }  
 
-	  if (i == howMany-1)
+	  r.origin.x = iP.x + 13;
+	  r.origin.y = iP.y;
+	  r.size.width = s.width;
+	  r.size.height = 15;
+	  
+	  fRect = r;
+	  if (itemState == NSSelectedTab)
 	    {
-	      iP.x += s.width + 13;
-	      
-	      [[NSColor controlBackgroundColor] set];
+	      // Undraw the line that separates the tab from its view.
+	      fRect.origin.y -= 1;
+	      fRect.size.height += 1;
+	    }
+	  NSRectFill(fRect);
+
+	  // Draw the line at the top of the item
+	  [lineColour set];
+	  DPSsetlinewidth(ctxt, 1);
+	  DPSmoveto(ctxt, r.origin.x, r.origin.y + 16);
+	  DPSrlineto(ctxt, r.size.width, 0);
+	  DPSstroke(ctxt);
+	  
+	  // Label
+	  [anItem drawLabel: truncate inRect: r];
+	  
+	  iP.x += s.width + 13;
+	  previousState = itemState;
+
+	  if (i == howMany - 1)
+	    {
+	      [backgroundColour set];
 	    
 	      if ([anItem tabState] == NSSelectedTab)
 	        {	      
-	          NSRectFill (NSMakeRect (iP.x, iP.y, 14, 17));
-		  [[NSImage imageNamed: @"common_TabSelectedRight.tiff"]
+		  iP.y -= 1;
+	          NSRectFill(NSMakeRect(iP.x, iP.y, 14, 17));
+		  [[NSImage imageNamed: @"common_TabSelectedRight"]
 		    compositeToPoint: iP operation: NSCompositeSourceOver];
+		  iP.y += 1;
 		}  
 	      else if ([anItem tabState] == NSBackgroundTab)
 		{
-	          NSRectFill (NSMakeRect (iP.x, iP.y, 14, 17));
-		  [[NSImage imageNamed: @"common_TabUnSelectedRight.tiff"]
+	          NSRectFill(NSMakeRect(iP.x, iP.y, 14, 17));
+		  [[NSImage imageNamed: @"common_TabUnSelectedRight"]
 		    compositeToPoint: iP operation: NSCompositeSourceOver];
 		}
 	      else
@@ -689,6 +720,7 @@
 	    }
 	}
     }
+  // FIXME: Missing drawing code for other cases
 
   DPSgrestore(ctxt);
 }
@@ -706,14 +738,14 @@
  */
 - (NSTabViewItem*) tabViewItemAtPoint: (NSPoint)point
 {
-  int		howMany = [_items count];
-  int		i;
+  int howMany = [_items count];
+  int i;
 
   for (i = 0; i < howMany; i++)
     {
       NSTabViewItem *anItem = [_items objectAtIndex: i];
 
-      if (NSPointInRect(point,[anItem _tabRect]))
+      if (NSPointInRect(point, [anItem _tabRect]))
 	return anItem;
     }
 
@@ -768,29 +800,14 @@
   [super encodeWithCoder: aCoder];
   if ([aCoder allowsKeyedCoding])
     {
-      unsigned int type = 0;
-      switch(_type)
-	{
-	case NSTopTabsBezelBorder:
-	  type = 0;
-	  break;
-	case NSLeftTabsBezelBorder:
-	  type = 1;
-	  break;
-	case NSBottomTabsBezelBorder:
-	  type = 2;
-	  break;
-	case NSRightTabsBezelBorder:
-	  type = 3;
-	  break;
-	}
+      unsigned int type = _type; // no flags set...
 
       [aCoder encodeBool: [self allowsTruncatedLabels] forKey: @"NSAllowTruncatedLabels"];
       [aCoder encodeBool: [self drawsBackground] forKey: @"NSDrawsBackground"];
       [aCoder encodeObject: [self font] forKey: @"NSFont"];
       [aCoder encodeObject: _items forKey: @"NSTabViewItems"];
       [aCoder encodeObject: [self selectedTabViewItem] forKey: @"NSSelectedTabViewItem"];
-      [aCoder encodeInt: type forKey: @"NSTvFlags"]; // no flags set...
+      [aCoder encodeInt: type forKey: @"NSTvFlags"];
     }
   else
     {
@@ -835,32 +852,49 @@
 	}
       if ([aDecoder containsValueForKey: @"NSTvFlags"])
         {
-	  unsigned int type = [aDecoder decodeIntForKey: @"NSTvFlags"];
-	  switch(type)
-	    {
-	    case 0: 
-	      _type = NSTopTabsBezelBorder;
-	      break;
-	    case 1: 
-	      _type = NSLeftTabsBezelBorder;
-	      break;
-	    case 2: 
-	      _type = NSBottomTabsBezelBorder;
-	      break;
-	    case 3:
-	      _type = NSRightTabsBezelBorder;
-	      break;
-	    default:
-	      _type = NSTopTabsBezelBorder;
-	      break;
-	    }
+	  int vFlags = [aDecoder decodeIntForKey: @"NSTvFlags"];
+
+	  [self setControlTint: ((vFlags & 0x70000000) >> 28)];
+	  [self setControlSize: ((vFlags & 0x0c000000) >> 26)];
+	  [self setTabViewType: (vFlags & 0x00000007)];
 	}
     }
   else
     {
+      int version = [aDecoder versionForClassName: @"NSTabView"];
+
       [aDecoder decodeValueOfObjCType: @encode(id) at: &_items];
       [aDecoder decodeValueOfObjCType: @encode(id) at: &_font];
       [aDecoder decodeValueOfObjCType: @encode(NSTabViewType) at: &_type];
+      if (version < 2)
+        {
+	  switch(_type)
+	    {
+	      case 0:
+		_type = NSTopTabsBezelBorder;
+		break;
+	      case 5:
+		_type = NSLeftTabsBezelBorder;
+		break;
+	      case 1:
+		_type = NSBottomTabsBezelBorder;
+		break;
+	      case 6:
+		_type = NSRightTabsBezelBorder;
+		break;
+	      case 2:
+		_type = NSNoTabsBezelBorder;
+		break;
+	      case 3:
+		_type = NSNoTabsLineBorder;
+		break;
+	      case 4:
+		_type = NSNoTabsNoBorder;
+		break;
+	      default:
+		break;
+	    }
+	}
       [aDecoder decodeValueOfObjCType: @encode(BOOL) at: &_draws_background];
       [aDecoder decodeValueOfObjCType: @encode(BOOL) at: &_truncated_label];
       _delegate = [aDecoder decodeObject];
