@@ -338,7 +338,7 @@ static Class textFieldCellClass;
 //
 - (void) mouseDown: (NSEvent*)theEvent
 {
-  if ([self isSelectable] == NO)
+  if ([self isSelectable] == NO || [self isEnabled] == NO)
     {
       [super mouseDown: theEvent];
       return;
@@ -392,7 +392,7 @@ static Class textFieldCellClass;
 
 - (BOOL) acceptsFirstMouse: (NSEvent *)aEvent
 {
-  return [self isEditable];
+  return [self isEditable] && [self isEnabled];
 }
 
 /** <p>Returns whether the NSTextField accepts to be the first responder.
@@ -405,7 +405,7 @@ static Class textFieldCellClass;
   // we do not accept first responder if there is already a 
   // _text_object, else it would make the _text_object resign
   // and end editing
-  return (_text_object == nil) && [self isSelectable];
+  return (_text_object == nil) && [self isSelectable] && [self isEnabled];
 }
 
 - (BOOL) becomeFirstResponder
@@ -488,32 +488,17 @@ static Class textFieldCellClass;
     }
 }
 
-/**<p>Posts a NSControlTextDidBeginEditingNotification notification with object
-   self and a NSDictionary containing the NSFieldEditor for key
-   as user Info</p>
-*/
 - (void) textDidBeginEditing: (NSNotification *)aNotification
 {
-  NSDictionary *notifDict;
-  
-  notifDict = [NSDictionary dictionaryWithObject:[aNotification object] 
-			    forKey: @"NSFieldEditor"];
-
-  [nc postNotificationName: NSControlTextDidBeginEditingNotification
-      object: self
-      userInfo: notifDict];
+  [super textDidBeginEditing: aNotification];
 }
 
 - (void) textDidChange: (NSNotification *)aNotification
 {
-  NSDictionary *d;
+
   NSFormatter *formatter;
 
-  d = [NSDictionary dictionaryWithObject: [aNotification object] 
-		    forKey: @"NSFieldEditor"];
-  [nc postNotificationName: NSControlTextDidChangeNotification
-      object: self
-      userInfo: d];
+  [super textDidChange: aNotification];
 
   formatter = [_cell formatter];
   if (formatter != nil)
@@ -559,26 +544,14 @@ static Class textFieldCellClass;
 	      NSLog (@"Unimplemented: should delete last typed character");
 	    }
 	}
-
     }
 }
 
 - (void) textDidEndEditing: (NSNotification *)aNotification
 {
-  NSDictionary *d;
   id textMovement;
 
-  [self validateEditing];
-
-  [_cell endEditing: [aNotification object]];
-
-  _text_object = nil;
-
-  d = [NSDictionary dictionaryWithObject: [aNotification object] 
-		    forKey: @"NSFieldEditor"];
-  [nc postNotificationName: NSControlTextDidEndEditingNotification
-      object: self
-      userInfo: d];
+  [super textDidEndEditing: aNotification];
 
   textMovement = [[aNotification userInfo] objectForKey: @"NSTextMovement"];
   if (textMovement)
@@ -709,7 +682,7 @@ static Class textFieldCellClass;
 - (void) encodeWithCoder: (NSCoder*)aCoder
 {
   [super encodeWithCoder: aCoder];
-  if(![aCoder allowsKeyedCoding])
+  if (![aCoder allowsKeyedCoding])
     {
       [aCoder encodeConditionalObject: _delegate];
       [aCoder encodeValueOfObjCType: @encode(SEL) at: &_error_action];
@@ -719,7 +692,7 @@ static Class textFieldCellClass;
 - (id) initWithCoder: (NSCoder*)aDecoder
 {
   self = [super initWithCoder: aDecoder];
-  if([aDecoder allowsKeyedCoding])
+  if ([aDecoder allowsKeyedCoding])
     {
       // do nothing for now...
     }
