@@ -189,9 +189,17 @@ static NSColor	*txtCol;
 {
   if (_textfieldcell_draws_background)
     {
-      [_background_color set];
+      if ([self isEnabled])
+	{
+          [_background_color set];
+	}
+      else
+	{
+	  [[NSColor controlBackgroundColor] set];
+	}
       NSRectFill ([self drawingRectForBounds: cellFrame]);
     }
+
   [super drawInteriorWithFrame: cellFrame inView: controlView];
 }
 
@@ -208,7 +216,7 @@ static NSColor	*txtCol;
   BOOL tmp;
   [super encodeWithCoder: aCoder];
 
-  if([aCoder allowsKeyedCoding])
+  if ([aCoder allowsKeyedCoding])
     {
       [aCoder encodeObject: [self backgroundColor] forKey: @"NSBackgroundColor"];
       [aCoder encodeObject: [self textColor] forKey: @"NSTextColor"];
