@@ -52,6 +52,7 @@
 #include "AppKit/NSScrollView.h"
 #include "AppKit/NSTextStorage.h"
 #include "AppKit/NSTextView.h"
+#include "AppKit/NSParagraphStyle.h"
 
 /*
 These methods are for user actions, ie. they are normally called from
@@ -113,7 +114,7 @@ send -shouldChangeTextInRange:replacementString: or -didChangeText.
 
 /** First some helpers **/
 
-@interface NSTextView (user_action_helpers)
+@interface NSTextView (UserActionHelpers)
 
 -(void) _illegalMovement: (int)textMovement;
 
@@ -124,7 +125,7 @@ send -shouldChangeTextInRange:replacementString: or -didChangeText.
 @end
 
 
-@implementation NSTextView (user_action_helpers)
+@implementation NSTextView (UserActionHelpers)
 
 - (void) _illegalMovement: (int)textMovement
 {
@@ -221,7 +222,7 @@ send -shouldChangeTextInRange:replacementString: or -didChangeText.
 @end
 
 
-@implementation NSTextView (user_actions)
+@implementation NSTextView (UserActions)
 
 /* Helpers used with _changeAttribute:inRange:using:. */
 static NSNumber *int_minus_one(NSNumber *cur)
@@ -746,28 +747,26 @@ added to the selection (1,3).
 	  [self setSelectedRange: NSMakeRange(anchor, cindex - anchor)
 			affinity: NSSelectionAffinityDownstream
 		  stillSelecting: NO];
-	  [self scrollRangeToVisible: NSMakeRange(anchor, cindex - anchor)];
 	}
       else
  	{
 	  [self setSelectedRange: NSMakeRange(cindex, anchor - cindex)
 			affinity: NSSelectionAffinityUpstream
 		  stillSelecting: NO];
-	  [self scrollRangeToVisible: NSMakeRange(cindex, anchor - cindex)];
 	}
     }
   else
     {
       [self setSelectedRange: NSMakeRange(cindex, 0)];
-      [self scrollRangeToVisible: NSMakeRange(cindex, 0)];
     }
+  [self scrollRangeToVisible: NSMakeRange(cindex, 0)];
 }
 
-- (void) _move: (GSInsertionPointMovementDirection)direction
-      distance: (float)distance
-	select: (BOOL)select
+- (void) _moveFrom: (unsigned int)cindex
+	 direction: (GSInsertionPointMovementDirection)direction
+          distance: (float)distance
+	    select: (BOOL)select
 {
-  unsigned int cindex;
   int new_direction;
 
   if (direction == GSInsertionPointMoveUp ||
@@ -785,7 +784,6 @@ added to the selection (1,3).
       new_direction = 0;
     }
 
-  cindex = [self _movementOrigin];
   if (new_direction != _currentInsertionPointMovementDirection ||
       !new_direction)
     {
@@ -803,6 +801,64 @@ added to the selection (1,3).
   _currentInsertionPointMovementDirection = new_direction;
 }
 
+- (void) _move: (GSInsertionPointMovementDirection)direction
+      distance: (float)distance
+	select: (BOOL)select
+{
+  [self _moveFrom: [self _movementOrigin]
+	direction: direction
+	 distance: distance
+	   select: select];
+}
+
+
+/*
+ * returns the character index for the left or right side of the selected text
+ * based upon the writing direction of the paragraph style.
+ * it should only be used when moving a literal direction such as left right
+ * up or down, not directions like forward, backward, beginning or end
+ */
+- (unsigned int) _characterIndexForSelectedRange: (NSRange)range
+  			direction: (GSInsertionPointMovementDirection)direction
+{
+  unsigned int cIndex;
+  NSParagraphStyle *parStyle;
+  NSWritingDirection writingDirection;
+  
+  parStyle = [[self typingAttributes]
+	  	objectForKey: NSParagraphStyleAttributeName];
+  writingDirection = [parStyle baseWritingDirection];
+  
+  switch (writingDirection)
+    {
+      case NSWritingDirectionLeftToRight:
+        cIndex = (direction == GSInsertionPointMoveLeft
+		  || direction == GSInsertionPointMoveUp)
+	         ? range.location
+		 : NSMaxRange(range);
+        break;
+      case NSWritingDirectionRightToLeft:
+        cIndex = (direction == GSInsertionPointMoveLeft
+		  || direction == GSInsertionPointMoveUp)
+        	 ? NSMaxRange(range)
+		 : range.location;
+        break;
+      case NSWritingDirectionNaturalDirection:
+        // not sure if we should see this as it should resolve to either
+        // LeftToRight or RightToLeft in NSParagraphStyle
+        // for the users language.
+	//
+	// currently falls back to default..
+      default:
+	/* default to LeftToRight */
+        cIndex = (direction == GSInsertionPointMoveLeft
+		  || direction == GSInsertionPointMoveUp)
+	         ? range.location
+		 : NSMaxRange(range);
+        break;
+     }
+  return cIndex;
+}
 
 /*
 Insertion point movement actions.
@@ -813,7 +869,12 @@ check if there was a reason for that.
 
 - (void) moveUp: (id)sender
 {
-  [self _move: GSInsertionPointMoveUp
+  NSRange range = [self selectedRange];
+  unsigned int cIndex = [self _characterIndexForSelectedRange:range
+	  			direction:GSInsertionPointMoveUp];
+  
+  [self _moveFrom: cIndex
+	direction: GSInsertionPointMoveUp
 	distance: 0.0
 	select: NO];
 }
@@ -827,7 +888,11 @@ check if there was a reason for that.
 
 - (void) moveDown: (id)sender
 {
-  [self _move: GSInsertionPointMoveDown
+  NSRange range = [self selectedRange];
+  unsigned int cIndex = [self _characterIndexForSelectedRange: range
+	  			direction: GSInsertionPointMoveDown];
+  [self _moveFrom: cIndex
+	direction: GSInsertionPointMoveDown
 	distance: 0.0
 	select: NO];
 }
@@ -841,26 +906,56 @@ check if there was a reason for that.
 
 - (void) moveLeft: (id)sender
 {
-  [self _move: GSInsertionPointMoveLeft
-	distance: 0.0
-	select: NO];
+  NSRange range = [self selectedRange];
+
+  if (range.length)
+    {
+      unsigned int cIndex;
+      
+      cIndex = [self _characterIndexForSelectedRange: range
+	      		direction:GSInsertionPointMoveLeft];
+      [self _moveTo: cIndex select: NO];
+    }
+  else 
+    {
+
+      [self _move: GSInsertionPointMoveLeft
+ 	    distance: 0.0
+	    select: NO];
+    }
 }
 
 - (void) moveRight: (id)sender
 {
-  [self _move: GSInsertionPointMoveRight
-	distance: 0.0
-	select: NO];
+  NSRange range = [self selectedRange];
+  
+  if (range.length)
+    {
+      unsigned int cIndex;
+      
+      cIndex = [self _characterIndexForSelectedRange: range
+	       		direction: GSInsertionPointMoveRight];
+      [self _moveTo: cIndex select: NO];
+    }
+  else
+    {
+      [self _move: GSInsertionPointMoveRight
+ 	    distance: 0.0
+	    select: NO];
+    }
 }
 
 
 - (void) moveBackward: (id)sender
 {
-  unsigned int to = [self _movementOrigin];
+  NSRange range = [self selectedRange];
+  unsigned int to = range.location;
 
-  if (to == 0)
-    return;
-  to--;
+  if (range.length == 0 && to)
+    {
+      to--;
+    }
+  
   [self _moveTo: to
 	 select: NO];
 }
@@ -878,14 +973,18 @@ check if there was a reason for that.
 
 - (void) moveForward: (id)sender
 {
-  unsigned int to = [self _movementOrigin];
-
-  if (to == [_textStorage length])
-    return;
-  to++;
+  NSRange range = [self selectedRange];
+  unsigned int to = NSMaxRange(range);
+  
+  if (range.length == 0 && to != [_textStorage length])
+    {
+      to++;
+    }
+  
   [self _moveTo: to
 	 select: NO];
 }
+
 - (void) moveForwardAndModifySelection: (id)sender
 {
   unsigned int to = [self _movementOrigin];
@@ -899,9 +998,11 @@ check if there was a reason for that.
 
 - (void) moveWordBackward: (id)sender
 {
+  NSRange range = [self selectedRange];
   unsigned int newLocation;
-
-  newLocation = [_textStorage nextWordFromIndex: [self _movementOrigin]
+  unsigned int cIndex = range.location;
+  
+  newLocation = [_textStorage nextWordFromIndex: cIndex
 			      forward: NO];
   [self _moveTo: newLocation
 	 select: NO];
@@ -920,8 +1021,9 @@ check if there was a reason for that.
 - (void) moveWordForward: (id)sender
 {
   unsigned newLocation;
+  unsigned int cIndex = NSMaxRange([self selectedRange]);
 
-  newLocation = [_textStorage nextWordFromIndex: [self _movementOrigin]
+  newLocation = [_textStorage nextWordFromIndex: cIndex
 			      forward: YES];
   [self _moveTo: newLocation
 	 select: NO];
@@ -943,30 +1045,63 @@ check if there was a reason for that.
 	 select: NO];
 }
 
+- (void) moveToBeginningOfDocumentAndModifySelection: (id)sender
+{
+  [self _moveTo: 0
+	  select:YES];
+}
+
 - (void) moveToEndOfDocument: (id)sender
 {
   [self _moveTo: [_textStorage length]
 	 select: NO];
 }
 
+- (void) moveToEndOfDocumentAndModifySelection: (id)sender
+{
+  [self _moveTo: [_textStorage length]
+	  select:YES];
+}
+
 - (void) moveToBeginningOfParagraph: (id)sender
+{
+  NSRange aRange = [self selectedRange];
+ 
+  
+  aRange = [[_textStorage string] lineRangeForRange: 
+				      NSMakeRange(aRange.location, 0)];
+  [self _moveTo: aRange.location
+	 select: NO];
+}
+
+- (void) moveToBeginningOfParagraphAndModifySelection: (id)sender
 {
   NSRange aRange;
   
   aRange = [[_textStorage string] lineRangeForRange: 
 				      NSMakeRange([self _movementOrigin], 0)];
   [self _moveTo: aRange.location
-	 select: NO];
+	 select: YES];
 }
 
-- (void) moveToEndOfParagraph: (id)sender
+- (void) _moveToEndOfParagraph: (id)sender modify:(BOOL)flag
 {
   NSRange aRange;
   unsigned newLocation;
   unsigned maxRange;
-  
+  unsigned int cIndex;
+
+  if (flag)
+    {
+      cIndex = [self _movementOrigin];
+    }
+  else
+    {
+      cIndex = NSMaxRange([self selectedRange]);
+    }
+
   aRange = [[_textStorage string] lineRangeForRange: 
-				      NSMakeRange([self _movementOrigin], 0)];
+				      NSMakeRange(cIndex, 0)];
   maxRange = NSMaxRange (aRange);
 
   if (maxRange == 0)
@@ -1010,23 +1145,54 @@ check if there was a reason for that.
     }
 
   [self _moveTo: newLocation
-	 select: NO];
+	 select: flag];
 }
 
+- (void) moveToEndOfParagraph: (id)sender
+{
+  [self _moveToEndOfParagraph:sender modify:NO];  
+}
+
+- (void) moveToEndOfParagraphAndModifySelection: (id)sender
+{
+  [self _moveToEndOfParagraph:sender modify:YES];  
+}
 
 /* TODO: this is only the beginning and end of lines if lines are horizontal
 and layout is left-to-right */
 - (void) moveToBeginningOfLine: (id)sender
 {
-  [self _move: GSInsertionPointMoveLeft
+  NSRange range = [self selectedRange];
+  unsigned int cIndex = range.location;
+
+  [self _moveFrom: cIndex
+	direction: GSInsertionPointMoveLeft
 	distance: 1e8
 	select: NO];
 }
+
+- (void) moveToBeginningOfLineAndModifySelection: (id)sender
+{
+  [self _move: GSInsertionPointMoveLeft
+	distance: 1e8
+	select: YES];
+}
+
 - (void) moveToEndOfLine: (id)sender
+{
+  unsigned int cIndex = NSMaxRange([self selectedRange]);
+
+  [self _moveFrom: cIndex
+	direction: GSInsertionPointMoveRight
+	distance: 1e8
+	select: NO];
+}
+
+- (void) moveToEndOfLineAndModifySelection: (id)sender
 {
   [self _move: GSInsertionPointMoveRight
 	distance: 1e8
-	select: NO];
+	select: YES];
 }
 
 /**
@@ -1035,11 +1201,22 @@ and layout is left-to-right */
  * horizontal position of the last vertical movement.
  * If the receiver is a field editor, this method returns immediatly. 
  */
-- (void) pageDown: (id)sender
+- (void) _pageDown: (id)sender modify: (BOOL)flag
 {
   float    scrollDelta;
   float    oldOriginY;
   float    newOriginY;
+  unsigned int cIndex;
+  
+  if (flag)
+    {
+      cIndex = [self _movementOrigin];
+    }
+  else
+    {
+      cIndex = [self _characterIndexForSelectedRange: [self selectedRange]
+	      		direction: GSInsertionPointMoveDown];
+    }
 
   /*
    * Scroll; also determine how far to move the insertion point.
@@ -1051,17 +1228,24 @@ and layout is left-to-right */
 
   if (scrollDelta == 0)
     {
-      /* TODO/FIXME: If no scroll was done, it means we are in the
-       * last page of the document already - should we move the
-       * insertion point to the last line when the user clicks
-       * 'PageDown' in that case ?
-       */
+      [self _moveTo:[_textStorage length] select:flag];
       return;
     }
 
-  [self _move: GSInsertionPointMoveDown
+  [self _moveFrom: cIndex
+	direction: GSInsertionPointMoveDown
 	distance: scrollDelta
-	select: NO];
+	select: flag];
+}
+
+- (void) pageDown:(id)sender
+{
+  [self _pageDown:sender modify:NO];
+}
+
+- (void) pageDownAndModifySelection:(id)sender
+{
+  [self _pageDown:sender modify:YES];
 }
 
 /**
@@ -1070,12 +1254,22 @@ and layout is left-to-right */
  * horizontal position of the last vertical movement.
  * If the receiver is a field editor, this method returns immediatly. 
  */
-- (void) pageUp: (id)sender
+- (void) _pageUp: (id)sender modify:(BOOL)flag
 {
   float    scrollDelta;
   float    oldOriginY;
   float    newOriginY;
-
+  unsigned int cIndex;
+  
+  if (flag)
+    {
+      cIndex = [self _movementOrigin];
+    }
+  else
+    {
+      cIndex = [self _characterIndexForSelectedRange:[self selectedRange]
+		        direction: GSInsertionPointMoveUp];
+    }
   /*
    * Scroll; also determine how far to move the insertion point.
    */
@@ -1086,46 +1280,44 @@ and layout is left-to-right */
 
   if (scrollDelta == 0)
     {
-      /* TODO/FIXME: If no scroll was done, it means we are in the
-       * first page of the document already - should we move the
-       * insertion point to the first line when the user clicks
-       * 'PageUp' in that case ?
-       */
-      return;
+      [self _moveTo:0 select:flag];
+      return; 
     }
 
-
-  [self _move: GSInsertionPointMoveUp
+  [self _moveFrom: cIndex
+	direction: GSInsertionPointMoveUp
 	distance: -scrollDelta
-	select: NO];
+	select: flag];
+}
+
+- (void) pageUp:(id)sender
+{
+  [self _pageUp:sender modify:NO];
+}
+
+- (void) pageUpAndModifySelection:(id)sender
+{
+  [self _pageUp:sender modify:YES];
 }
 
 - (void) scrollLineDown: (id)sender
 {
-  // TODO
-  NSLog(@"Method %s is not implemented for class %s",
-	"scrollLineDown:", "NSTextView");
+  [[self enclosingScrollView] scrollLineDown: sender];
 }
 
 - (void) scrollLineUp: (id)sender
 {
-  // TODO
-  NSLog(@"Method %s is not implemented for class %s",
-	"scrollLineUp:", "NSTextView");
+  [[self enclosingScrollView] scrollLineUp: sender];
 }
 
 - (void) scrollPageDown: (id)sender
 {
-  // TODO
-  NSLog(@"Method %s is not implemented for class %s",
-	"scrollPageDown:", "NSTextView");
+  [[self enclosingScrollView] scrollPageDown: sender];
 }
 
 - (void) scrollPageUp: (id)sender
 {
-  // TODO
-  NSLog(@"Method %s is not implemented for class %s",
-	"scrollPageUp:", "NSTextView");
+  [[self enclosingScrollView] scrollPageUp: sender];
 }
 
 
