@@ -96,6 +96,22 @@ NSString *NSApplicationWillResignActiveNotification
 NSString *NSApplicationWillUnhideNotification = @"ApplicationWillUnhide";
 NSString *NSApplicationWillUpdateNotification = @"ApplicationWillUpdate";
 
+// NSBitmapImageRep Global strings
+NSString *NSImageCompressionMethod = @"NSImageCompressionMethod";
+NSString *NSImageCompressionFactor = @"NSImageCompressionFactor";
+NSString *NSImageDitherTransparency = @"NSImageDitherTransparency";
+NSString *NSImageRGBColorTable = @"NSImageRGBColorTable";
+NSString *NSImageInterlaced = @"NSImageInterlaced";
+//NSString *NSImageColorSyncProfileData = @"NSImageColorSyncProfileData";  // Mac OS X only
+//NSString *GSImageICCProfileData = @"GSImageICCProfileData";  // if & when GNUstep supports color management
+NSString *NSImageFrameCount = @"NSImageFrameCount";
+NSString *NSImageCurrentFrame = @"NSImageCurrentFrame";
+NSString *NSImageCurrentFrameDuration = @"NSImageCurrentFrameDuration";
+NSString *NSImageLoopCount = @"NSImageLoopCount";
+NSString *NSImageGamma = @"NSImageGamma";
+NSString *NSImageProgressive = @"NSImageProgressive";
+//NSString *NSImageEXIFData = @"NSImageEXIFData";  // No support yet in GNUstep
+
 // NSColor Global strings
 NSString *NSCalibratedWhiteColorSpace = @"NSCalibratedWhiteColorSpace";
 NSString *NSCalibratedBlackColorSpace = @"NSCalibratedBlackColorSpace";
@@ -413,19 +429,30 @@ NSString *NSWorkspaceWillUnmountNotification =
 @"NSWorkspaceWillUnmountNotification";
 
 /*
- *	NSStringDrawing NSString additions
+ *	NSStringDrawing NSAttributedString additions
  */
-NSString *NSFontAttributeName  = @"NSFontAttributeName";
-NSString *NSParagraphStyleAttributeName = @"NSParagraphStyleAttributeName";
-NSString *NSForegroundColorAttributeName = @"NSForegroundColorAttributeName";
-NSString *NSUnderlineStyleAttributeName = @"NSUnderlineStyleAttributeName";
-NSString *NSSuperscriptAttributeName = @"NSSuperscriptAttributeName";
-NSString *NSBackgroundColorAttributeName = @"NSBackgroundColorAttributeName";
 NSString *NSAttachmentAttributeName = @"NSAttachmentAttributeName";
-NSString *NSLigatureAttributeName = @"NSLigatureAttributeName";
+NSString *NSBackgroundColorAttributeName = @"NSBackgroundColorAttributeName";
 NSString *NSBaselineOffsetAttributeName = @"NSBaselineOffsetAttributeName";
+NSString *NSCursorAttributeName = @"NSCursorAttributeName";
+NSString *NSExpansionAttributeName = @"NSExpansionAttributeName";
+NSString *NSFontAttributeName = @"NSFontAttributeName";
+NSString *NSForegroundColorAttributeName = @"NSForegroundColorAttributeName";
 NSString *NSKernAttributeName = @"NSKernAttributeName";
+NSString *NSLigatureAttributeName = @"NSLigatureAttributeName";
 NSString *NSLinkAttributeName = @"NSLinkAttributeName";
+NSString *NSObliquenessAttributeName = @"NSObliquenessAttributeName";
+NSString *NSParagraphStyleAttributeName = @"NSParagraphStyleAttributeName";
+NSString *NSShadowAttributeName = @"NSShadowAttributeName";
+NSString *NSStrikethroughColorAttributeName
+  = @"NSStrikethroughColorAttributeName";
+NSString *NSStrokeColorAttributeName = @"NSStrokeColorAttributeName";
+NSString *NSStrokeWidthAttributeName = @"NSStrokeWidthAttributeName";
+NSString *NSSuperscriptAttributeName = @"NSSuperscriptAttributeName";
+NSString *NSToolTipAttributeName = @"NSToolTipAttributeName";
+NSString *NSUnderlineColorAttributeName = @"NSUnderlineColorAttributeName";
+NSString *NSUnderlineStyleAttributeName = @"NSUnderlineStyleAttributeName";
+
 
 // NSToolbar notifications
 NSString *NSToolbarDidRemoveItemNotification = @"NSToolbarDidRemoveItemNotification";
@@ -474,6 +501,16 @@ const NSWindowDepth _GSWindowDepths[7] = { 258, 264, 514, 516, 517, 520, 0 };
 
 /* End of color functions externs */
 
+// NSKeyValueBinding
+NSString *NSObservedObjectKey = @"NSObservedObjectKey";
+NSString *NSObservedKeyPath = @"NSObservedKeyPath";
+NSString *NSOptionsKey = @"NSOptionsKey";
+// FIXME: Need to defined!
+id NSMultipleValuesMarker = nil;
+id NSNoSelectionMarker = nil;
+id NSNotApplicableMarker = nil;
+
+
 extern void __objc_gui_force_linking (void);
 
 void
